View source: R/backup_operations.R
| backup_associate_backup_vault_mpa_approval_team | R Documentation |
Associates an MPA approval team with a backup vault.
See https://www.paws-r-sdk.com/docs/backup_associate_backup_vault_mpa_approval_team/ for full documentation.
backup_associate_backup_vault_mpa_approval_team(
BackupVaultName,
MpaApprovalTeamArn,
RequesterComment = NULL
)
BackupVaultName |
[required] The name of the backup vault to associate with the MPA approval team. |
MpaApprovalTeamArn |
[required] The Amazon Resource Name (ARN) of the MPA approval team to associate with the backup vault. |
RequesterComment |
A comment provided by the requester explaining the association request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.