backup_create_backup_access_point: Creates a backup access point for an Amazon S3 recovery point

View source: R/backup_operations.R

backup_create_backup_access_pointR Documentation

Creates a backup access point for an Amazon S3 recovery point

Description

Creates a backup access point for an Amazon S3 recovery point. A backup access point provides on-demand, read-only access to the backup data in a recovery point through an Amazon S3 access point, without initiating a restore.

See https://www.paws-r-sdk.com/docs/backup_create_backup_access_point/ for full documentation.

Usage

backup_create_backup_access_point(
  AccessPointMetadata = NULL,
  AccessPointPolicy = NULL,
  Name,
  RecoveryPointArn,
  Tags = NULL
)

Arguments

AccessPointMetadata

Metadata for the backup access point. For continuous (point-in-time) recovery points, you must include an AccessPointInTime timestamp (in format ⁠2021-11-27T03:30:27Z⁠). The access point provides access to the content present in the backup at that specific time. You can specify any time within the continuous backup's retention period, up to the latest restorable time. For snapshot recovery points, do not include AccessPointInTime.

AccessPointPolicy

An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point. The policy controls how backup data can be accessed through the access point. If you do not specify a policy, access is governed by the caller's IAM permissions. For more information, see Configuring IAM policies for using access points in the Amazon S3 User Guide.

Name

[required] The name of the backup access point. This name is shared with the Amazon S3 access point namespace. It must be unique within your account and Region and cannot conflict with an existing Amazon S3 access point. For more information about access point naming, see Access points naming rules, restrictions, and limitations in the Amazon S3 User Guide.

RecoveryPointArn

[required] The Amazon Resource Name (ARN) of the recovery point for which to create the backup access point. The recovery point must be an Amazon S3 recovery point in the AVAILABLE, STOPPED, or COMPLETED state.

Tags

The tags to assign to the backup access point.


paws.storage documentation built on Oct. 8, 2026, 9:17 a.m.