View source: R/backup_operations.R
| backup_create_tiering_configuration | R Documentation |
Creates a tiering configuration.
See https://www.paws-r-sdk.com/docs/backup_create_tiering_configuration/ for full documentation.
backup_create_tiering_configuration(
TieringConfiguration,
TieringConfigurationTags = NULL,
CreatorRequestId = NULL
)
TieringConfiguration |
[required] A tiering configuration must contain a unique The |
TieringConfigurationTags |
The tags to assign to the tiering configuration. |
CreatorRequestId |
This is a unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. This parameter is optional. If used, this parameter must contain 1 to 50 alphanumeric or '-_.' characters. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.