View source: R/backup_operations.R
| backup_delete_backup_access_point | R Documentation |
Deletes a backup access point. This deletes the underlying Amazon S3 access point and, if no other backup access points remain for the recovery point, resumes lifecycle transitions for that recovery point.
See https://www.paws-r-sdk.com/docs/backup_delete_backup_access_point/ for full documentation.
backup_delete_backup_access_point(AccessPointArn)
AccessPointArn |
[required] The Amazon Resource Name (ARN) of the backup access point to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.