backup_describe_backup_access_point: Returns metadata about a backup access point, including its...

View source: R/backup_operations.R

backup_describe_backup_access_pointR Documentation

Returns metadata about a backup access point, including its status and the details of the underlying Amazon S3 access point

Description

Returns metadata about a backup access point, including its status and the details of the underlying Amazon S3 access point.

See https://www.paws-r-sdk.com/docs/backup_describe_backup_access_point/ for full documentation.

Usage

backup_describe_backup_access_point(AccessPointArn)

Arguments

AccessPointArn

[required] The Amazon Resource Name (ARN) of the backup access point to describe.


paws.storage documentation built on Oct. 8, 2026, 9:17 a.m.