backup_describe_global_settings: Describes whether the Amazon Web Services account has enabled...

View source: R/backup_operations.R

backup_describe_global_settingsR Documentation

Describes whether the Amazon Web Services account has enabled different cross-account management options, including cross-account backup, multi-party approval, and delegated administrator

Description

Describes whether the Amazon Web Services account has enabled different cross-account management options, including cross-account backup, multi-party approval, and delegated administrator. Returns an error if the account is not a member of an Organizations organization. Example: ⁠describe-global-settings --region us-west-2⁠

See https://www.paws-r-sdk.com/docs/backup_describe_global_settings/ for full documentation.

Usage

backup_describe_global_settings()

paws.storage documentation built on May 30, 2026, 9:13 a.m.