backup_disassociate_backup_vault_mpa_approval_team: Removes the association between an MPA approval team and a...

View source: R/backup_operations.R

backup_disassociate_backup_vault_mpa_approval_teamR Documentation

Removes the association between an MPA approval team and a backup vault, disabling the MPA approval workflow for restore operations

Description

Removes the association between an MPA approval team and a backup vault, disabling the MPA approval workflow for restore operations.

See https://www.paws-r-sdk.com/docs/backup_disassociate_backup_vault_mpa_approval_team/ for full documentation.

Usage

backup_disassociate_backup_vault_mpa_approval_team(
  BackupVaultName,
  RequesterComment = NULL
)

Arguments

BackupVaultName

[required] The name of the backup vault from which to disassociate the MPA approval team.

RequesterComment

An optional comment explaining the reason for disassociating the MPA approval team from the backup vault.


paws.storage documentation built on May 30, 2026, 9:13 a.m.