backup_get_backup_plan: Returns BackupPlan details for the specified BackupPlanId

View source: R/backup_operations.R

backup_get_backup_planR Documentation

Returns BackupPlan details for the specified BackupPlanId

Description

Returns BackupPlan details for the specified BackupPlanId. The details are the body of a backup plan in JSON format, in addition to plan metadata.

See https://www.paws-r-sdk.com/docs/backup_get_backup_plan/ for full documentation.

Usage

backup_get_backup_plan(
  BackupPlanId,
  VersionId = NULL,
  MaxScheduledRunsPreview = NULL
)

Arguments

BackupPlanId

[required] Uniquely identifies a backup plan.

VersionId

Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version IDs cannot be edited.

MaxScheduledRunsPreview

Number of future scheduled backup runs to preview. When set to 0 (default), no scheduled runs preview is included in the response. Valid range is 0-10.


paws.storage documentation built on May 30, 2026, 9:13 a.m.