View source: R/backup_operations.R
| backup_get_pitr_malware_scan_results | R Documentation |
Returns the malware scan results for a specified point in time within a continuous (point-in-time recovery) backup.
See https://www.paws-r-sdk.com/docs/backup_get_pitr_malware_scan_results/ for full documentation.
backup_get_pitr_malware_scan_results(
RecoveryPointArn,
BackupVaultName,
ScanEndTime,
MalwareScanner
)
RecoveryPointArn |
[required] An ARN that uniquely identifies the target recovery point for scanning; for example, |
BackupVaultName |
[required] The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created. |
ScanEndTime |
[required] The point in time within the continuous backup to examine for malware scan results. |
MalwareScanner |
[required] The scanning engine used for the corresponding scan job. Currently only |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.