View source: R/backup_operations.R
| backup_get_recovery_point_index_details | R Documentation |
This operation returns the metadata and details specific to the backup index associated with the specified recovery point.
See https://www.paws-r-sdk.com/docs/backup_get_recovery_point_index_details/ for full documentation.
backup_get_recovery_point_index_details(BackupVaultName, RecoveryPointArn)
BackupVaultName |
[required] The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created. Accepted characters include lowercase letters, numbers, and hyphens. |
RecoveryPointArn |
[required] An ARN that uniquely identifies a recovery point; for example, |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.