backup_list_backup_access_points: Returns a list of the backup access points in your account...

View source: R/backup_operations.R

backup_list_backup_access_pointsR Documentation

Returns a list of the backup access points in your account and Region

Description

Returns a list of the backup access points in your account and Region.

See https://www.paws-r-sdk.com/docs/backup_list_backup_access_points/ for full documentation.

Usage

backup_list_backup_access_points(MaxResults = NULL, NextToken = NULL)

Arguments

MaxResults

The maximum number of items to be returned.

NextToken

The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.


paws.storage documentation built on Oct. 8, 2026, 9:17 a.m.