backup_list_backup_access_points_by_resource: Returns the backup access points associated with the...

View source: R/backup_operations.R

backup_list_backup_access_points_by_resourceR Documentation

Returns the backup access points associated with the specified resource, such as an Amazon S3 bucket

Description

Returns the backup access points associated with the specified resource, such as an Amazon S3 bucket.

See https://www.paws-r-sdk.com/docs/backup_list_backup_access_points_by_resource/ for full documentation.

Usage

backup_list_backup_access_points_by_resource(
  MaxResults = NULL,
  NextToken = NULL,
  ResourceArn
)

Arguments

MaxResults

The maximum number of items to be returned.

NextToken

The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

ResourceArn

[required] The Amazon Resource Name (ARN) of the resource whose backup access points you want to list.


paws.storage documentation built on Oct. 8, 2026, 9:17 a.m.