Returns a list of existing backup jobs for an authenticated account for the last 30 days. For a longer period of time, consider using these monitoring tools.
See https://paws-r.github.io/docs/backup/list_backup_jobs.html for full documentation.
backup_list_backup_jobs(
NextToken = NULL,
MaxResults = NULL,
ByResourceArn = NULL,
ByState = NULL,
ByBackupVaultName = NULL,
ByCreatedBefore = NULL,
ByCreatedAfter = NULL,
ByResourceType = NULL,
ByAccountId = NULL,
ByCompleteAfter = NULL,
ByCompleteBefore = NULL
)The next item following a partial list of returned items. For example,
if a request is made to return maxResults number of items, NextToken
allows you to return more items in your list starting at the location
pointed to by the next token.
The maximum number of items to be returned.
Returns only backup jobs that match the specified resource Amazon Resource Name (ARN).
Returns only backup jobs that are in the specified state.
Returns only backup jobs that will be stored in the specified backup vault. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created. They consist of lowercase letters, numbers, and hyphens.
Returns only backup jobs that were created before the specified date.
Returns only backup jobs that were created after the specified date.
Returns only backup jobs for the specified resources:
Aurora for Amazon Aurora
DocumentDB for Amazon DocumentDB (with MongoDB compatibility)
DynamoDB for Amazon DynamoDB
EBS for Amazon Elastic Block Store
EC2 for Amazon Elastic Compute Cloud
EFS for Amazon Elastic File System
FSx for Amazon FSx
Neptune for Amazon Neptune
RDS for Amazon Relational Database Service
Storage Gateway for Storage Gateway
S3 for Amazon S3
VirtualMachine for virtual machines
The account ID to list the jobs from. Returns only backup jobs associated with the specified account ID.
If used from an Organizations management account, passing * returns
all jobs across the organization.
Returns only backup jobs completed after a date expressed in Unix format and Coordinated Universal Time (UTC).
Returns only backup jobs completed before a date expressed in Unix format and Coordinated Universal Time (UTC).