Returns metadata about your copy jobs.
See https://paws-r.github.io/docs/backup/list_copy_jobs.html for full documentation.
backup_list_copy_jobs(
NextToken = NULL,
MaxResults = NULL,
ByResourceArn = NULL,
ByState = NULL,
ByCreatedBefore = NULL,
ByCreatedAfter = NULL,
ByResourceType = NULL,
ByDestinationVaultArn = NULL,
ByAccountId = NULL,
ByCompleteBefore = NULL,
ByCompleteAfter = NULL
)The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
The maximum number of items to be returned.
Returns only copy jobs that match the specified resource Amazon Resource Name (ARN).
Returns only copy jobs that are in the specified state.
Returns only copy jobs that were created before the specified date.
Returns only copy jobs that were created after the specified date.
Returns only backup jobs for the specified resources:
Aurora for Amazon Aurora
DocumentDB for Amazon DocumentDB (with MongoDB compatibility)
DynamoDB for Amazon DynamoDB
EBS for Amazon Elastic Block Store
EC2 for Amazon Elastic Compute Cloud
EFS for Amazon Elastic File System
FSx for Amazon FSx
Neptune for Amazon Neptune
RDS for Amazon Relational Database Service
Storage Gateway for Storage Gateway
S3 for Amazon S3
VirtualMachine for virtual machines
An Amazon Resource Name (ARN) that uniquely identifies a source backup
vault to copy from; for example,
arn:aws:backup:us-east-1:123456789012:vault:aBackupVault.
The account ID to list the jobs from. Returns only copy jobs associated with the specified account ID.
Returns only copy jobs completed before a date expressed in Unix format and Coordinated Universal Time (UTC).
Returns only copy jobs completed after a date expressed in Unix format and Coordinated Universal Time (UTC).