View source: R/backup_operations.R
| backup_list_indexed_recovery_points | R Documentation |
This operation returns a list of recovery points that have an associated index, belonging to the specified account.
See https://www.paws-r-sdk.com/docs/backup_list_indexed_recovery_points/ for full documentation.
backup_list_indexed_recovery_points(
NextToken = NULL,
MaxResults = NULL,
SourceResourceArn = NULL,
CreatedBefore = NULL,
CreatedAfter = NULL,
ResourceType = NULL,
IndexStatus = NULL
)
NextToken |
The next item following a partial list of returned recovery points. For example, if a request is made to return |
MaxResults |
The maximum number of resource list items to be returned. |
SourceResourceArn |
A string of the Amazon Resource Name (ARN) that uniquely identifies the source resource. |
CreatedBefore |
Returns only indexed recovery points that were created before the specified date. |
CreatedAfter |
Returns only indexed recovery points that were created after the specified date. |
ResourceType |
Returns a list of indexed recovery points for the specified resource type(s). Accepted values include:
|
IndexStatus |
Include this parameter to filter the returned list by the indicated statuses. Accepted values: A recovery point with an index that has the status of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.