backup_list_restore_access_backup_vaults: Returns a list of restore access backup vaults associated...

View source: R/backup_operations.R

backup_list_restore_access_backup_vaultsR Documentation

Returns a list of restore access backup vaults associated with a specified backup vault

Description

Returns a list of restore access backup vaults associated with a specified backup vault.

See https://www.paws-r-sdk.com/docs/backup_list_restore_access_backup_vaults/ for full documentation.

Usage

backup_list_restore_access_backup_vaults(
  BackupVaultName,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

BackupVaultName

[required] The name of the backup vault for which to list associated restore access backup vaults.

NextToken

The pagination token from a previous request to retrieve the next set of results.

MaxResults

The maximum number of items to return in the response.


paws.storage documentation built on May 30, 2026, 9:13 a.m.