View source: R/backup_operations.R
| backup_list_scan_job_summaries | R Documentation |
This is a request for a summary of scan jobs created or running within the most recent 30 days.
See https://www.paws-r-sdk.com/docs/backup_list_scan_job_summaries/ for full documentation.
backup_list_scan_job_summaries(
AccountId = NULL,
ResourceType = NULL,
MalwareScanner = NULL,
ScanResultStatus = NULL,
State = NULL,
AggregationPeriod = NULL,
MaxResults = NULL,
NextToken = NULL
)
AccountId |
Returns the job count for the specified account. If the request is sent from a member account or an account not part of Amazon Web Services Organizations, jobs within requestor's account will be returned. Root, admin, and delegated administrator accounts can use the value
|
ResourceType |
Returns the job count for the specified resource type. Use request The the value
|
MalwareScanner |
Returns only the scan jobs for the specified malware scanner. Currently the only MalwareScanner is |
ScanResultStatus |
Returns only the scan jobs for the specified scan results. |
State |
Returns only the scan jobs for the specified scanning job state. |
AggregationPeriod |
The period for the returned results.
|
MaxResults |
The maximum number of items to be returned. The value is an integer. Range of accepted values is from 1 to 500. |
NextToken |
The next item following a partial list of returned items. For example, if a request is made to return |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.