View source: R/backup_operations.R
| backup_list_tiering_configurations | R Documentation |
Returns a list of tiering configurations.
See https://www.paws-r-sdk.com/docs/backup_list_tiering_configurations/ for full documentation.
backup_list_tiering_configurations(MaxResults = NULL, NextToken = NULL)
MaxResults |
The maximum number of items to be returned. |
NextToken |
The next item following a partial list of returned items. For example, if a request is made to return |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.