backup_revoke_restore_access_backup_vault: Revokes access to a restore access backup vault, removing the...

View source: R/backup_operations.R

backup_revoke_restore_access_backup_vaultR Documentation

Revokes access to a restore access backup vault, removing the ability to restore from its recovery points and permanently deleting the vault

Description

Revokes access to a restore access backup vault, removing the ability to restore from its recovery points and permanently deleting the vault.

See https://www.paws-r-sdk.com/docs/backup_revoke_restore_access_backup_vault/ for full documentation.

Usage

backup_revoke_restore_access_backup_vault(
  BackupVaultName,
  RestoreAccessBackupVaultArn,
  RequesterComment = NULL
)

Arguments

BackupVaultName

[required] The name of the source backup vault associated with the restore access backup vault to be revoked.

RestoreAccessBackupVaultArn

[required] The ARN of the restore access backup vault to revoke.

RequesterComment

A comment explaining the reason for revoking access to the restore access backup vault.


paws.storage documentation built on May 30, 2026, 9:13 a.m.