Removes a set of key-value pairs from a recovery point, backup plan, or backup vault identified by an Amazon Resource Name (ARN)
backup_untag_resource(ResourceArn, TagKeyList)[required] An ARN that uniquely identifies a resource. The format of the ARN depends on the type of the tagged resource.
[required] A list of keys to identify which key-value tags to remove from a resource.
svc$untag_resource(
ResourceArn = "string",
TagKeyList = list(
"string"
)
)