Updates an existing backup plan identified by its backupPlanId with the input document in JSON format. The new version is uniquely identified by a VersionId.
See https://paws-r.github.io/docs/backup/update_backup_plan.html for full documentation.
backup_update_backup_plan(BackupPlanId, BackupPlan)[required] Uniquely identifies a backup plan.
[required] Specifies the body of a backup plan. Includes a BackupPlanName and one
or more sets of Rules.