backup_update_global_settings: Updates whether the Amazon Web Services account has enabled...

View source: R/backup_operations.R

backup_update_global_settingsR Documentation

Updates whether the Amazon Web Services account has enabled different cross-account management options, including cross-account backup, multi-party approval, and delegated administrator

Description

Updates whether the Amazon Web Services account has enabled different cross-account management options, including cross-account backup, multi-party approval, and delegated administrator. Returns an error if the account is not an Organizations management account. Use the describe_global_settings API to determine the current settings.

See https://www.paws-r-sdk.com/docs/backup_update_global_settings/ for full documentation.

Usage

backup_update_global_settings(GlobalSettings = NULL)

Arguments

GlobalSettings

Inputs can include:

A value for isCrossAccountBackupEnabled. Values can be true or false. Example: ⁠update-global-settings --global-settings isCrossAccountBackupEnabled=false⁠.

A value for Multi-party approval, styled as isMpaEnabled. Values can be true or false. Example: ⁠update-global-settings --global-settings isMpaEnabled=false⁠.

A value for Backup Service-Linked Role creation, styled as isDelegatedAdministratorEnabled. Values can be true or false. Example: ⁠update-global-settings --global-settings isDelegatedAdministratorEnabled=false⁠.


paws.storage documentation built on May 30, 2026, 9:13 a.m.