Returns the current LifecycleConfiguration object for the specified Amazon EFS file system. EFS lifecycle management uses the LifecycleConfiguration object to identify which files to move to the EFS Infrequent Access (IA) storage class. For a file system without a LifecycleConfiguration object, the call returns an empty array in the response.
See https://www.paws-r-sdk.com/docs/efs_describe_lifecycle_configuration/ for full documentation.
efs_describe_lifecycle_configuration(FileSystemId)[required] The ID of the file system whose LifecycleConfiguration object you want
to retrieve (String).