efs_modify_mount_target_security_groups: Modifies the set of security groups in effect for a mount...

View source: R/efs_operations.R

efs_modify_mount_target_security_groupsR Documentation

Modifies the set of security groups in effect for a mount target

Description

Modifies the set of security groups in effect for a mount target.

See https://www.paws-r-sdk.com/docs/efs_modify_mount_target_security_groups/ for full documentation.

Usage

efs_modify_mount_target_security_groups(MountTargetId, SecurityGroups = NULL)

Arguments

MountTargetId

[required] The ID of the mount target whose security groups you want to modify.

SecurityGroups

An array of VPC security group IDs.


paws.storage documentation built on May 30, 2026, 9:13 a.m.