Use this action to manage EFS lifecycle management and EFS Intelligent-Tiering. A LifecycleConfiguration consists of one or more LifecyclePolicy objects that define the following:
See https://www.paws-r-sdk.com/docs/efs_put_lifecycle_configuration/ for full documentation.
efs_put_lifecycle_configuration(FileSystemId, LifecyclePolicies)[required] The ID of the file system for which you are creating the
LifecycleConfiguration object (String).
[required] An array of LifecyclePolicy objects that define the file system's
LifecycleConfiguration object. A LifecycleConfiguration object
informs EFS lifecycle management and EFS Intelligent-Tiering of the
following:
When to move files in the file system from primary storage to the IA storage class.
When to move files that are in IA storage to primary storage.
When using the put-lifecycle-configuration CLI command or the
put_lifecycle_configuration API
action, Amazon EFS requires that each LifecyclePolicy object have only
a single transition. This means that in a request body,
LifecyclePolicies must be structured as an array of LifecyclePolicy
objects, one object for each transition, TransitionToIA,
TransitionToPrimaryStorageClass. See the example requests in the
following section for more information.