fsx_copy_backup: Copies an existing backup within the same Amazon Web Services...

View source: R/fsx_operations.R

fsx_copy_backupR Documentation

Copies an existing backup within the same Amazon Web Services account to another Amazon Web Services Region (cross-Region copy) or within the same Amazon Web Services Region (in-Region copy)

Description

Copies an existing backup within the same Amazon Web Services account to another Amazon Web Services Region (cross-Region copy) or within the same Amazon Web Services Region (in-Region copy). You can have up to five backup copy requests in progress to a single destination Region per account.

See https://www.paws-r-sdk.com/docs/fsx_copy_backup/ for full documentation.

Usage

fsx_copy_backup(
  ClientRequestToken = NULL,
  SourceBackupId,
  SourceRegion = NULL,
  KmsKeyId = NULL,
  CopyTags = NULL,
  Tags = NULL
)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

SourceBackupId

[required] The ID of the source backup. Specifies the ID of the backup that's being copied.

SourceRegion

The source Amazon Web Services Region of the backup. Specifies the Amazon Web Services Region from which the backup is being copied. The source and destination Regions must be in the same Amazon Web Services partition. If you don't specify a Region, SourceRegion defaults to the Region where the request is sent from (in-Region copy).

KmsKeyId

Specifies the ID of the Key Management Service (KMS) key to use for encrypting data on Amazon FSx file systems, as follows:

  • Amazon FSx for Lustre PERSISTENT_1 and PERSISTENT_2 deployment types only.

    SCRATCH_1 and SCRATCH_2 types are encrypted using the Amazon FSx service KMS key for your account.

  • Amazon FSx for NetApp ONTAP

  • Amazon FSx for OpenZFS

  • Amazon FSx for Windows File Server

If a KmsKeyId isn't specified, the Amazon FSx-managed KMS key for your account is used. For more information, see Encrypt in the Key Management Service API Reference.

CopyTags

A Boolean flag indicating whether tags from the source backup should be copied to the backup copy. This value defaults to false.

If you set CopyTags to true and the source backup has existing tags, you can use the Tags parameter to create new tags, provided that the sum of the source backup tags and the new tags doesn't exceed 50. Both sets of tags are merged. If there are tag conflicts (for example, two tags with the same key but different values), the tags created with the Tags parameter take precedence.

Tags

A list of Tag values, with a maximum of 50 elements.


paws.storage documentation built on May 30, 2026, 9:13 a.m.