View source: R/fsx_operations.R
| fsx_copy_snapshot_and_update_volume | R Documentation |
Updates an existing volume by using a snapshot from another Amazon FSx for OpenZFS file system. For more information, see on-demand data replication in the Amazon FSx for OpenZFS User Guide.
See https://www.paws-r-sdk.com/docs/fsx_copy_snapshot_and_update_volume/ for full documentation.
fsx_copy_snapshot_and_update_volume(
ClientRequestToken = NULL,
VolumeId,
SourceSnapshotARN,
CopyStrategy = NULL,
Options = NULL
)
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
VolumeId |
[required] Specifies the ID of the volume that you are copying the snapshot to. |
SourceSnapshotARN |
[required] The Amazon Resource Name (ARN) for a given resource. ARNs uniquely identify Amazon Web Services resources. We require an ARN when you need to specify a resource unambiguously across all of Amazon Web Services. For more information, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. |
CopyStrategy |
Specifies the strategy to use when copying data from a snapshot to the volume.
|
Options |
Confirms that you want to delete data on the destination volume that wasn’t there during the previous snapshot replication. Your replication will fail if you don’t include an option for a specific type of data and that data is on your destination. For example, if you don’t include
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.