fsx_create_and_attach_s3_access_point: Creates an S3 access point and attaches it to an Amazon FSx...

View source: R/fsx_operations.R

fsx_create_and_attach_s3_access_pointR Documentation

Creates an S3 access point and attaches it to an Amazon FSx volume

Description

Creates an S3 access point and attaches it to an Amazon FSx volume. For FSx for OpenZFS file systems, the volume must be hosted on a high-availability file system, either Single-AZ or Multi-AZ. For more information, see Accessing your data using Amazon S3 access points. in the Amazon FSx for OpenZFS User Guide.

See https://www.paws-r-sdk.com/docs/fsx_create_and_attach_s3_access_point/ for full documentation.

Usage

fsx_create_and_attach_s3_access_point(
  ClientRequestToken = NULL,
  Name,
  Type,
  OpenZFSConfiguration = NULL,
  OntapConfiguration = NULL,
  S3AccessPoint = NULL
)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

Name

[required] The name you want to assign to this S3 access point.

Type

[required] The type of S3 access point you want to create. Only OpenZFS is supported.

OpenZFSConfiguration

Specifies the configuration to use when creating and attaching an S3 access point to an FSx for OpenZFS volume.

OntapConfiguration

Specifies the FSx for ONTAP volume that the S3 access point will be attached to, and the file system user identity.

S3AccessPoint

Specifies the virtual private cloud (VPC) configuration if you're creating an access point that is restricted to a VPC. For more information, see Creating access points restricted to a virtual private cloud.


paws.storage documentation built on May 30, 2026, 9:13 a.m.