View source: R/fsx_operations.R
| fsx_create_data_repository_task | R Documentation |
Creates an Amazon FSx for Lustre data repository task. A create_data_repository_task operation will fail if a data repository is not linked to the FSx file system.
See https://www.paws-r-sdk.com/docs/fsx_create_data_repository_task/ for full documentation.
fsx_create_data_repository_task(
Type,
Paths = NULL,
FileSystemId,
Report,
ClientRequestToken = NULL,
Tags = NULL,
CapacityToRelease = NULL,
ReleaseConfiguration = NULL
)
Type |
[required] Specifies the type of data repository task to create.
|
Paths |
A list of paths for the data repository task to use when the task is processed. If a path that you provide isn't valid, the task fails. If you don't provide paths, the default behavior is to export all files to S3 (for export tasks), import all files from S3 (for import tasks), or release all exported files that meet the last accessed time criteria (for release tasks).
|
FileSystemId |
[required] The globally unique ID of the file system, assigned by Amazon FSx. |
Report |
[required] Defines whether or not Amazon FSx provides a CompletionReport once the task has completed. A CompletionReport provides a detailed report on the files that Amazon FSx processed that meet the criteria specified by the |
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
Tags |
A list of |
CapacityToRelease |
Specifies the amount of data to release, in GiB, by an Amazon File Cache |
ReleaseConfiguration |
The configuration that specifies the last accessed time criteria for files that will be released from an Amazon FSx for Lustre file system. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.