View source: R/fsx_operations.R
| fsx_create_file_system_from_backup | R Documentation |
Creates a new Amazon FSx for Lustre, Amazon FSx for Windows File Server, or Amazon FSx for OpenZFS file system from an existing Amazon FSx backup.
See https://www.paws-r-sdk.com/docs/fsx_create_file_system_from_backup/ for full documentation.
fsx_create_file_system_from_backup(
BackupId,
ClientRequestToken = NULL,
SubnetIds,
SecurityGroupIds = NULL,
Tags = NULL,
WindowsConfiguration = NULL,
LustreConfiguration = NULL,
StorageType = NULL,
KmsKeyId = NULL,
FileSystemTypeVersion = NULL,
OpenZFSConfiguration = NULL,
StorageCapacity = NULL,
NetworkType = NULL
)
BackupId |
[required] The ID of the source backup. Specifies the backup that you are copying. |
ClientRequestToken |
A string of up to 63 ASCII characters that Amazon FSx uses to ensure idempotent creation. This string is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
SubnetIds |
[required] Specifies the IDs of the subnets that the file system will be accessible from. For Windows Windows |
SecurityGroupIds |
A list of IDs for the security groups that apply to the specified network interfaces created for file system access. These security groups apply to all network interfaces. This value isn't returned in later |
Tags |
The tags to be applied to the file system at file system creation. The key value of the |
WindowsConfiguration |
The configuration for this Microsoft Windows file system. |
LustreConfiguration |
The Lustre configuration for the file system being created. The following parameters are not supported for file systems with a data repository association created with .
|
StorageType |
Sets the storage type for the Windows, OpenZFS, or Lustre file system that you're creating from a backup. Valid values are
The default value is HDD and SSD storage types have different minimum storage capacity requirements. A restored file system's storage capacity is tied to the file system that was backed up. You can create a file system that uses HDD storage from a backup of a file system that used SSD storage if the original SSD file system had a storage capacity of at least 2000 GiB. |
KmsKeyId |
Specifies the ID of the Key Management Service (KMS) key to use for encrypting data on Amazon FSx file systems, as follows:
If a |
FileSystemTypeVersion |
Sets the version for the Amazon FSx for Lustre file system that you're creating from a backup. Valid values are You can enter a Lustre version that is newer than the backup's |
OpenZFSConfiguration |
The OpenZFS configuration for the file system that's being created. |
StorageCapacity |
Sets the storage capacity of the OpenZFS file system that you're creating from a backup, in gibibytes (GiB). Valid values are from 64 GiB up to 524,288 GiB (512 TiB). However, the value that you specify must be equal to or greater than the backup's storage capacity value. If you don't use the If used to create a file system other than OpenZFS, you must provide a value that matches the backup's |
NetworkType |
Sets the network type for the Amazon FSx for OpenZFS file system that you're creating from a backup. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.