fsx_create_snapshot: Creates a snapshot of an existing Amazon FSx for OpenZFS...

View source: R/fsx_operations.R

fsx_create_snapshotR Documentation

Creates a snapshot of an existing Amazon FSx for OpenZFS volume

Description

Creates a snapshot of an existing Amazon FSx for OpenZFS volume. With snapshots, you can easily undo file changes and compare file versions by restoring the volume to a previous version.

See https://www.paws-r-sdk.com/docs/fsx_create_snapshot/ for full documentation.

Usage

fsx_create_snapshot(ClientRequestToken = NULL, Name, VolumeId, Tags = NULL)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

Name

[required] The name of the snapshot.

VolumeId

[required] The ID of the volume that you are taking a snapshot of.

Tags

A list of Tag values, with a maximum of 50 elements.


paws.storage documentation built on May 30, 2026, 9:13 a.m.