View source: R/fsx_operations.R
| fsx_create_storage_virtual_machine | R Documentation |
Creates a storage virtual machine (SVM) for an Amazon FSx for ONTAP file system.
See https://www.paws-r-sdk.com/docs/fsx_create_storage_virtual_machine/ for full documentation.
fsx_create_storage_virtual_machine(
ActiveDirectoryConfiguration = NULL,
ClientRequestToken = NULL,
FileSystemId,
Name,
SvmAdminPassword = NULL,
Tags = NULL,
RootVolumeSecurityStyle = NULL
)
ActiveDirectoryConfiguration |
Describes the self-managed Microsoft Active Directory to which you want to join the SVM. Joining an Active Directory provides user authentication and access control for SMB clients, including Microsoft Windows and macOS clients accessing the file system. |
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
FileSystemId |
[required] The globally unique ID of the file system, assigned by Amazon FSx. |
Name |
[required] The name of the SVM. |
SvmAdminPassword |
The password to use when managing the SVM using the NetApp ONTAP CLI or REST API. If you do not specify a password, you can still use the file system's |
Tags |
A list of |
RootVolumeSecurityStyle |
The security style of the root volume of the SVM. Specify one of the following values:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.