fsx_create_volume: Creates an FSx for ONTAP or Amazon FSx for OpenZFS storage...

View source: R/fsx_operations.R

fsx_create_volumeR Documentation

Creates an FSx for ONTAP or Amazon FSx for OpenZFS storage volume

Description

Creates an FSx for ONTAP or Amazon FSx for OpenZFS storage volume.

See https://www.paws-r-sdk.com/docs/fsx_create_volume/ for full documentation.

Usage

fsx_create_volume(
  ClientRequestToken = NULL,
  VolumeType,
  Name,
  OntapConfiguration = NULL,
  Tags = NULL,
  OpenZFSConfiguration = NULL
)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

VolumeType

[required] Specifies the type of volume to create; ONTAP and OPENZFS are the only valid volume types.

Name

[required] Specifies the name of the volume that you're creating.

OntapConfiguration

Specifies the configuration to use when creating the ONTAP volume.

Tags

A list of Tag values, with a maximum of 50 elements.

OpenZFSConfiguration

Specifies the configuration to use when creating the OpenZFS volume.


paws.storage documentation built on May 30, 2026, 9:13 a.m.