fsx_create_volume_from_backup: Creates a new Amazon FSx for NetApp ONTAP volume from an...

View source: R/fsx_operations.R

fsx_create_volume_from_backupR Documentation

Creates a new Amazon FSx for NetApp ONTAP volume from an existing Amazon FSx volume backup

Description

Creates a new Amazon FSx for NetApp ONTAP volume from an existing Amazon FSx volume backup.

See https://www.paws-r-sdk.com/docs/fsx_create_volume_from_backup/ for full documentation.

Usage

fsx_create_volume_from_backup(
  BackupId,
  ClientRequestToken = NULL,
  Name,
  OntapConfiguration = NULL,
  Tags = NULL
)

Arguments

BackupId

[required] The ID of the source backup. Specifies the backup that you are copying.

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

Name

[required] The name of the new volume you're creating.

OntapConfiguration

Specifies the configuration of the ONTAP volume that you are creating.

Tags

A list of Tag values, with a maximum of 50 elements.


paws.storage documentation built on May 30, 2026, 9:13 a.m.