fsx_delete_file_cache: Deletes an Amazon File Cache resource

View source: R/fsx_operations.R

fsx_delete_file_cacheR Documentation

Deletes an Amazon File Cache resource

Description

Deletes an Amazon File Cache resource. After deletion, the cache no longer exists, and its data is gone.

See https://www.paws-r-sdk.com/docs/fsx_delete_file_cache/ for full documentation.

Usage

fsx_delete_file_cache(FileCacheId, ClientRequestToken = NULL)

Arguments

FileCacheId

[required] The ID of the cache that's being deleted.

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.


paws.storage documentation built on May 30, 2026, 9:13 a.m.