fsx_delete_snapshot: Deletes an Amazon FSx for OpenZFS snapshot

View source: R/fsx_operations.R

fsx_delete_snapshotR Documentation

Deletes an Amazon FSx for OpenZFS snapshot

Description

Deletes an Amazon FSx for OpenZFS snapshot. After deletion, the snapshot no longer exists, and its data is gone. Deleting a snapshot doesn't affect snapshots stored in a file system backup.

See https://www.paws-r-sdk.com/docs/fsx_delete_snapshot/ for full documentation.

Usage

fsx_delete_snapshot(ClientRequestToken = NULL, SnapshotId)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

SnapshotId

[required] The ID of the snapshot that you want to delete.


paws.storage documentation built on May 30, 2026, 9:13 a.m.