fsx_delete_storage_virtual_machine: Deletes an existing Amazon FSx for ONTAP storage virtual...

View source: R/fsx_operations.R

fsx_delete_storage_virtual_machineR Documentation

Deletes an existing Amazon FSx for ONTAP storage virtual machine (SVM)

Description

Deletes an existing Amazon FSx for ONTAP storage virtual machine (SVM). Prior to deleting an SVM, you must delete all non-root volumes in the SVM, otherwise the operation will fail.

See https://www.paws-r-sdk.com/docs/fsx_delete_storage_virtual_machine/ for full documentation.

Usage

fsx_delete_storage_virtual_machine(
  ClientRequestToken = NULL,
  StorageVirtualMachineId
)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

StorageVirtualMachineId

[required] The ID of the SVM that you want to delete.


paws.storage documentation built on May 30, 2026, 9:13 a.m.