View source: R/fsx_operations.R
| fsx_describe_data_repository_tasks | R Documentation |
Returns the description of specific Amazon FSx for Lustre or Amazon File Cache data repository tasks, if one or more TaskIds values are provided in the request, or if filters are used in the request. You can use filters to narrow the response to include just tasks for specific file systems or caches, or tasks in a specific lifecycle state. Otherwise, it returns all data repository tasks owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.
See https://www.paws-r-sdk.com/docs/fsx_describe_data_repository_tasks/ for full documentation.
fsx_describe_data_repository_tasks(
TaskIds = NULL,
Filters = NULL,
MaxResults = NULL,
NextToken = NULL
)
TaskIds |
(Optional) IDs of the tasks whose descriptions you want to retrieve (String). |
Filters |
(Optional) You can use filters to narrow the |
MaxResults |
The maximum number of resources to return in the response. This value must be an integer greater than zero. |
NextToken |
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.