View source: R/fsx_operations.R
| fsx_describe_file_system_aliases | R Documentation |
Returns the DNS aliases that are associated with the specified Amazon FSx for Windows File Server file system. A history of all DNS aliases that have been associated with and disassociated from the file system is available in the list of AdministrativeAction provided in the describe_file_systems operation response.
See https://www.paws-r-sdk.com/docs/fsx_describe_file_system_aliases/ for full documentation.
fsx_describe_file_system_aliases(
ClientRequestToken = NULL,
FileSystemId,
MaxResults = NULL,
NextToken = NULL
)
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
FileSystemId |
[required] The ID of the file system to return the associated DNS aliases for (String). |
MaxResults |
Maximum number of DNS aliases to return in the response (integer). This parameter value must be greater than 0. The number of items that Amazon FSx returns is the minimum of the |
NextToken |
Opaque pagination token returned from a previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.