fsx_describe_snapshots: Returns the description of specific Amazon FSx for OpenZFS...

View source: R/fsx_operations.R

fsx_describe_snapshotsR Documentation

Returns the description of specific Amazon FSx for OpenZFS snapshots, if a SnapshotIds value is provided

Description

Returns the description of specific Amazon FSx for OpenZFS snapshots, if a SnapshotIds value is provided. Otherwise, this operation returns all snapshots owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.

See https://www.paws-r-sdk.com/docs/fsx_describe_snapshots/ for full documentation.

Usage

fsx_describe_snapshots(
  SnapshotIds = NULL,
  Filters = NULL,
  MaxResults = NULL,
  NextToken = NULL,
  IncludeShared = NULL
)

Arguments

SnapshotIds

The IDs of the snapshots that you want to retrieve. This parameter value overrides any filters. If any IDs aren't found, a SnapshotNotFound error occurs.

Filters

The filters structure. The supported names are file-system-id or volume-id.

MaxResults

The maximum number of resources to return in the response. This value must be an integer greater than zero.

NextToken

(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.

IncludeShared

Set to false (default) if you want to only see the snapshots owned by your Amazon Web Services account. Set to true if you want to see the snapshots in your account and the ones shared with you from another account.


paws.storage documentation built on May 30, 2026, 9:13 a.m.