fsx_describe_volumes: Describes one or more Amazon FSx for NetApp ONTAP or Amazon...

View source: R/fsx_operations.R

fsx_describe_volumesR Documentation

Describes one or more Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volumes

Description

Describes one or more Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volumes.

See https://www.paws-r-sdk.com/docs/fsx_describe_volumes/ for full documentation.

Usage

fsx_describe_volumes(
  VolumeIds = NULL,
  Filters = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

VolumeIds

The IDs of the volumes whose descriptions you want to retrieve.

Filters

Enter a filter Name and Values pair to view a select set of volumes.

MaxResults

The maximum number of resources to return in the response. This value must be an integer greater than zero.

NextToken

(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.


paws.storage documentation built on May 30, 2026, 9:13 a.m.