fsx_detach_and_delete_s3_access_point: Detaches an S3 access point from an Amazon FSx volume and...

View source: R/fsx_operations.R

fsx_detach_and_delete_s3_access_pointR Documentation

Detaches an S3 access point from an Amazon FSx volume and deletes the S3 access point

Description

Detaches an S3 access point from an Amazon FSx volume and deletes the S3 access point.

See https://www.paws-r-sdk.com/docs/fsx_detach_and_delete_s3_access_point/ for full documentation.

Usage

fsx_detach_and_delete_s3_access_point(ClientRequestToken = NULL, Name)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

Name

[required] The name of the S3 access point attachment that you want to delete.


paws.storage documentation built on May 30, 2026, 9:13 a.m.