fsx_disassociate_file_system_aliases: Use this action to disassociate, or remove, one or more...

View source: R/fsx_operations.R

fsx_disassociate_file_system_aliasesR Documentation

Use this action to disassociate, or remove, one or more Domain Name Service (DNS) aliases from an Amazon FSx for Windows File Server file system

Description

Use this action to disassociate, or remove, one or more Domain Name Service (DNS) aliases from an Amazon FSx for Windows File Server file system. If you attempt to disassociate a DNS alias that is not associated with the file system, Amazon FSx responds with an HTTP status code 400 (Bad Request). For more information, see Working with DNS Aliases.

See https://www.paws-r-sdk.com/docs/fsx_disassociate_file_system_aliases/ for full documentation.

Usage

fsx_disassociate_file_system_aliases(
  ClientRequestToken = NULL,
  FileSystemId,
  Aliases
)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

FileSystemId

[required] Specifies the file system from which to disassociate the DNS aliases.

Aliases

[required] An array of one or more DNS alias names to disassociate, or remove, from the file system.


paws.storage documentation built on May 30, 2026, 9:13 a.m.