fsx_update_file_cache: Updates the configuration of an existing Amazon File Cache...

View source: R/fsx_operations.R

fsx_update_file_cacheR Documentation

Updates the configuration of an existing Amazon File Cache resource

Description

Updates the configuration of an existing Amazon File Cache resource. You can update multiple properties in a single request.

See https://www.paws-r-sdk.com/docs/fsx_update_file_cache/ for full documentation.

Usage

fsx_update_file_cache(
  FileCacheId,
  ClientRequestToken = NULL,
  LustreConfiguration = NULL
)

Arguments

FileCacheId

[required] The ID of the cache that you are updating.

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

LustreConfiguration

The configuration updates for an Amazon File Cache resource.


paws.storage documentation built on May 30, 2026, 9:13 a.m.