fsx_update_shared_vpc_configuration: Configures whether participant accounts in your organization...

View source: R/fsx_operations.R

fsx_update_shared_vpc_configurationR Documentation

Configures whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner

Description

Configures whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner. For more information, see the Amazon FSx for NetApp ONTAP User Guide.

See https://www.paws-r-sdk.com/docs/fsx_update_shared_vpc_configuration/ for full documentation.

Usage

fsx_update_shared_vpc_configuration(
  EnableFsxRouteTableUpdatesFromParticipantAccounts = NULL,
  ClientRequestToken = NULL
)

Arguments

EnableFsxRouteTableUpdatesFromParticipantAccounts

Specifies whether participant accounts can create FSx for ONTAP Multi-AZ file systems in shared subnets. Set to true to enable or false to disable.

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.


paws.storage documentation built on May 30, 2026, 9:13 a.m.