fsx_update_snapshot: Updates the name of an Amazon FSx for OpenZFS snapshot

View source: R/fsx_operations.R

fsx_update_snapshotR Documentation

Updates the name of an Amazon FSx for OpenZFS snapshot

Description

Updates the name of an Amazon FSx for OpenZFS snapshot.

See https://www.paws-r-sdk.com/docs/fsx_update_snapshot/ for full documentation.

Usage

fsx_update_snapshot(ClientRequestToken = NULL, Name, SnapshotId)

Arguments

ClientRequestToken

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

Name

[required] The name of the snapshot to update.

SnapshotId

[required] The ID of the snapshot that you want to update, in the format ⁠fsvolsnap-0123456789abcdef0⁠.


paws.storage documentation built on May 30, 2026, 9:13 a.m.