glacier_abort_multipart_upload: This operation aborts a multipart upload identified by the...

View source: R/glacier_operations.R

glacier_abort_multipart_uploadR Documentation

This operation aborts a multipart upload identified by the upload ID

Description

This operation aborts a multipart upload identified by the upload ID.

See https://www.paws-r-sdk.com/docs/glacier_abort_multipart_upload/ for full documentation.

Usage

glacier_abort_multipart_upload(accountId, vaultName, uploadId)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.

uploadId

[required] The upload ID of the multipart upload to delete.


paws.storage documentation built on May 30, 2026, 9:13 a.m.