glacier_delete_archive: This operation deletes an archive from a vault

View source: R/glacier_operations.R

glacier_delete_archiveR Documentation

This operation deletes an archive from a vault

Description

This operation deletes an archive from a vault. Subsequent requests to initiate a retrieval of this archive will fail. Archive retrievals that are in progress for this archive ID may or may not succeed according to the following scenarios:

See https://www.paws-r-sdk.com/docs/glacier_delete_archive/ for full documentation.

Usage

glacier_delete_archive(accountId, vaultName, archiveId)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.

archiveId

[required] The ID of the archive to delete.


paws.storage documentation built on May 30, 2026, 9:13 a.m.