glacier_delete_vault_access_policy: This operation deletes the access policy associated with the...

View source: R/glacier_operations.R

glacier_delete_vault_access_policyR Documentation

This operation deletes the access policy associated with the specified vault

Description

This operation deletes the access policy associated with the specified vault. The operation is eventually consistent; that is, it might take some time for Amazon Glacier to completely remove the access policy, and you might still see the effect of the policy for a short time after you send the delete request.

See https://www.paws-r-sdk.com/docs/glacier_delete_vault_access_policy/ for full documentation.

Usage

glacier_delete_vault_access_policy(accountId, vaultName)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.


paws.storage documentation built on May 30, 2026, 9:13 a.m.