glacier_describe_job: This operation returns information about a job you previously...

View source: R/glacier_operations.R

glacier_describe_jobR Documentation

This operation returns information about a job you previously initiated, including the job initiation date, the user who initiated the job, the job status code/message and the Amazon SNS topic to notify after Amazon Glacier (Glacier) completes the job

Description

This operation returns information about a job you previously initiated, including the job initiation date, the user who initiated the job, the job status code/message and the Amazon SNS topic to notify after Amazon Glacier (Glacier) completes the job. For more information about initiating a job, see initiate_job.

See https://www.paws-r-sdk.com/docs/glacier_describe_job/ for full documentation.

Usage

glacier_describe_job(accountId, vaultName, jobId)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.

jobId

[required] The ID of the job to describe.


paws.storage documentation built on May 30, 2026, 9:13 a.m.