glacier_get_vault_access_policy: This operation retrieves the access-policy subresource set on...

View source: R/glacier_operations.R

glacier_get_vault_access_policyR Documentation

This operation retrieves the access-policy subresource set on the vault; for more information on setting this subresource, see Set Vault Access Policy (PUT access-policy)

Description

This operation retrieves the access-policy subresource set on the vault; for more information on setting this subresource, see Set Vault Access Policy (PUT access-policy). If there is no access policy set on the vault, the operation returns a ⁠404 Not found⁠ error. For more information about vault access policies, see Amazon Glacier Access Control with Vault Access Policies.

See https://www.paws-r-sdk.com/docs/glacier_get_vault_access_policy/ for full documentation.

Usage

glacier_get_vault_access_policy(accountId, vaultName)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.


paws.storage documentation built on May 30, 2026, 9:13 a.m.