glacier_get_vault_lock: This operation retrieves the following attributes from the...

View source: R/glacier_operations.R

glacier_get_vault_lockR Documentation

This operation retrieves the following attributes from the lock-policy subresource set on the specified vault:

Description

This operation retrieves the following attributes from the lock-policy subresource set on the specified vault:

See https://www.paws-r-sdk.com/docs/glacier_get_vault_lock/ for full documentation.

Usage

glacier_get_vault_lock(accountId, vaultName)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.


paws.storage documentation built on May 30, 2026, 9:13 a.m.