glacier_initiate_job: This operation initiates a job of the specified type, which...

View source: R/glacier_operations.R

glacier_initiate_jobR Documentation

This operation initiates a job of the specified type, which can be a select, an archival retrieval, or a vault retrieval

Description

This operation initiates a job of the specified type, which can be a select, an archival retrieval, or a vault retrieval. For more information about using this operation, see the documentation for the underlying REST API Initiate a Job.

See https://www.paws-r-sdk.com/docs/glacier_initiate_job/ for full documentation.

Usage

glacier_initiate_job(accountId, vaultName, jobParameters = NULL)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.

jobParameters

Provides options for specifying job information.


paws.storage documentation built on May 30, 2026, 9:13 a.m.