glacier_initiate_multipart_upload: This operation initiates a multipart upload

View source: R/glacier_operations.R

glacier_initiate_multipart_uploadR Documentation

This operation initiates a multipart upload

Description

This operation initiates a multipart upload. Amazon Glacier creates a multipart upload resource and returns its ID in the response. The multipart upload ID is used in subsequent requests to upload parts of an archive (see upload_multipart_part).

See https://www.paws-r-sdk.com/docs/glacier_initiate_multipart_upload/ for full documentation.

Usage

glacier_initiate_multipart_upload(
  accountId,
  vaultName,
  archiveDescription = NULL,
  partSize = NULL
)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.

archiveDescription

The archive description that you are uploading in parts.

The part size must be a megabyte (1024 KB) multiplied by a power of 2, for example 1048576 (1 MB), 2097152 (2 MB), 4194304 (4 MB), 8388608 (8 MB), and so on. The minimum allowable part size is 1 MB, and the maximum is 4 GB (4096 MB).

partSize

The size of each part except the last, in bytes. The last part can be smaller than this part size.


paws.storage documentation built on May 30, 2026, 9:13 a.m.