glacier_set_vault_notifications: This operation configures notifications that will be sent...

View source: R/glacier_operations.R

glacier_set_vault_notificationsR Documentation

This operation configures notifications that will be sent when specific events happen to a vault

Description

This operation configures notifications that will be sent when specific events happen to a vault. By default, you don't get any notifications.

See https://www.paws-r-sdk.com/docs/glacier_set_vault_notifications/ for full documentation.

Usage

glacier_set_vault_notifications(
  accountId,
  vaultName,
  vaultNotificationConfig = NULL
)

Arguments

accountId

[required] The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

vaultName

[required] The name of the vault.

vaultNotificationConfig

Provides options for specifying notification configuration.


paws.storage documentation built on May 30, 2026, 9:13 a.m.