omics: Amazon Omics

View source: R/omics_service.R

omicsR Documentation

Amazon Omics

Description

Amazon Web Services HealthOmics is a service that helps users such as bioinformaticians, researchers, and scientists to store, query, analyze, and generate insights from genomics and other biological data. It simplifies and accelerates the process of storing and analyzing genomic information for Amazon Web Services.

For an introduction to the service, see What is Amazon Web Services HealthOmics? in the Amazon Web Services HealthOmics User Guide.

Usage

omics(config = list(), credentials = list(), endpoint = NULL, region = NULL)

Arguments

config

Optional configuration of credentials, endpoint, and/or region.

  • credentials:

    • creds:

      • access_key_id: AWS access key ID

      • secret_access_key: AWS secret access key

      • session_token: AWS temporary session token

    • profile: The name of a profile to use. If not given, then the default profile is used.

    • anonymous: Set anonymous credentials.

  • endpoint: The complete URL to use for the constructed client.

  • region: The AWS Region used in instantiating the client.

  • close_connection: Immediately close all HTTP connections.

  • timeout: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.

  • s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e. ⁠http://s3.amazonaws.com/BUCKET/KEY⁠.

  • sts_regional_endpoint: Set sts regional endpoint resolver to regional or legacy https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html

credentials

Optional credentials shorthand for the config parameter

  • creds:

    • access_key_id: AWS access key ID

    • secret_access_key: AWS secret access key

    • session_token: AWS temporary session token

  • profile: The name of a profile to use. If not given, then the default profile is used.

  • anonymous: Set anonymous credentials.

endpoint

Optional shorthand for complete URL to use for the constructed client.

region

Optional shorthand for AWS Region used in instantiating the client.

Value

A client for the service. You can call the service's operations using syntax like svc$operation(...), where svc is the name you've assigned to the client. The available operations are listed in the Operations section.

Service syntax

svc <- omics(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string",
      anonymous = "logical"
    ),
    endpoint = "string",
    region = "string",
    close_connection = "logical",
    timeout = "numeric",
    s3_force_path_style = "logical",
    sts_regional_endpoint = "string"
  ),
  credentials = list(
    creds = list(
      access_key_id = "string",
      secret_access_key = "string",
      session_token = "string"
    ),
    profile = "string",
    anonymous = "logical"
  ),
  endpoint = "string",
  region = "string"
)

Operations

abort_multipart_read_set_upload Stops a multipart read set upload into a sequence store and returns a response with no body if the operation is successful
accept_share Accept a resource share request
batch_delete_read_set Deletes one or more read sets
cancel_annotation_import_job Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
cancel_run Cancels a run using its ID and returns a response with no body if the operation is successful
cancel_run_batch Cancels all runs within a specified batch
cancel_variant_import_job Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
complete_multipart_read_set_upload Completes a multipart read set upload into a sequence store after you have initiated the upload process with CreateMultipartReadSetUpload and uploaded all read set parts using UploadReadSetPart
create_annotation_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
create_annotation_store_version Creates a new version of an annotation store
create_configuration Create a new configuration
create_multipart_read_set_upload Initiates a multipart read set upload for uploading partitioned source files into a sequence store
create_reference_store Creates a reference store and returns metadata in JSON format
create_run_cache Creates a run cache to store and reference task outputs from completed private runs
create_run_group Creates a run group to limit the compute resources for the runs that are added to the group
create_sequence_store Creates a sequence store and returns its metadata
create_share Creates a cross-account shared resource
create_variant_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
create_workflow Creates a private workflow
create_workflow_version Creates a new workflow version for the workflow that you specify with the workflowId parameter
delete_annotation_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
delete_annotation_store_versions Deletes one or multiple versions of an annotation store
delete_batch Deletes a run batch resource and its associated metadata
delete_configuration Delete an existing configuration
delete_reference Deletes a reference genome and returns a response with no body if the operation is successful
delete_reference_store Deletes a reference store and returns a response with no body if the operation is successful
delete_run Deletes a run and returns a response with no body if the operation is successful
delete_run_batch Deletes the individual workflow runs within a batch
delete_run_cache Deletes a run cache and returns a response with no body if the operation is successful
delete_run_group Deletes a run group and returns a response with no body if the operation is successful
delete_s3_access_policy Deletes an access policy for the specified store
delete_sequence_store Deletes a sequence store and returns a response with no body if the operation is successful
delete_share Deletes a resource share
delete_variant_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
delete_workflow Deletes a workflow by specifying its ID
delete_workflow_version Deletes a workflow version
get_annotation_import_job Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
get_annotation_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
get_annotation_store_version Retrieves the metadata for an annotation store version
get_batch Retrieves details and current status for a specific run batch, including submission progress and run execution counts
get_configuration Retrieve configuration details for specified name
get_read_set Retrieves detailed information from parts of a read set and returns the read set in the same format that it was uploaded
get_read_set_activation_job Returns detailed information about the status of a read set activation job in JSON format
get_read_set_export_job Retrieves status information about a read set export job and returns the data in JSON format
get_read_set_import_job Gets detailed and status information about a read set import job and returns the data in JSON format
get_read_set_metadata Retrieves the metadata for a read set from a sequence store in JSON format
get_reference Downloads parts of data from a reference genome and returns the reference file in the same format that it was uploaded
get_reference_import_job Monitors the status of a reference import job
get_reference_metadata Retrieves metadata for a reference genome
get_reference_store Gets information about a reference store
get_run Gets detailed information about a specific run using its ID
get_run_cache Retrieves detailed information about the specified run cache using its ID
get_run_group Gets information about a run group and returns its metadata
get_run_task Gets detailed information about a run task using its ID
get_s3_access_policy Retrieves details about an access policy on a given store
get_sequence_store Retrieves metadata for a sequence store using its ID and returns it in JSON format
get_share Retrieves the metadata for the specified resource share
get_variant_import_job Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
get_variant_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
get_workflow Gets all information about a workflow using its ID
get_workflow_version Gets information about a workflow version
list_annotation_import_jobs Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
list_annotation_stores Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
list_annotation_store_versions Lists the versions of an annotation store
list_batch Returns a list of run batches in your account, with optional filtering by status, name, or run group
list_configurations List all configurations for the account
list_multipart_read_set_uploads Lists in-progress multipart read set uploads for a sequence store and returns it in a JSON formatted output
list_read_set_activation_jobs Retrieves a list of read set activation jobs and returns the metadata in a JSON formatted output
list_read_set_export_jobs Retrieves a list of read set export jobs in a JSON formatted response
list_read_set_import_jobs Retrieves a list of read set import jobs and returns the data in JSON format
list_read_sets Retrieves a list of read sets from a sequence store ID and returns the metadata in JSON format
list_read_set_upload_parts Lists all parts in a multipart read set upload for a sequence store and returns the metadata in a JSON formatted output
list_reference_import_jobs Retrieves the metadata of one or more reference import jobs for a reference store
list_references Retrieves the metadata of one or more reference genomes in a reference store
list_reference_stores Retrieves a list of reference stores linked to your account and returns their metadata in JSON format
list_run_caches Retrieves a list of your run caches and the metadata for each cache
list_run_groups Retrieves a list of all run groups and returns the metadata for each run group
list_runs Retrieves a list of runs and returns each run's metadata and status
list_runs_in_batch Returns a paginated list of individual workflow runs within a specific batch
list_run_tasks Returns a list of tasks and status information within their specified run
list_sequence_stores Retrieves a list of sequence stores and returns each sequence store's metadata
list_shares Retrieves the resource shares associated with an account
list_tags_for_resource Retrieves a list of tags for a resource
list_variant_import_jobs Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
list_variant_stores Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
list_workflows Retrieves a list of existing workflows
list_workflow_versions Lists the workflow versions for the specified workflow
put_s3_access_policy Adds an access policy to the specified store
start_annotation_import_job Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
start_read_set_activation_job Activates an archived read set and returns its metadata in a JSON formatted output
start_read_set_export_job Starts a read set export job
start_read_set_import_job Imports a read set from the sequence store
start_reference_import_job Imports a reference genome from Amazon S3 into a specified reference store
start_run Starts a new run and returns details about the run, or duplicates an existing run
start_run_batch Starts a batch of workflow runs
start_variant_import_job Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
tag_resource Tags a resource
untag_resource Removes tags from a resource
update_annotation_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
update_annotation_store_version Updates the description of an annotation store version
update_run_cache Updates a run cache using its ID and returns a response with no body if the operation is successful
update_run_group Updates the settings of a run group and returns a response with no body if the operation is successful
update_sequence_store Update one or more parameters for the sequence store
update_variant_store Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers
update_workflow Updates information about a workflow
update_workflow_version Updates information about the workflow version
upload_read_set_part Uploads a specific part of a read set into a sequence store

Examples

## Not run: 
svc <- omics()
svc$abort_multipart_read_set_upload(
  Foo = 123
)

## End(Not run)


paws.storage documentation built on May 30, 2026, 9:13 a.m.