omics_abort_multipart_read_set_upload: Stops a multipart read set upload into a sequence store and...

View source: R/omics_operations.R

omics_abort_multipart_read_set_uploadR Documentation

Stops a multipart read set upload into a sequence store and returns a response with no body if the operation is successful

Description

Stops a multipart read set upload into a sequence store and returns a response with no body if the operation is successful. To confirm that a multipart read set upload has been stopped, use the list_multipart_read_set_uploads API operation to view all active multipart read set uploads.

See https://www.paws-r-sdk.com/docs/omics_abort_multipart_read_set_upload/ for full documentation.

Usage

omics_abort_multipart_read_set_upload(sequenceStoreId, uploadId)

Arguments

sequenceStoreId

[required] The sequence store ID for the store involved in the multipart upload.

uploadId

[required] The ID for the multipart upload.


paws.storage documentation built on May 30, 2026, 9:13 a.m.