omics_batch_delete_read_set: Deletes one or more read sets

View source: R/omics_operations.R

omics_batch_delete_read_setR Documentation

Deletes one or more read sets

Description

Deletes one or more read sets. If the operation is successful, it returns a response with no body. If there is an error with deleting one of the read sets, the operation returns an error list. If the operation successfully deletes only a subset of files, it will return an error list for the remaining files that fail to be deleted. There is a limit of 100 read sets that can be deleted in each batch_delete_read_set API call.

See https://www.paws-r-sdk.com/docs/omics_batch_delete_read_set/ for full documentation.

Usage

omics_batch_delete_read_set(ids, sequenceStoreId)

Arguments

ids

[required] The read sets' IDs.

sequenceStoreId

[required] The read sets' sequence store ID.


paws.storage documentation built on May 30, 2026, 9:13 a.m.