omics_complete_multipart_read_set_upload: Completes a multipart read set upload into a sequence store...

View source: R/omics_operations.R

omics_complete_multipart_read_set_uploadR Documentation

Completes a multipart read set upload into a sequence store after you have initiated the upload process with CreateMultipartReadSetUpload and uploaded all read set parts using UploadReadSetPart

Description

Completes a multipart read set upload into a sequence store after you have initiated the upload process with create_multipart_read_set_upload and uploaded all read set parts using upload_read_set_part. You must specify the parts you uploaded using the parts parameter. If the operation is successful, it returns the read set ID(s) of the uploaded read set(s).

See https://www.paws-r-sdk.com/docs/omics_complete_multipart_read_set_upload/ for full documentation.

Usage

omics_complete_multipart_read_set_upload(sequenceStoreId, uploadId, parts)

Arguments

sequenceStoreId

[required] The sequence store ID for the store involved in the multipart upload.

uploadId

[required] The ID for the multipart upload.

parts

[required] The individual uploads or parts of a multipart upload.


paws.storage documentation built on May 30, 2026, 9:13 a.m.