View source: R/omics_operations.R
| omics_create_annotation_store | R Documentation |
Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers. Existing customers can continue to use the service as normal. For more information, see Amazon Web Services HealthOmics variant store and annotation store availability change.
See https://www.paws-r-sdk.com/docs/omics_create_annotation_store/ for full documentation.
omics_create_annotation_store(
reference = NULL,
name = NULL,
description = NULL,
tags = NULL,
versionName = NULL,
sseConfig = NULL,
storeFormat,
storeOptions = NULL
)
reference |
The genome reference for the store's annotations. |
name |
A name for the store. |
description |
A description for the store. |
tags |
Tags for the store. |
versionName |
The name given to an annotation store version to distinguish it from other versions. |
sseConfig |
Server-side encryption (SSE) settings for the store. |
storeFormat |
[required] The annotation file format of the store. |
storeOptions |
File parsing options for the annotation store. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.