omics_create_multipart_read_set_upload: Initiates a multipart read set upload for uploading...

View source: R/omics_operations.R

omics_create_multipart_read_set_uploadR Documentation

Initiates a multipart read set upload for uploading partitioned source files into a sequence store

Description

Initiates a multipart read set upload for uploading partitioned source files into a sequence store. You can directly import source files from an EC2 instance and other local compute, or from an S3 bucket. To separate these source files into parts, use the split operation. Each part cannot be larger than 100 MB. If the operation is successful, it provides an uploadId which is required by the upload_read_set_part API operation to upload parts into a sequence store.

See https://www.paws-r-sdk.com/docs/omics_create_multipart_read_set_upload/ for full documentation.

Usage

omics_create_multipart_read_set_upload(
  sequenceStoreId,
  clientToken = NULL,
  sourceFileType,
  subjectId,
  sampleId,
  generatedFrom = NULL,
  referenceArn = NULL,
  name,
  description = NULL,
  tags = NULL
)

Arguments

sequenceStoreId

[required] The sequence store ID for the store that is the destination of the multipart uploads.

clientToken

An idempotency token that can be used to avoid triggering multiple multipart uploads.

sourceFileType

[required] The type of file being uploaded.

subjectId

[required] The source's subject ID.

sampleId

[required] The source's sample ID.

generatedFrom

Where the source originated.

referenceArn

The ARN of the reference.

name

[required] The name of the read set.

description

The description of the read set.

tags

Any tags to add to the read set.


paws.storage documentation built on May 30, 2026, 9:13 a.m.