omics_create_reference_store: Creates a reference store and returns metadata in JSON format

View source: R/omics_operations.R

omics_create_reference_storeR Documentation

Creates a reference store and returns metadata in JSON format

Description

Creates a reference store and returns metadata in JSON format. Reference stores are used to store reference genomes in FASTA format. A reference store is created when the first reference genome is imported. To import additional reference genomes from an Amazon S3 bucket, use the start_reference_import_job API operation.

See https://www.paws-r-sdk.com/docs/omics_create_reference_store/ for full documentation.

Usage

omics_create_reference_store(
  name,
  description = NULL,
  sseConfig = NULL,
  tags = NULL,
  clientToken = NULL
)

Arguments

name

[required] A name for the store.

description

A description for the store.

sseConfig

Server-side encryption (SSE) settings for the store.

tags

Tags for the store.

clientToken

To ensure that requests don't run multiple times, specify a unique token for each request.


paws.storage documentation built on May 30, 2026, 9:13 a.m.