omics_create_sequence_store: Creates a sequence store and returns its metadata

View source: R/omics_operations.R

omics_create_sequence_storeR Documentation

Creates a sequence store and returns its metadata

Description

Creates a sequence store and returns its metadata. Sequence stores are used to store sequence data files called read sets that are saved in FASTQ, BAM, uBAM, or CRAM formats. For aligned formats (BAM and CRAM), a sequence store can only use one reference genome. For unaligned formats (FASTQ and uBAM), a reference genome is not required. You can create multiple sequence stores per region per account.

See https://www.paws-r-sdk.com/docs/omics_create_sequence_store/ for full documentation.

Usage

omics_create_sequence_store(
  name,
  description = NULL,
  sseConfig = NULL,
  tags = NULL,
  clientToken = NULL,
  fallbackLocation = NULL,
  eTagAlgorithmFamily = NULL,
  propagatedSetLevelTags = NULL,
  s3AccessConfig = NULL
)

Arguments

name

[required] A name for the store.

description

A description for the store.

sseConfig

Server-side encryption (SSE) settings for the store.

tags

Tags for the store. You can configure up to 50 tags.

clientToken

An idempotency token used to dedupe retry requests so that duplicate runs are not created.

fallbackLocation

An S3 location that is used to store files that have failed a direct upload. You can add or change the fallbackLocation after creating a sequence store. This is not required if you are uploading files from a different S3 bucket.

eTagAlgorithmFamily

The ETag algorithm family to use for ingested read sets. The default value is MD5up. For more information on ETags, see ETags and data provenance in the Amazon Web Services HealthOmics User Guide.

propagatedSetLevelTags

The tags keys to propagate to the S3 objects associated with read sets in the sequence store. These tags can be used as input to add metadata to your read sets.

s3AccessConfig

S3 access configuration parameters. This specifies the parameters needed to access logs stored in S3 buckets. The S3 bucket must be in the same region and account as the sequence store.


paws.storage documentation built on May 30, 2026, 9:13 a.m.