View source: R/omics_operations.R
| omics_create_variant_store | R Documentation |
Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers. Existing customers can continue to use the service as normal. For more information, see Amazon Web Services HealthOmics variant store and annotation store availability change.
See https://www.paws-r-sdk.com/docs/omics_create_variant_store/ for full documentation.
omics_create_variant_store(
reference,
name = NULL,
description = NULL,
tags = NULL,
sseConfig = NULL
)
reference |
[required] The genome reference for the store's variants. |
name |
A name for the store. |
description |
A description for the store. |
tags |
Tags for the store. |
sseConfig |
Server-side encryption (SSE) settings for the store. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.