omics_delete_annotation_store: Amazon Web Services HealthOmics variant stores and annotation...

View source: R/omics_operations.R

omics_delete_annotation_storeR Documentation

Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers

Description

Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers. Existing customers can continue to use the service as normal. For more information, see Amazon Web Services HealthOmics variant store and annotation store availability change.

See https://www.paws-r-sdk.com/docs/omics_delete_annotation_store/ for full documentation.

Usage

omics_delete_annotation_store(name, force = NULL)

Arguments

name

[required] The store's name.

force

Whether to force deletion.


paws.storage documentation built on May 30, 2026, 9:13 a.m.