omics_delete_batch: Deletes a run batch resource and its associated metadata

View source: R/omics_operations.R

omics_delete_batchR Documentation

Deletes a run batch resource and its associated metadata

Description

Deletes a run batch resource and its associated metadata. This operation does not delete the individual workflow runs. To delete the runs, call delete_run_batch before calling delete_batch.

See https://www.paws-r-sdk.com/docs/omics_delete_batch/ for full documentation.

Usage

omics_delete_batch(batchId)

Arguments

batchId

[required] The identifier portion of the run batch ARN.


paws.storage documentation built on May 30, 2026, 9:13 a.m.