omics_delete_reference: Deletes a reference genome and returns a response with no...

View source: R/omics_operations.R

omics_delete_referenceR Documentation

Deletes a reference genome and returns a response with no body if the operation is successful

Description

Deletes a reference genome and returns a response with no body if the operation is successful. The read set associated with the reference genome must first be deleted before deleting the reference genome. After the reference genome is deleted, you can delete the reference store using the delete_reference_store API operation.

See https://www.paws-r-sdk.com/docs/omics_delete_reference/ for full documentation.

Usage

omics_delete_reference(id, referenceStoreId)

Arguments

id

[required] The reference's ID.

referenceStoreId

[required] The reference's store ID.


paws.storage documentation built on May 30, 2026, 9:13 a.m.