omics_delete_reference_store: Deletes a reference store and returns a response with no body...

View source: R/omics_operations.R

omics_delete_reference_storeR Documentation

Deletes a reference store and returns a response with no body if the operation is successful

Description

Deletes a reference store and returns a response with no body if the operation is successful. You can only delete a reference store when it does not contain any reference genomes. To empty a reference store, use delete_reference.

See https://www.paws-r-sdk.com/docs/omics_delete_reference_store/ for full documentation.

Usage

omics_delete_reference_store(id)

Arguments

id

[required] The store's ID.


paws.storage documentation built on May 30, 2026, 9:13 a.m.