omics_delete_run: Deletes a run and returns a response with no body if the...

View source: R/omics_operations.R

omics_delete_runR Documentation

Deletes a run and returns a response with no body if the operation is successful

Description

Deletes a run and returns a response with no body if the operation is successful. You can only delete a run that has reached a COMPLETED, FAILED, or CANCELLED stage. A completed run has delivered an output, or was cancelled and resulted in no output. When you delete a run, only the metadata associated with the run is deleted. The run outputs remain in Amazon S3 and logs remain in CloudWatch.

See https://www.paws-r-sdk.com/docs/omics_delete_run/ for full documentation.

Usage

omics_delete_run(id)

Arguments

id

[required] The run's ID.


paws.storage documentation built on May 30, 2026, 9:13 a.m.