omics_get_batch: Retrieves details and current status for a specific run...

View source: R/omics_operations.R

omics_get_batchR Documentation

Retrieves details and current status for a specific run batch, including submission progress and run execution counts

Description

Retrieves details and current status for a specific run batch, including submission progress and run execution counts.

See https://www.paws-r-sdk.com/docs/omics_get_batch/ for full documentation.

Usage

omics_get_batch(batchId)

Arguments

batchId

[required] The identifier portion of the run batch ARN.


paws.storage documentation built on May 30, 2026, 9:13 a.m.