omics_get_read_set: Retrieves detailed information from parts of a read set and...

View source: R/omics_operations.R

omics_get_read_setR Documentation

Retrieves detailed information from parts of a read set and returns the read set in the same format that it was uploaded

Description

Retrieves detailed information from parts of a read set and returns the read set in the same format that it was uploaded. You must have read sets uploaded to your sequence store in order to run this operation.

See https://www.paws-r-sdk.com/docs/omics_get_read_set/ for full documentation.

Usage

omics_get_read_set(id, sequenceStoreId, file = NULL, partNumber)

Arguments

id

[required] The read set's ID.

sequenceStoreId

[required] The read set's sequence store ID.

file

The file to retrieve.

partNumber

[required] The part number to retrieve.


paws.storage documentation built on May 30, 2026, 9:13 a.m.