omics_get_read_set_export_job: Retrieves status information about a read set export job and...

View source: R/omics_operations.R

omics_get_read_set_export_jobR Documentation

Retrieves status information about a read set export job and returns the data in JSON format

Description

Retrieves status information about a read set export job and returns the data in JSON format. Use this operation to actively monitor the progress of an export job.

See https://www.paws-r-sdk.com/docs/omics_get_read_set_export_job/ for full documentation.

Usage

omics_get_read_set_export_job(sequenceStoreId, id)

Arguments

sequenceStoreId

[required] The job's sequence store ID.

id

[required] The job's ID.


paws.storage documentation built on May 30, 2026, 9:13 a.m.