omics_get_reference: Downloads parts of data from a reference genome and returns...

View source: R/omics_operations.R

omics_get_referenceR Documentation

Downloads parts of data from a reference genome and returns the reference file in the same format that it was uploaded

Description

Downloads parts of data from a reference genome and returns the reference file in the same format that it was uploaded.

See https://www.paws-r-sdk.com/docs/omics_get_reference/ for full documentation.

Usage

omics_get_reference(
  id,
  referenceStoreId,
  range = NULL,
  partNumber,
  file = NULL
)

Arguments

id

[required] The reference's ID.

referenceStoreId

[required] The reference's store ID.

range

The range to retrieve.

partNumber

[required] The part number to retrieve.

file

The file to retrieve.


paws.storage documentation built on May 30, 2026, 9:13 a.m.