omics_get_s3_access_policy: Retrieves details about an access policy on a given store

View source: R/omics_operations.R

omics_get_s3_access_policyR Documentation

Retrieves details about an access policy on a given store

Description

Retrieves details about an access policy on a given store.

See https://www.paws-r-sdk.com/docs/omics_get_s3_access_policy/ for full documentation.

Usage

omics_get_s3_access_policy(s3AccessPointArn)

Arguments

s3AccessPointArn

[required] The S3 access point ARN that has the access policy.


paws.storage documentation built on May 30, 2026, 9:13 a.m.