omics_get_workflow: Gets all information about a workflow using its ID

View source: R/omics_operations.R

omics_get_workflowR Documentation

Gets all information about a workflow using its ID

Description

Gets all information about a workflow using its ID.

See https://www.paws-r-sdk.com/docs/omics_get_workflow/ for full documentation.

Usage

omics_get_workflow(id, type = NULL, export = NULL, workflowOwnerId = NULL)

Arguments

id

[required] The workflow's ID.

type

The workflow's type.

export

The export format for the workflow.

workflowOwnerId

The ID of the workflow owner.


paws.storage documentation built on May 30, 2026, 9:13 a.m.