omics_get_workflow_version: Gets information about a workflow version

View source: R/omics_operations.R

omics_get_workflow_versionR Documentation

Gets information about a workflow version

Description

Gets information about a workflow version. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.

See https://www.paws-r-sdk.com/docs/omics_get_workflow_version/ for full documentation.

Usage

omics_get_workflow_version(
  workflowId,
  versionName,
  type = NULL,
  export = NULL,
  workflowOwnerId = NULL
)

Arguments

workflowId

[required] The workflow's ID. The workflowId is not the UUID.

versionName

[required] The workflow version name.

type

The workflow's type.

export

The export format for the workflow.

workflowOwnerId

The 12-digit account ID of the workflow owner. The workflow owner ID can be retrieved using the get_share API operation. If you are the workflow owner, you do not need to include this ID.


paws.storage documentation built on May 30, 2026, 9:13 a.m.