omics_list_read_set_activation_jobs: Retrieves a list of read set activation jobs and returns the...

View source: R/omics_operations.R

omics_list_read_set_activation_jobsR Documentation

Retrieves a list of read set activation jobs and returns the metadata in a JSON formatted output

Description

Retrieves a list of read set activation jobs and returns the metadata in a JSON formatted output. To extract metadata from a read set activation job, use the get_read_set_activation_job API operation.

See https://www.paws-r-sdk.com/docs/omics_list_read_set_activation_jobs/ for full documentation.

Usage

omics_list_read_set_activation_jobs(
  sequenceStoreId,
  maxResults = NULL,
  nextToken = NULL,
  filter = NULL
)

Arguments

sequenceStoreId

[required] The read set's sequence store ID.

maxResults

The maximum number of read set activation jobs to return in one page of results.

nextToken

Specify the pagination token from a previous request to retrieve the next page of results.

filter

A filter to apply to the list.


paws.storage documentation built on May 30, 2026, 9:13 a.m.