omics_list_read_set_export_jobs: Retrieves a list of read set export jobs in a JSON formatted...

View source: R/omics_operations.R

omics_list_read_set_export_jobsR Documentation

Retrieves a list of read set export jobs in a JSON formatted response

Description

Retrieves a list of read set export jobs in a JSON formatted response. This API operation is used to check the status of a read set export job initiated by the start_read_set_export_job API operation.

See https://www.paws-r-sdk.com/docs/omics_list_read_set_export_jobs/ for full documentation.

Usage

omics_list_read_set_export_jobs(
  sequenceStoreId,
  maxResults = NULL,
  nextToken = NULL,
  filter = NULL
)

Arguments

sequenceStoreId

[required] The jobs' sequence store ID.

maxResults

The maximum number of jobs to return in one page of results.

nextToken

Specify the pagination token from a previous request to retrieve the next page of results.

filter

A filter to apply to the list.


paws.storage documentation built on May 30, 2026, 9:13 a.m.