omics_list_reference_import_jobs: Retrieves the metadata of one or more reference import jobs...

View source: R/omics_operations.R

omics_list_reference_import_jobsR Documentation

Retrieves the metadata of one or more reference import jobs for a reference store

Description

Retrieves the metadata of one or more reference import jobs for a reference store.

See https://www.paws-r-sdk.com/docs/omics_list_reference_import_jobs/ for full documentation.

Usage

omics_list_reference_import_jobs(
  maxResults = NULL,
  nextToken = NULL,
  referenceStoreId,
  filter = NULL
)

Arguments

maxResults

The maximum number of jobs to return in one page of results.

nextToken

Specify the pagination token from a previous request to retrieve the next page of results.

referenceStoreId

[required] The job's reference store ID.

filter

A filter to apply to the list.


paws.storage documentation built on May 30, 2026, 9:13 a.m.