omics_list_references: Retrieves the metadata of one or more reference genomes in a...

View source: R/omics_operations.R

omics_list_referencesR Documentation

Retrieves the metadata of one or more reference genomes in a reference store

Description

Retrieves the metadata of one or more reference genomes in a reference store.

See https://www.paws-r-sdk.com/docs/omics_list_references/ for full documentation.

Usage

omics_list_references(
  referenceStoreId,
  maxResults = NULL,
  nextToken = NULL,
  filter = NULL
)

Arguments

referenceStoreId

[required] The references' reference store ID.

maxResults

The maximum number of references to return in one page of results.

nextToken

Specify the pagination token from a previous request to retrieve the next page of results.

filter

A filter to apply to the list.


paws.storage documentation built on May 30, 2026, 9:13 a.m.