omics_list_run_caches: Retrieves a list of your run caches and the metadata for each...

View source: R/omics_operations.R

omics_list_run_cachesR Documentation

Retrieves a list of your run caches and the metadata for each cache

Description

Retrieves a list of your run caches and the metadata for each cache.

See https://www.paws-r-sdk.com/docs/omics_list_run_caches/ for full documentation.

Usage

omics_list_run_caches(maxResults = NULL, startingToken = NULL)

Arguments

maxResults

The maximum number of results to return.

startingToken

Optional pagination token returned from a prior call to the list_run_caches API operation.


paws.storage documentation built on May 30, 2026, 9:13 a.m.