omics_list_run_groups: Retrieves a list of all run groups and returns the metadata...

View source: R/omics_operations.R

omics_list_run_groupsR Documentation

Retrieves a list of all run groups and returns the metadata for each run group

Description

Retrieves a list of all run groups and returns the metadata for each run group.

See https://www.paws-r-sdk.com/docs/omics_list_run_groups/ for full documentation.

Usage

omics_list_run_groups(name = NULL, startingToken = NULL, maxResults = NULL)

Arguments

name

The run groups' name.

startingToken

Specify the pagination token from a previous request to retrieve the next page of results.

maxResults

The maximum number of run groups to return in one page of results.


paws.storage documentation built on May 30, 2026, 9:13 a.m.