omics_list_run_tasks: Returns a list of tasks and status information within their...

View source: R/omics_operations.R

omics_list_run_tasksR Documentation

Returns a list of tasks and status information within their specified run

Description

Returns a list of tasks and status information within their specified run. Use this operation to monitor runs and to identify which specific tasks have failed.

See https://www.paws-r-sdk.com/docs/omics_list_run_tasks/ for full documentation.

Usage

omics_list_run_tasks(
  id,
  status = NULL,
  startingToken = NULL,
  maxResults = NULL
)

Arguments

id

[required] The run's ID.

status

Filter the list by status.

startingToken

Specify the pagination token from a previous request to retrieve the next page of results.

maxResults

The maximum number of run tasks to return in one page of results.


paws.storage documentation built on May 30, 2026, 9:13 a.m.