omics_list_runs_in_batch: Returns a paginated list of individual workflow runs within a...

View source: R/omics_operations.R

omics_list_runs_in_batchR Documentation

Returns a paginated list of individual workflow runs within a specific batch

Description

Returns a paginated list of individual workflow runs within a specific batch. Use this operation to map each runSettingId to its HealthOmics-generated runId, and to check the submission status of each run. Only one filter per call is supported.

See https://www.paws-r-sdk.com/docs/omics_list_runs_in_batch/ for full documentation.

Usage

omics_list_runs_in_batch(
  batchId,
  maxItems = NULL,
  startingToken = NULL,
  submissionStatus = NULL,
  runSettingId = NULL,
  runId = NULL
)

Arguments

batchId

[required] The identifier portion of the run batch ARN.

maxItems

The maximum number of runs to return.

startingToken

A pagination token returned from a prior list_runs_in_batch call.

submissionStatus

Filter runs by submission status.

runSettingId

Filter runs by the customer-provided run setting ID.

runId

Filter runs by the HealthOmics-generated run ID.


paws.storage documentation built on May 30, 2026, 9:13 a.m.