omics_list_workflow_versions: Lists the workflow versions for the specified workflow

View source: R/omics_operations.R

omics_list_workflow_versionsR Documentation

Lists the workflow versions for the specified workflow

Description

Lists the workflow versions for the specified workflow. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.

See https://www.paws-r-sdk.com/docs/omics_list_workflow_versions/ for full documentation.

Usage

omics_list_workflow_versions(
  workflowId,
  type = NULL,
  workflowOwnerId = NULL,
  startingToken = NULL,
  maxResults = NULL
)

Arguments

workflowId

[required] The workflow's ID. The workflowId is not the UUID.

type

The workflow type.

workflowOwnerId

The 12-digit account ID of the workflow owner. The workflow owner ID can be retrieved using the get_share API operation. If you are the workflow owner, you do not need to include this ID.

startingToken

Specify the pagination token from a previous request to retrieve the next page of results.

maxResults

The maximum number of workflows to return in one page of results.


paws.storage documentation built on May 30, 2026, 9:13 a.m.