omics_list_workflows: Retrieves a list of existing workflows

View source: R/omics_operations.R

omics_list_workflowsR Documentation

Retrieves a list of existing workflows

Description

Retrieves a list of existing workflows. You can filter for specific workflows by their name and type. Using the type parameter, specify PRIVATE to retrieve a list of private workflows or specify READY2RUN for a list of all Ready2Run workflows. If you do not specify the type of workflow, this operation returns a list of existing workflows.

See https://www.paws-r-sdk.com/docs/omics_list_workflows/ for full documentation.

Usage

omics_list_workflows(
  type = NULL,
  name = NULL,
  startingToken = NULL,
  maxResults = NULL
)

Arguments

type

Filter the list by workflow type.

name

Filter the list by workflow name.

startingToken

Specify the pagination token from a previous request to retrieve the next page of results.

maxResults

The maximum number of workflows to return in one page of results.


paws.storage documentation built on May 30, 2026, 9:13 a.m.