omics_start_read_set_export_job: Starts a read set export job

View source: R/omics_operations.R

omics_start_read_set_export_jobR Documentation

Starts a read set export job

Description

Starts a read set export job. When the export job is finished, the read set is exported to an Amazon S3 bucket which can be retrieved using the get_read_set_export_job API operation.

See https://www.paws-r-sdk.com/docs/omics_start_read_set_export_job/ for full documentation.

Usage

omics_start_read_set_export_job(
  sequenceStoreId,
  destination,
  roleArn,
  clientToken = NULL,
  sources
)

Arguments

sequenceStoreId

[required] The read set's sequence store ID.

destination

[required] A location for exported files in Amazon S3.

roleArn

[required] A service role for the job.

clientToken

To ensure that jobs don't run multiple times, specify a unique token for each job.

sources

[required] The job's source files.


paws.storage documentation built on May 30, 2026, 9:13 a.m.