omics_start_read_set_import_job: Imports a read set from the sequence store

View source: R/omics_operations.R

omics_start_read_set_import_jobR Documentation

Imports a read set from the sequence store

Description

Imports a read set from the sequence store. Read set import jobs support a maximum of 100 read sets of different types. Monitor the progress of your read set import job by calling the get_read_set_import_job API operation.

See https://www.paws-r-sdk.com/docs/omics_start_read_set_import_job/ for full documentation.

Usage

omics_start_read_set_import_job(
  sequenceStoreId,
  roleArn,
  clientToken = NULL,
  sources
)

Arguments

sequenceStoreId

[required] The read set's sequence store ID.

roleArn

[required] A service role for the job.

clientToken

To ensure that jobs don't run multiple times, specify a unique token for each job.

sources

[required] The job's source files.


paws.storage documentation built on May 30, 2026, 9:13 a.m.