View source: R/omics_operations.R
| omics_start_run | R Documentation |
Starts a new run and returns details about the run, or duplicates an existing run. A run is a single invocation of a workflow. If you provide request IDs, Amazon Web Services HealthOmics identifies duplicate requests and starts the run only once. Monitor the progress of the run by calling the get_run API operation.
See https://www.paws-r-sdk.com/docs/omics_start_run/ for full documentation.
omics_start_run(
workflowId = NULL,
workflowType = NULL,
runId = NULL,
roleArn,
name = NULL,
cacheId = NULL,
cacheBehavior = NULL,
runGroupId = NULL,
priority = NULL,
parameters = NULL,
storageCapacity = NULL,
outputUri,
logLevel = NULL,
tags = NULL,
requestId,
retentionMode = NULL,
storageType = NULL,
workflowOwnerId = NULL,
workflowVersionName = NULL,
networkingMode = NULL,
configurationName = NULL
)
workflowId |
The run's workflow ID. The |
workflowType |
The run's workflow type. The |
runId |
The ID of a run to duplicate. |
roleArn |
[required] A service role for the run. The |
name |
A name for the run. This is recommended to view and organize runs in the Amazon Web Services HealthOmics console and CloudWatch logs. |
cacheId |
Identifier of the cache associated with this run. If you don't specify a cache ID, no task outputs are cached for this run. |
cacheBehavior |
The cache behavior for the run. You specify this value if you want to override the default behavior for the cache. You had set the default value when you created the cache. For more information, see Run cache behavior in the Amazon Web Services HealthOmics User Guide. |
runGroupId |
The run's group ID. Use a run group to cap the compute resources (and number of concurrent runs) for the runs that you add to the run group. |
priority |
Use the run priority (highest: 1) to establish the order of runs in a run group when you start a run. If multiple runs share the same priority, the run that was initiated first will have the higher priority. Runs that do not belong to a run group can be assigned a priority. The priorities of these runs are ranked among other runs that are not in a run group. For more information, see Run priority in the Amazon Web Services HealthOmics User Guide. |
parameters |
Parameters for the run. The run needs all required parameters and can include optional parameters. The run cannot include any parameters that are not defined in the parameter template. To retrieve parameters from the run, use the GetRun API operation. |
storageCapacity |
The |
outputUri |
[required] An output S3 URI for the run. The S3 bucket must be in the same region as the workflow. The role ARN must have permission to write to this S3 bucket. |
logLevel |
A log level for the run. |
tags |
Tags for the run. You can add up to 50 tags per run. For more information, see Adding a tag in the Amazon Web Services HealthOmics User Guide. |
requestId |
[required] An idempotency token used to dedupe retry requests so that duplicate runs are not created. |
retentionMode |
The retention mode for the run. The default value is Amazon Web Services HealthOmics stores a fixed number of runs that are available to the console and API. In the default mode ( For more information about retention mode, see Specifying run retention mode in the Amazon Web Services HealthOmics User Guide. |
storageType |
The storage type for the run. If you set the storage type to |
workflowOwnerId |
The 12-digit account ID of the workflow owner that is used for running a shared workflow. The workflow owner ID can be retrieved using the |
workflowVersionName |
The name of the workflow version. Use workflow versions to track and organize changes to the workflow. If your workflow has multiple versions, the run uses the default version unless you specify a version name. To learn more, see Workflow versioning in the Amazon Web Services HealthOmics User Guide. |
networkingMode |
Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED. |
configurationName |
Optional configuration name to use for the workflow run. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.