omics_start_run_batch: Starts a batch of workflow runs

View source: R/omics_operations.R

omics_start_run_batchR Documentation

Starts a batch of workflow runs

Description

Starts a batch of workflow runs. You can group up to 100,000 runs into a single batch that share a common configuration defined in defaultRunSetting. Per-run overrides can be provided either inline via inlineSettings (up to 100 runs) or via a JSON file stored in Amazon S3 via s3UriSettings (up to 100,000 runs).

See https://www.paws-r-sdk.com/docs/omics_start_run_batch/ for full documentation.

Usage

omics_start_run_batch(
  batchName = NULL,
  requestId,
  tags = NULL,
  defaultRunSetting,
  batchRunSettings
)

Arguments

batchName

An optional user-friendly name for the run batch.

requestId

[required] A client token used to deduplicate retry requests and prevent duplicate batches from being created.

tags

AWS tags to associate with the batch resource. These tags are not inherited by individual runs. To tag individual runs, use defaultRunSetting.runTags.

defaultRunSetting

[required] Shared configuration applied to all runs in the batch. See DefaultRunSetting.

batchRunSettings

[required] The individual run configurations. Specify exactly one of inlineSettings or s3UriSettings. See BatchRunSettings.


paws.storage documentation built on May 30, 2026, 9:13 a.m.