omics_update_run_cache: Updates a run cache using its ID and returns a response with...

View source: R/omics_operations.R

omics_update_run_cacheR Documentation

Updates a run cache using its ID and returns a response with no body if the operation is successful

Description

Updates a run cache using its ID and returns a response with no body if the operation is successful. You can update the run cache description, name, or the default run cache behavior with CACHE_ON_FAILURE or CACHE_ALWAYS. To confirm that your run cache settings have been properly updated, use the get_run_cache API operation.

See https://www.paws-r-sdk.com/docs/omics_update_run_cache/ for full documentation.

Usage

omics_update_run_cache(
  cacheBehavior = NULL,
  description = NULL,
  id,
  name = NULL
)

Arguments

cacheBehavior

Update the default run cache behavior.

description

Update the run cache description.

id

[required] The identifier of the run cache you want to update.

name

Update the name of the run cache.


paws.storage documentation built on May 30, 2026, 9:13 a.m.