View source: R/omics_operations.R
| omics_update_sequence_store | R Documentation |
Update one or more parameters for the sequence store.
See https://www.paws-r-sdk.com/docs/omics_update_sequence_store/ for full documentation.
omics_update_sequence_store(
id,
name = NULL,
description = NULL,
clientToken = NULL,
fallbackLocation = NULL,
propagatedSetLevelTags = NULL,
s3AccessConfig = NULL
)
id |
[required] The ID of the sequence store. |
name |
A name for the sequence store. |
description |
A description for the sequence store. |
clientToken |
To ensure that requests don't run multiple times, specify a unique token for each request. |
fallbackLocation |
The S3 URI of a bucket and folder to store Read Sets that fail to upload. |
propagatedSetLevelTags |
The tags keys to propagate to the S3 objects associated with read sets in the sequence store. |
s3AccessConfig |
S3 access configuration parameters. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.