omics_update_workflow_version: Updates information about the workflow version

View source: R/omics_operations.R

omics_update_workflow_versionR Documentation

Updates information about the workflow version

Description

Updates information about the workflow version. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.

See https://www.paws-r-sdk.com/docs/omics_update_workflow_version/ for full documentation.

Usage

omics_update_workflow_version(
  workflowId,
  versionName,
  description = NULL,
  storageType = NULL,
  storageCapacity = NULL,
  readmeMarkdown = NULL
)

Arguments

workflowId

[required] The workflow's ID. The workflowId is not the UUID.

versionName

[required] The name of the workflow version.

description

Description of the workflow version.

storageType

The default storage type for runs that use this workflow version. The storageType can be overridden at run time. DYNAMIC storage dynamically scales the storage up or down, based on file system utilization. STATIC storage allocates a fixed amount of storage. For more information about dynamic and static storage types, see Run storage types in the in the Amazon Web Services HealthOmics User Guide .

storageCapacity

The default static storage capacity (in gibibytes) for runs that use this workflow version. The storageCapacity can be overwritten at run time. The storage capacity is not required for runs with a DYNAMIC storage type.

readmeMarkdown

The markdown content for the workflow version's README file. This provides documentation and usage information for users of this specific workflow version.


paws.storage documentation built on May 30, 2026, 9:13 a.m.