View source: R/s3_operations.R
| s3_complete_multipart_upload | R Documentation |
Completes a multipart upload by assembling previously uploaded parts.
See https://www.paws-r-sdk.com/docs/s3_complete_multipart_upload/ for full documentation.
s3_complete_multipart_upload(
Bucket,
Key,
MultipartUpload = NULL,
UploadId,
ChecksumCRC32 = NULL,
ChecksumCRC32C = NULL,
ChecksumCRC64NVME = NULL,
ChecksumSHA1 = NULL,
ChecksumSHA256 = NULL,
ChecksumSHA512 = NULL,
ChecksumMD5 = NULL,
ChecksumXXHASH64 = NULL,
ChecksumXXHASH3 = NULL,
ChecksumXXHASH128 = NULL,
ChecksumType = NULL,
MpuObjectSize = NULL,
RequestPayer = NULL,
ExpectedBucketOwner = NULL,
IfMatch = NULL,
IfNoneMatch = NULL,
SSECustomerAlgorithm = NULL,
SSECustomerKey = NULL,
SSECustomerKeyMD5 = NULL
)
Bucket |
[required] Name of the bucket to which the multipart upload was initiated. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
Key |
[required] Object key for which the multipart upload was initiated. |
MultipartUpload |
The container for the multipart upload request information. |
UploadId |
[required] ID for the initiated multipart upload. |
ChecksumCRC32 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit |
ChecksumCRC32C |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit |
ChecksumCRC64NVME |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit |
ChecksumSHA1 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit |
ChecksumSHA256 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit |
ChecksumSHA512 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 512-bit |
ChecksumMD5 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit |
ChecksumXXHASH64 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit |
ChecksumXXHASH3 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit |
ChecksumXXHASH128 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit |
ChecksumType |
This header specifies the checksum type of the object, which determines how part-level checksums are combined to create an object-level checksum for multipart objects. You can use this header as a data integrity check to verify that the checksum type that is received is the same checksum that was specified. If the checksum type doesn’t match the checksum type that was specified for the object during the |
MpuObjectSize |
The expected total object size of the multipart upload request. If there’s a mismatch between the specified object size value and the actual object size value, it results in an |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
IfMatch |
Uploads the object only if the ETag (entity tag) value provided during the WRITE operation matches the ETag of the object in S3. If the ETag values do not match, the operation returns a If a conflicting operation occurs during the upload S3 returns a Expects the ETag value as a string. For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide. |
IfNoneMatch |
Uploads the object only if the object key name does not already exist in the bucket specified. Otherwise, Amazon S3 returns a If a conflicting operation occurs during the upload S3 returns a Expects the '*' (asterisk) character. For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide. |
SSECustomerAlgorithm |
The server-side encryption (SSE) algorithm used to encrypt the object. This parameter is required only when the object was created using a checksum algorithm or if your bucket policy requires the use of SSE-C. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
SSECustomerKey |
The server-side encryption (SSE) customer managed key. This parameter is needed only when the object was created using a checksum algorithm. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
SSECustomerKeyMD5 |
The MD5 server-side encryption (SSE) customer managed key. This parameter is needed only when the object was created using a checksum algorithm. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.