View source: R/s3_operations.R
| s3_copy_object | R Documentation |
Creates a copy of an object that is already stored in Amazon S3.
See https://www.paws-r-sdk.com/docs/s3_copy_object/ for full documentation.
s3_copy_object(
ACL = NULL,
Bucket,
CacheControl = NULL,
ChecksumAlgorithm = NULL,
ContentDisposition = NULL,
ContentEncoding = NULL,
ContentLanguage = NULL,
ContentType = NULL,
CopySource,
CopySourceIfMatch = NULL,
CopySourceIfModifiedSince = NULL,
CopySourceIfNoneMatch = NULL,
CopySourceIfUnmodifiedSince = NULL,
Expires = NULL,
GrantFullControl = NULL,
GrantRead = NULL,
GrantReadACP = NULL,
GrantWriteACP = NULL,
IfMatch = NULL,
IfNoneMatch = NULL,
Key,
Metadata = NULL,
MetadataDirective = NULL,
TaggingDirective = NULL,
ServerSideEncryption = NULL,
StorageClass = NULL,
WebsiteRedirectLocation = NULL,
SSECustomerAlgorithm = NULL,
SSECustomerKey = NULL,
SSECustomerKeyMD5 = NULL,
SSEKMSKeyId = NULL,
SSEKMSEncryptionContext = NULL,
BucketKeyEnabled = NULL,
CopySourceSSECustomerAlgorithm = NULL,
CopySourceSSECustomerKey = NULL,
CopySourceSSECustomerKeyMD5 = NULL,
RequestPayer = NULL,
Tagging = NULL,
ObjectLockMode = NULL,
ObjectLockRetainUntilDate = NULL,
ObjectLockLegalHoldStatus = NULL,
ExpectedBucketOwner = NULL,
ExpectedSourceBucketOwner = NULL
)
ACL |
The canned access control list (ACL) to apply to the object. When you copy an object, the ACL metadata is not preserved and is set to If the destination bucket that you're copying objects to uses the bucket owner enforced setting for S3 Object Ownership, ACLs are disabled and no longer affect permissions. Buckets that use this setting only accept
|
Bucket |
[required] The name of the destination bucket. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Copying objects across different Amazon Web Services Regions isn't supported when the source or destination bucket is in Amazon Web Services Local Zones. The source and destination buckets must have the same parent Amazon Web Services Region. Otherwise, you get an HTTP Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must use the Outpost bucket access point ARN or the access point alias for the destination bucket. You can only copy objects within the same Outpost bucket. It's not supported to copy objects across different Amazon Web Services Outposts, between buckets on the same Outposts, or between Outposts buckets and any other bucket types. For more information about S3 on Outposts, see What is S3 on Outposts? in the S3 on Outposts guide. When you use this action with S3 on Outposts through the REST API, you must direct requests to the S3 on Outposts hostname, in the format |
CacheControl |
Specifies the caching behavior along the request/reply chain. |
ChecksumAlgorithm |
Indicates the algorithm that you want Amazon S3 to use to create the checksum for the object. For more information, see Checking object integrity in the Amazon S3 User Guide. When you copy an object, if the source object has a checksum, that checksum value will be copied to the new object by default. If the For directory buckets, when you use Amazon Web Services SDKs, |
ContentDisposition |
Specifies presentational information for the object. Indicates whether an object should be displayed in a web browser or downloaded as a file. It allows specifying the desired filename for the downloaded file. |
ContentEncoding |
Specifies what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field. For directory buckets, only the |
ContentLanguage |
The language the content is in. |
ContentType |
A standard MIME type that describes the format of the object data. |
CopySource |
[required] Specifies the source object for the copy operation. The source object can be up to 5 GB. If the source object is an object that was uploaded by using a multipart upload, the object copy will be a single part object after the source object is copied to the destination bucket. You specify the value of the copy source in one of two formats, depending on whether you want to access the source object through an access point:
If your source bucket versioning is enabled, the If you enable versioning on the destination bucket, Amazon S3 generates a unique version ID for the copied object. This version ID is different from the version ID of the source object. Amazon S3 returns the version ID of the copied object in the If you do not enable versioning or suspend it on the destination bucket, the version ID that Amazon S3 generates in the Directory buckets - S3 Versioning isn't enabled and supported for directory buckets. |
CopySourceIfMatch |
Copies the object if its entity tag (ETag) matches the specified tag. If both the
|
CopySourceIfModifiedSince |
Copies the object if it has been modified since the specified time. If both the
|
CopySourceIfNoneMatch |
Copies the object if its entity tag (ETag) is different than the specified ETag. If both the
|
CopySourceIfUnmodifiedSince |
Copies the object if it hasn't been modified since the specified time. If both the
|
Expires |
The date and time at which the object is no longer cacheable. |
GrantFullControl |
Gives the grantee READ, READ_ACP, and WRITE_ACP permissions on the object.
|
GrantRead |
Allows grantee to read the object data and its metadata.
|
GrantReadACP |
Allows grantee to read the object ACL.
|
GrantWriteACP |
Allows grantee to write the ACL for the applicable object.
|
IfMatch |
Copies the object if the entity tag (ETag) of the destination object matches the specified tag. If the ETag values do not match, the operation returns a Expects the ETag value as a string. For more information about conditional requests, see RFC 7232. |
IfNoneMatch |
Copies the object only if the object key name at the destination does not already exist in the bucket specified. Otherwise, Amazon S3 returns a Expects the '*' (asterisk) character. For more information about conditional requests, see RFC 7232. |
Key |
[required] The key of the destination object. |
Metadata |
A map of metadata to store with the object in S3. |
MetadataDirective |
Specifies whether the metadata is copied from the source object or replaced with metadata that's provided in the request. When copying an object, you can preserve all metadata (the default) or specify new metadata. If this header isn’t specified, General purpose bucket - For general purpose buckets, when you grant permissions, you can use the
|
TaggingDirective |
Specifies whether the object tag-set is copied from the source object or replaced with the tag-set that's provided in the request. The default value is Directory buckets - For directory buckets in a
Because only the empty tag-set is supported for directory buckets in a
|
ServerSideEncryption |
The server-side encryption algorithm used when storing this object in Amazon S3. Unrecognized or unsupported values won’t write a destination object and will receive a Amazon S3 automatically encrypts all new objects that are copied to an S3 bucket. When copying an object, if you don't specify encryption information in your copy request, the encryption setting of the target object is set to the default encryption configuration of the destination bucket. By default, all buckets have a base level of encryption configuration that uses server-side encryption with Amazon S3 managed keys (SSE-S3). If the destination bucket has a different default encryption configuration, Amazon S3 uses the corresponding encryption key to encrypt the target object copy. With server-side encryption, Amazon S3 encrypts your data as it writes your data to disks in its data centers and decrypts the data when you access it. For more information about server-side encryption, see Using Server-Side Encryption in the Amazon S3 User Guide. General purpose buckets
Directory buckets
|
StorageClass |
If the
You can use the Before using an object as a source object for the copy operation, you must restore a copy of it if it meets any of the following conditions:
For more information, see |
WebsiteRedirectLocation |
If the destination bucket is configured as a website, redirects requests for this object copy to another object in the same bucket or to an external URL. Amazon S3 stores the value of this header in the object metadata. This value is unique to each object and is not copied when using the This functionality is not supported for directory buckets. |
SSECustomerAlgorithm |
Specifies the algorithm to use when encrypting the object (for example, When you perform a This functionality is not supported when the destination bucket is a directory bucket. |
SSECustomerKey |
Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded. Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the This functionality is not supported when the destination bucket is a directory bucket. |
SSECustomerKeyMD5 |
Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. This functionality is not supported when the destination bucket is a directory bucket. |
SSEKMSKeyId |
Specifies the KMS key ID (Key ID, Key ARN, or Key Alias) to use for object encryption. All GET and PUT requests for an object protected by KMS will fail if they're not made via SSL or using SigV4. For information about configuring any of the officially supported Amazon Web Services SDKs and Amazon Web Services CLI, see Specifying the Signature Version in Request Authentication in the Amazon S3 User Guide. Directory buckets - To encrypt data using SSE-KMS, it's recommended to specify the |
SSEKMSEncryptionContext |
Specifies the Amazon Web Services KMS Encryption Context as an additional encryption context to use for the destination object encryption. The value of this header is a base64-encoded UTF-8 string holding JSON with the encryption context key-value pairs. General purpose buckets - This value must be explicitly added to specify encryption context for Directory buckets - You can optionally provide an explicit encryption context value. The value must match the default encryption context - the bucket Amazon Resource Name (ARN). An additional encryption context value is not supported. |
BucketKeyEnabled |
Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using Key Management Service (KMS) keys (SSE-KMS). If a target object uses SSE-KMS, you can enable an S3 Bucket Key for the object. Setting this header to For more information, see Amazon S3 Bucket Keys in the Amazon S3 User Guide. Directory buckets - S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through |
CopySourceSSECustomerAlgorithm |
Specifies the algorithm to use when decrypting the source object (for example, If the source object for the copy is stored in Amazon S3 using SSE-C, you must provide the necessary encryption information in your request so that Amazon S3 can decrypt the object for copying. This functionality is not supported when the source object is in a directory bucket. |
CopySourceSSECustomerKey |
Specifies the customer-provided encryption key for Amazon S3 to use to decrypt the source object. The encryption key provided in this header must be the same one that was used when the source object was created. If the source object for the copy is stored in Amazon S3 using SSE-C, you must provide the necessary encryption information in your request so that Amazon S3 can decrypt the object for copying. This functionality is not supported when the source object is in a directory bucket. |
CopySourceSSECustomerKeyMD5 |
Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. If the source object for the copy is stored in Amazon S3 using SSE-C, you must provide the necessary encryption information in your request so that Amazon S3 can decrypt the object for copying. This functionality is not supported when the source object is in a directory bucket. |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
Tagging |
The tag-set for the object copy in the destination bucket. This value must be used in conjunction with the The default value is the empty value. Directory buckets - For directory buckets in a
Because only the empty tag-set is supported for directory buckets in a
|
ObjectLockMode |
The Object Lock mode that you want to apply to the object copy. This functionality is not supported for directory buckets. |
ObjectLockRetainUntilDate |
The date and time when you want the Object Lock of the object copy to expire. This functionality is not supported for directory buckets. |
ObjectLockLegalHoldStatus |
Specifies whether you want to apply a legal hold to the object copy. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected destination bucket owner. If the account ID that you provide does not match the actual owner of the destination bucket, the request fails with the HTTP status code |
ExpectedSourceBucketOwner |
The account ID of the expected source bucket owner. If the account ID that you provide does not match the actual owner of the source bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.