s3_create_bucket: This action creates an Amazon S3 bucket

View source: R/s3_operations.R

s3_create_bucketR Documentation

This action creates an Amazon S3 bucket

Description

This action creates an Amazon S3 bucket. To create an Amazon S3 on Outposts bucket, see create_bucket .

See https://www.paws-r-sdk.com/docs/s3_create_bucket/ for full documentation.

Usage

s3_create_bucket(
  ACL = NULL,
  Bucket,
  CreateBucketConfiguration = NULL,
  GrantFullControl = NULL,
  GrantRead = NULL,
  GrantReadACP = NULL,
  GrantWrite = NULL,
  GrantWriteACP = NULL,
  ObjectLockEnabledForBucket = NULL,
  ObjectOwnership = NULL,
  BucketNamespace = NULL
)

Arguments

ACL

The canned ACL to apply to the bucket.

This functionality is not supported for directory buckets.

Bucket

[required] The name of the bucket to create.

General purpose buckets - For information about bucket naming restrictions, see Bucket naming rules in the Amazon S3 User Guide.

Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ⁠https://s3express-control.region-code.amazonaws.com/bucket-name ⁠. Virtual-hosted-style requests aren't supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide

CreateBucketConfiguration

The configuration information for the bucket.

GrantFullControl

Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.

This functionality is not supported for directory buckets.

GrantRead

Allows grantee to list the objects in the bucket.

This functionality is not supported for directory buckets.

GrantReadACP

Allows grantee to read the bucket ACL.

This functionality is not supported for directory buckets.

GrantWrite

Allows grantee to create new objects in the bucket.

For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.

This functionality is not supported for directory buckets.

GrantWriteACP

Allows grantee to write the ACL for the applicable bucket.

This functionality is not supported for directory buckets.

ObjectLockEnabledForBucket

Specifies whether you want S3 Object Lock to be enabled for the new bucket.

This functionality is not supported for directory buckets.

ObjectOwnership

The container element for object ownership for a bucket's ownership controls.

BucketOwnerPreferred - Objects uploaded to the bucket change ownership to the bucket owner if the objects are uploaded with the bucket-owner-full-control canned ACL.

ObjectWriter - The uploading account will own the object if the object is uploaded with the bucket-owner-full-control canned ACL.

BucketOwnerEnforced - Access control lists (ACLs) are disabled and no longer affect permissions. The bucket owner automatically owns and has full control over every object in the bucket. The bucket only accepts PUT requests that don't specify an ACL or specify bucket owner full control ACLs (such as the predefined bucket-owner-full-control canned ACL or a custom ACL in XML format that grants the same permissions).

By default, ObjectOwnership is set to BucketOwnerEnforced and ACLs are disabled. We recommend keeping ACLs disabled, except in uncommon use cases where you must control access for each object individually. For more information about S3 Object Ownership, see Controlling ownership of objects and disabling ACLs for your bucket in the Amazon S3 User Guide.

This functionality is not supported for directory buckets. Directory buckets use the bucket owner enforced setting for S3 Object Ownership.

BucketNamespace

Specifies the namespace where you want to create your general purpose bucket. When you create a general purpose bucket, you can choose to create a bucket in the shared global namespace or you can choose to create a bucket in your account regional namespace. Your account regional namespace is a subdivision of the global namespace that only your account can create buckets in. For more information on bucket namespaces, see Namespaces for general purpose buckets.

General purpose buckets in your account regional namespace must follow a specific naming convention. These buckets consist of a bucket name prefix that you create, and a suffix that contains your 12-digit Amazon Web Services Account ID, the Amazon Web Services Region code, and ends with -an. Bucket names must follow the format bucket-name-prefix-accountId-region-an (for example, amzn-s3-demo-bucket-111122223333-us-west-2-an). For information about bucket naming restrictions, see Account regional namespace naming rules in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.


paws.storage documentation built on May 30, 2026, 9:13 a.m.