s3_create_bucket_metadata_table_configuration: We recommend that you create your S3 Metadata configurations...

View source: R/s3_operations.R

s3_create_bucket_metadata_table_configurationR Documentation

We recommend that you create your S3 Metadata configurations by using the V2 CreateBucketMetadataConfiguration API operation

Description

We recommend that you create your S3 Metadata configurations by using the V2 create_bucket_metadata_configuration API operation. We no longer recommend using the V1 create_bucket_metadata_table_configuration API operation.

See https://www.paws-r-sdk.com/docs/s3_create_bucket_metadata_table_configuration/ for full documentation.

Usage

s3_create_bucket_metadata_table_configuration(
  Bucket,
  ContentMD5 = NULL,
  ChecksumAlgorithm = NULL,
  MetadataTableConfiguration,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The general purpose bucket that you want to create the metadata table configuration for.

ContentMD5

The Content-MD5 header for the metadata table configuration.

ChecksumAlgorithm

The checksum algorithm to use with your metadata table configuration.

MetadataTableConfiguration

[required] The contents of your metadata table configuration.

ExpectedBucketOwner

The expected owner of the general purpose bucket that corresponds to your metadata table configuration.


paws.storage documentation built on May 30, 2026, 9:13 a.m.