View source: R/s3_operations.R
| s3_create_multipart_upload | R Documentation |
End of support notice: As of October 1, 2025, Amazon S3 has discontinued support for Email Grantee Access Control Lists (ACLs). If you attempt to use an Email Grantee ACL in a request after October 1, 2025, the request will receive an HTTP 405 (Method Not Allowed) error.
See https://www.paws-r-sdk.com/docs/s3_create_multipart_upload/ for full documentation.
s3_create_multipart_upload(
ACL = NULL,
Bucket,
CacheControl = NULL,
ContentDisposition = NULL,
ContentEncoding = NULL,
ContentLanguage = NULL,
ContentType = NULL,
Expires = NULL,
GrantFullControl = NULL,
GrantRead = NULL,
GrantReadACP = NULL,
GrantWriteACP = NULL,
Key,
Metadata = NULL,
ServerSideEncryption = NULL,
StorageClass = NULL,
WebsiteRedirectLocation = NULL,
SSECustomerAlgorithm = NULL,
SSECustomerKey = NULL,
SSECustomerKeyMD5 = NULL,
SSEKMSKeyId = NULL,
SSEKMSEncryptionContext = NULL,
BucketKeyEnabled = NULL,
RequestPayer = NULL,
Tagging = NULL,
ObjectLockMode = NULL,
ObjectLockRetainUntilDate = NULL,
ObjectLockLegalHoldStatus = NULL,
ExpectedBucketOwner = NULL,
ChecksumAlgorithm = NULL,
ChecksumType = NULL
)
ACL |
The canned ACL to apply to the object. Amazon S3 supports a set of predefined ACLs, known as canned ACLs. Each canned ACL has a predefined set of grantees and permissions. For more information, see Canned ACL in the Amazon S3 User Guide. By default, all objects are private. Only the owner has full access control. When uploading an object, you can grant access permissions to individual Amazon Web Services accounts or to predefined groups defined by Amazon S3. These permissions are then added to the access control list (ACL) on the new object. For more information, see Using ACLs. One way to grant the permissions using the request headers is to specify a canned ACL with the
|
Bucket |
[required] The name of the bucket where the multipart upload is initiated and where the object is uploaded. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
CacheControl |
Specifies caching behavior along the request/reply chain. |
ContentDisposition |
Specifies presentational information for the object. |
ContentEncoding |
Specifies what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field. For directory buckets, only the |
ContentLanguage |
The language that the content is in. |
ContentType |
A standard MIME type describing the format of the object data. |
Expires |
The date and time at which the object is no longer cacheable. |
GrantFullControl |
Specify access permissions explicitly to give the grantee READ, READ_ACP, and WRITE_ACP permissions on the object. By default, all objects are private. Only the owner has full access control. When uploading an object, you can use this header to explicitly grant access permissions to specific Amazon Web Services accounts or groups. This header maps to specific permissions that Amazon S3 supports in an ACL. For more information, see Access Control List (ACL) Overview in the Amazon S3 User Guide. You specify each grantee as a type=value pair, where the type is one of the following:
For example, the following
|
GrantRead |
Specify access permissions explicitly to allow grantee to read the object data and its metadata. By default, all objects are private. Only the owner has full access control. When uploading an object, you can use this header to explicitly grant access permissions to specific Amazon Web Services accounts or groups. This header maps to specific permissions that Amazon S3 supports in an ACL. For more information, see Access Control List (ACL) Overview in the Amazon S3 User Guide. You specify each grantee as a type=value pair, where the type is one of the following:
For example, the following
|
GrantReadACP |
Specify access permissions explicitly to allows grantee to read the object ACL. By default, all objects are private. Only the owner has full access control. When uploading an object, you can use this header to explicitly grant access permissions to specific Amazon Web Services accounts or groups. This header maps to specific permissions that Amazon S3 supports in an ACL. For more information, see Access Control List (ACL) Overview in the Amazon S3 User Guide. You specify each grantee as a type=value pair, where the type is one of the following:
For example, the following
|
GrantWriteACP |
Specify access permissions explicitly to allows grantee to allow grantee to write the ACL for the applicable object. By default, all objects are private. Only the owner has full access control. When uploading an object, you can use this header to explicitly grant access permissions to specific Amazon Web Services accounts or groups. This header maps to specific permissions that Amazon S3 supports in an ACL. For more information, see Access Control List (ACL) Overview in the Amazon S3 User Guide. You specify each grantee as a type=value pair, where the type is one of the following:
For example, the following
|
Key |
[required] Object key for which the multipart upload is to be initiated. |
Metadata |
A map of metadata to store with the object in S3. |
ServerSideEncryption |
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
|
StorageClass |
By default, Amazon S3 uses the STANDARD Storage Class to store newly created objects. The STANDARD storage class provides high durability and high availability. Depending on performance needs, you can specify a different Storage Class. For more information, see Storage Classes in the Amazon S3 User Guide.
|
WebsiteRedirectLocation |
If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Amazon S3 stores the value of this header in the object metadata. This functionality is not supported for directory buckets. |
SSECustomerAlgorithm |
Specifies the algorithm to use when encrypting the object (for example, AES256). This functionality is not supported for directory buckets. |
SSECustomerKey |
Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the This functionality is not supported for directory buckets. |
SSECustomerKeyMD5 |
Specifies the 128-bit MD5 digest of the customer-provided encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. This functionality is not supported for directory buckets. |
SSEKMSKeyId |
Specifies the KMS key ID (Key ID, Key ARN, or Key Alias) to use for object encryption. If the KMS key doesn't exist in the same account that's issuing the command, you must use the full Key ARN not the Key ID. General purpose buckets - If you specify Directory buckets - To encrypt data using SSE-KMS, it's recommended to specify the |
SSEKMSEncryptionContext |
Specifies the Amazon Web Services KMS Encryption Context to use for object encryption. The value of this header is a Base64 encoded string of a UTF-8 encoded JSON, which contains the encryption context as key-value pairs. Directory buckets - You can optionally provide an explicit encryption context value. The value must match the default encryption context - the bucket Amazon Resource Name (ARN). An additional encryption context value is not supported. |
BucketKeyEnabled |
Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using Key Management Service (KMS) keys (SSE-KMS). General purpose buckets - Setting this header to Directory buckets - S3 Bucket Keys are always enabled for |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
Tagging |
The tag-set for the object. The tag-set must be encoded as URL Query parameters. This functionality is not supported for directory buckets. |
ObjectLockMode |
Specifies the Object Lock mode that you want to apply to the uploaded object. This functionality is not supported for directory buckets. |
ObjectLockRetainUntilDate |
Specifies the date and time when you want the Object Lock to expire. This functionality is not supported for directory buckets. |
ObjectLockLegalHoldStatus |
Specifies whether you want to apply a legal hold to the uploaded object. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
ChecksumAlgorithm |
Indicates the algorithm that you want Amazon S3 to use to create the checksum for the object. For more information, see Checking object integrity in the Amazon S3 User Guide. |
ChecksumType |
Indicates the checksum type that you want Amazon S3 to use to calculate the object’s checksum value. For more information, see Checking object integrity in the Amazon S3 User Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.