View source: R/s3_operations.R
| s3_create_session | R Documentation |
Creates a session that establishes temporary security credentials to support fast authentication and authorization for the Zonal endpoint API operations on directory buckets. For more information about Zonal endpoint API operations that include the Availability Zone in the request endpoint, see S3 Express One Zone APIs in the Amazon S3 User Guide.
See https://www.paws-r-sdk.com/docs/s3_create_session/ for full documentation.
s3_create_session(
SessionMode = NULL,
Bucket,
ServerSideEncryption = NULL,
SSEKMSKeyId = NULL,
SSEKMSEncryptionContext = NULL,
BucketKeyEnabled = NULL
)
SessionMode |
Specifies the mode of the session that will be created, either |
Bucket |
[required] The name of the bucket that you create a session for. |
ServerSideEncryption |
The server-side encryption algorithm to use when you store objects in the directory bucket. For directory buckets, there are only two supported options for server-side encryption: server-side encryption with Amazon S3 managed keys (SSE-S3) ( S3 access points for Amazon FSx - When accessing data stored in Amazon FSx file systems using S3 access points, the only valid server side encryption option is |
SSEKMSKeyId |
If you specify Your SSE-KMS configuration can only support 1 customer managed key per directory bucket's lifetime. The Amazon Web Services managed key ( |
SSEKMSEncryptionContext |
Specifies the Amazon Web Services KMS Encryption Context as an additional encryption context to use for object encryption. The value of this header is a Base64 encoded string of a UTF-8 encoded JSON, which contains the encryption context as key-value pairs. This value is stored as object metadata and automatically gets passed on to Amazon Web Services KMS for future General purpose buckets - This value must be explicitly added during Directory buckets - You can optionally provide an explicit encryption context value. The value must match the default encryption context - the bucket Amazon Resource Name (ARN). An additional encryption context value is not supported. |
BucketKeyEnabled |
Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using KMS keys (SSE-KMS). S3 Bucket Keys are always enabled for |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.