View source: R/s3_operations.R
| s3_delete_bucket_analytics_configuration | R Documentation |
This operation is not supported for directory buckets.
See https://www.paws-r-sdk.com/docs/s3_delete_bucket_analytics_configuration/ for full documentation.
s3_delete_bucket_analytics_configuration(
Bucket,
Id,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket from which an analytics configuration is deleted. |
Id |
[required] The ID that identifies the analytics configuration. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.