View source: R/s3_operations.R
| s3_delete_bucket_encryption | R Documentation |
This implementation of the DELETE action resets the default encryption for the bucket as server-side encryption with Amazon S3 managed keys (SSE-S3).
See https://www.paws-r-sdk.com/docs/s3_delete_bucket_encryption/ for full documentation.
s3_delete_bucket_encryption(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The name of the bucket containing the server-side encryption configuration to delete. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.