s3_delete_bucket_inventory_configuration: Deletes an S3 Inventory configuration (identified by the...

View source: R/s3_operations.R

s3_delete_bucket_inventory_configurationR Documentation

Deletes an S3 Inventory configuration (identified by the inventory ID) from the bucket

Description

Deletes an S3 Inventory configuration (identified by the inventory ID) from the bucket.

See https://www.paws-r-sdk.com/docs/s3_delete_bucket_inventory_configuration/ for full documentation.

Usage

s3_delete_bucket_inventory_configuration(
  Bucket,
  Id,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The name of the bucket containing the inventory configuration to delete.

Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ⁠https://s3express-control.region-code.amazonaws.com/bucket-name ⁠. Virtual-hosted-style requests aren't supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide

Id

[required] The ID used to identify the inventory configuration.

ExpectedBucketOwner

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ⁠403 Forbidden⁠ (access denied).

For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code ⁠501 Not Implemented⁠.


paws.storage documentation built on May 30, 2026, 9:13 a.m.