View source: R/s3_operations.R
| s3_delete_bucket_lifecycle | R Documentation |
Deletes the lifecycle configuration from the specified bucket. Amazon S3 removes all the lifecycle configuration rules in the lifecycle subresource associated with the bucket. Your objects never expire, and Amazon S3 no longer automatically deletes any objects on the basis of rules contained in the deleted lifecycle configuration.
See https://www.paws-r-sdk.com/docs/s3_delete_bucket_lifecycle/ for full documentation.
s3_delete_bucket_lifecycle(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The bucket name of the lifecycle to delete. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.