s3_delete_bucket_metadata_table_configuration: We recommend that you delete your S3 Metadata configurations...

View source: R/s3_operations.R

s3_delete_bucket_metadata_table_configurationR Documentation

We recommend that you delete your S3 Metadata configurations by using the V2 DeleteBucketMetadataTableConfiguration API operation

Description

We recommend that you delete your S3 Metadata configurations by using the V2 delete_bucket_metadata_table_configuration API operation. We no longer recommend using the V1 delete_bucket_metadata_table_configuration API operation.

See https://www.paws-r-sdk.com/docs/s3_delete_bucket_metadata_table_configuration/ for full documentation.

Usage

s3_delete_bucket_metadata_table_configuration(
  Bucket,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The general purpose bucket that you want to remove the metadata table configuration from.

ExpectedBucketOwner

The expected bucket owner of the general purpose bucket that you want to remove the metadata table configuration from.


paws.storage documentation built on May 30, 2026, 9:13 a.m.