View source: R/s3_operations.R
| s3_delete_bucket_metrics_configuration | R Documentation |
Deletes a metrics configuration for the Amazon CloudWatch request metrics (specified by the metrics configuration ID) from the bucket. Note that this doesn't include the daily storage metrics.
See https://www.paws-r-sdk.com/docs/s3_delete_bucket_metrics_configuration/ for full documentation.
s3_delete_bucket_metrics_configuration(Bucket, Id, ExpectedBucketOwner = NULL)
Bucket |
[required] The name of the bucket containing the metrics configuration to delete. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
Id |
[required] The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.