View source: R/s3_operations.R
| s3_delete_object | R Documentation |
Removes an object from a bucket. The behavior depends on the bucket's versioning state:
See https://www.paws-r-sdk.com/docs/s3_delete_object/ for full documentation.
s3_delete_object(
Bucket,
Key,
MFA = NULL,
VersionId = NULL,
RequestPayer = NULL,
BypassGovernanceRetention = NULL,
ExpectedBucketOwner = NULL,
IfMatch = NULL,
IfMatchLastModifiedTime = NULL,
IfMatchSize = NULL
)
Bucket |
[required] The bucket name of the bucket containing the object. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
Key |
[required] Key name of the object to delete. |
MFA |
The concatenation of the authentication device's serial number, a space, and the value that is displayed on your authentication device. Required to permanently delete a versioned object if versioning is configured with MFA delete enabled. This functionality is not supported for directory buckets. |
VersionId |
Version ID used to reference a specific version of the object. For directory buckets in this API operation, only the |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
BypassGovernanceRetention |
Indicates whether S3 Object Lock should bypass Governance-mode restrictions to process this operation. To use this header, you must have the This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
IfMatch |
Deletes the object if the ETag (entity tag) value provided during the delete operation matches the ETag of the object in S3. If the ETag values do not match, the operation returns a Expects the ETag value as a string. For more information about conditional requests, see RFC 7232. |
IfMatchLastModifiedTime |
If present, the object is deleted only if its modification times matches the provided This functionality is only supported for directory buckets. |
IfMatchSize |
If present, the object is deleted only if its size matches the provided size in bytes. If the This functionality is only supported for directory buckets. You can use the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.