View source: R/s3_operations.R
| s3_delete_objects | R Documentation |
This operation enables you to delete multiple objects from a bucket using a single HTTP request. If you know the object keys that you want to delete, then this operation provides a suitable alternative to sending individual delete requests, reducing per-request overhead.
See https://www.paws-r-sdk.com/docs/s3_delete_objects/ for full documentation.
s3_delete_objects(
Bucket,
Delete,
MFA = NULL,
RequestPayer = NULL,
BypassGovernanceRetention = NULL,
ExpectedBucketOwner = NULL,
ChecksumAlgorithm = NULL
)
Bucket |
[required] The bucket name containing the objects to delete. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
Delete |
[required] Container for the request. |
MFA |
The concatenation of the authentication device's serial number, a space, and the value that is displayed on your authentication device. Required to permanently delete a versioned object if versioning is configured with MFA delete enabled. When performing the This functionality is not supported for directory buckets. |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
BypassGovernanceRetention |
Specifies whether you want to delete this object even if it has a Governance-type Object Lock in place. To use this header, you must have the This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding For the
For more information, see Checking object integrity in the Amazon S3 User Guide. If the individual checksum value you provide through If you provide an individual checksum, Amazon S3 ignores any provided |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.