This implementation of the GET action uses the acl subresource to return the access control list (ACL) of a bucket. To use GET to return the ACL of the bucket, you must have READ_ACP access to the bucket. If READ_ACP permission is granted to the anonymous user, you can return the ACL of the bucket without using an authorization header.
See https://www.paws-r-sdk.com/docs/s3_get_bucket_acl/ for full documentation.
s3_get_bucket_acl(Bucket, ExpectedBucketOwner = NULL)[required] Specifies the S3 bucket whose ACL is being requested.
To use this API operation against an access point, provide the alias of the access point in place of the bucket name.
To use this API operation against an Object Lambda access point, provide
the alias of the Object Lambda access point in place of the bucket name.
If the Object Lambda access point alias in a request is not valid, the
error code InvalidAccessPointAliasError is returned. For more
information about InvalidAccessPointAliasError, see List of Error Codes.
The account ID of the expected bucket owner. If the bucket is owned by a
different account, the request fails with the HTTP status code
403 Forbidden (access denied).