s3_get_bucket_lifecycle_configuration: Returns the lifecycle configuration information set on the...

View source: R/s3_operations.R

s3_get_bucket_lifecycle_configurationR Documentation

Returns the lifecycle configuration information set on the bucket

Description

Returns the lifecycle configuration information set on the bucket. For information about lifecycle configuration, see Object Lifecycle Management.

See https://www.paws-r-sdk.com/docs/s3_get_bucket_lifecycle_configuration/ for full documentation.

Usage

s3_get_bucket_lifecycle_configuration(Bucket, ExpectedBucketOwner = NULL)

Arguments

Bucket

[required] The name of the bucket for which to get the lifecycle information.

ExpectedBucketOwner

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ⁠403 Forbidden⁠ (access denied).

This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.


paws.storage documentation built on May 30, 2026, 9:13 a.m.