View source: R/s3_operations.R
| s3_get_bucket_location | R Documentation |
Using the get_bucket_location operation is no longer a best practice. To return the Region that a bucket resides in, we recommend that you use the head_bucket operation instead. For backward compatibility, Amazon S3 continues to support the get_bucket_location operation.
See https://www.paws-r-sdk.com/docs/s3_get_bucket_location/ for full documentation.
s3_get_bucket_location(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The name of the bucket for which to get the location. When you use this API operation with an access point, provide the alias of the access point in place of the bucket name. When you use this API operation with an Object Lambda access point, provide the alias of the Object Lambda access point in place of the bucket name. If the Object Lambda access point alias in a request is not valid, the error code |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.