s3_get_bucket_metadata_configuration: Retrieves the S3 Metadata configuration for a general purpose...

View source: R/s3_operations.R

s3_get_bucket_metadata_configurationR Documentation

Retrieves the S3 Metadata configuration for a general purpose bucket

Description

Retrieves the S3 Metadata configuration for a general purpose bucket. For more information, see Accelerating data discovery with S3 Metadata in the Amazon S3 User Guide.

See https://www.paws-r-sdk.com/docs/s3_get_bucket_metadata_configuration/ for full documentation.

Usage

s3_get_bucket_metadata_configuration(Bucket, ExpectedBucketOwner = NULL)

Arguments

Bucket

[required] The general purpose bucket that corresponds to the metadata configuration that you want to retrieve.

ExpectedBucketOwner

The expected owner of the general purpose bucket that you want to retrieve the metadata table configuration for.


paws.storage documentation built on May 30, 2026, 9:13 a.m.