View source: R/s3_operations.R
| s3_get_bucket_policy | R Documentation |
Returns the policy of a specified bucket.
See https://www.paws-r-sdk.com/docs/s3_get_bucket_policy/ for full documentation.
s3_get_bucket_policy(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The bucket name to get the bucket policy for. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format Access points - When you use this API operation with an access point, provide the alias of the access point in place of the bucket name. Object Lambda access points - When you use this API operation with an Object Lambda access point, provide the alias of the Object Lambda access point in place of the bucket name. If the Object Lambda access point alias in a request is not valid, the error code Object Lambda access points are not supported by directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.