s3_get_object_acl: This operation is not supported for directory buckets

View source: R/s3_operations.R

s3_get_object_aclR Documentation

This operation is not supported for directory buckets

Description

This operation is not supported for directory buckets.

See https://www.paws-r-sdk.com/docs/s3_get_object_acl/ for full documentation.

Usage

s3_get_object_acl(
  Bucket,
  Key,
  VersionId = NULL,
  RequestPayer = NULL,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The bucket name that contains the object for which to get the ACL information.

Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.

Key

[required] The key of the object for which to get the ACL information.

VersionId

Version ID used to reference a specific version of the object.

This functionality is not supported for directory buckets.

RequestPayer

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

ExpectedBucketOwner

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ⁠403 Forbidden⁠ (access denied).


paws.storage documentation built on May 30, 2026, 9:13 a.m.