s3_get_object_annotation: Retrieves an annotation from an Amazon S3 object

View source: R/s3_operations.R

s3_get_object_annotationR Documentation

Retrieves an annotation from an Amazon S3 object

Description

Retrieves an annotation from an Amazon S3 object. To use this operation, you must have the s3:GetObjectAnnotation permission.

See https://www.paws-r-sdk.com/docs/s3_get_object_annotation/ for full documentation.

Usage

s3_get_object_annotation(
  Bucket,
  Key,
  AnnotationName,
  VersionId = NULL,
  RequestPayer = NULL,
  ExpectedBucketOwner = NULL,
  ChecksumMode = NULL
)

Arguments

Bucket

[required] The name of the bucket that contains the object.

Key

[required] The object key.

AnnotationName

[required] The name of the annotation to retrieve.

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

VersionId

The version ID of the object.

RequestPayer

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

ExpectedBucketOwner

The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.

ChecksumMode

Set to ENABLED to validate the checksum of the annotation payload on retrieval.


paws.storage documentation built on Oct. 8, 2026, 9:17 a.m.