View source: R/s3_operations.R
| s3_head_object | R Documentation |
The HEAD operation retrieves metadata from an object without returning the object itself. This operation is useful if you're interested only in an object's metadata.
See https://www.paws-r-sdk.com/docs/s3_head_object/ for full documentation.
s3_head_object(
Bucket,
IfMatch = NULL,
IfModifiedSince = NULL,
IfNoneMatch = NULL,
IfUnmodifiedSince = NULL,
Key,
Range = NULL,
ResponseCacheControl = NULL,
ResponseContentDisposition = NULL,
ResponseContentEncoding = NULL,
ResponseContentLanguage = NULL,
ResponseContentType = NULL,
ResponseExpires = NULL,
VersionId = NULL,
SSECustomerAlgorithm = NULL,
SSECustomerKey = NULL,
SSECustomerKeyMD5 = NULL,
RequestPayer = NULL,
PartNumber = NULL,
ExpectedBucketOwner = NULL,
ChecksumMode = NULL
)
Bucket |
[required] The name of the bucket that contains the object. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
IfMatch |
Return the object only if its entity tag (ETag) is the same as the one specified; otherwise, return a 412 (precondition failed) error. If both of the
Then Amazon S3 returns For more information about conditional requests, see RFC 7232. |
IfModifiedSince |
Return the object only if it has been modified since the specified time; otherwise, return a 304 (not modified) error. If both of the
Then Amazon S3 returns the For more information about conditional requests, see RFC 7232. |
IfNoneMatch |
Return the object only if its entity tag (ETag) is different from the one specified; otherwise, return a 304 (not modified) error. If both of the
Then Amazon S3 returns the For more information about conditional requests, see RFC 7232. |
IfUnmodifiedSince |
Return the object only if it has not been modified since the specified time; otherwise, return a 412 (precondition failed) error. If both of the
Then Amazon S3 returns For more information about conditional requests, see RFC 7232. |
Key |
[required] The object key. |
Range |
HeadObject returns only the metadata for an object. If the Range is satisfiable, only the |
ResponseCacheControl |
Sets the |
ResponseContentDisposition |
Sets the |
ResponseContentEncoding |
Sets the |
ResponseContentLanguage |
Sets the |
ResponseContentType |
Sets the |
ResponseExpires |
Sets the |
VersionId |
Version ID used to reference a specific version of the object. For directory buckets in this API operation, only the |
SSECustomerAlgorithm |
Specifies the algorithm to use when encrypting the object (for example, AES256). This functionality is not supported for directory buckets. |
SSECustomerKey |
Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the This functionality is not supported for directory buckets. |
SSECustomerKeyMD5 |
Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. This functionality is not supported for directory buckets. |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
PartNumber |
Part number of the object being read. This is a positive integer between 1 and 10,000. Effectively performs a 'ranged' HEAD request for the part specified. Useful querying about the size of the part and the number of parts in this object. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
ChecksumMode |
To retrieve the checksum, this parameter must be enabled. General purpose buckets - If you enable checksum mode and the object is uploaded with a checksum and encrypted with an Key Management Service (KMS) key, you must have permission to use the Directory buckets - If you enable |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.