s3_list_bucket_metrics_configurations: Lists the metrics configurations for the bucket

View source: R/s3_operations.R

s3_list_bucket_metrics_configurationsR Documentation

Lists the metrics configurations for the bucket

Description

Lists the metrics configurations for the bucket. The metrics configurations are only for the request metrics of the bucket and do not provide information on daily storage metrics. You can have up to 1,000 configurations per bucket.

See https://www.paws-r-sdk.com/docs/s3_list_bucket_metrics_configurations/ for full documentation.

Usage

s3_list_bucket_metrics_configurations(
  Bucket,
  ContinuationToken = NULL,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The name of the bucket containing the metrics configurations to retrieve.

Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ⁠https://s3express-control.region-code.amazonaws.com/bucket-name ⁠. Virtual-hosted-style requests aren't supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide

ContinuationToken

The marker that is used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.

ExpectedBucketOwner

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ⁠403 Forbidden⁠ (access denied).

For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code ⁠501 Not Implemented⁠.


paws.storage documentation built on May 30, 2026, 9:13 a.m.