View source: R/s3_operations.R
| s3_list_object_annotations | R Documentation |
Lists the annotations attached to an Amazon S3 object. Results are paginated, with a maximum of 1,000 annotations per object. Use the AnnotationPrefix parameter to filter the results by name prefix.
See https://www.paws-r-sdk.com/docs/s3_list_object_annotations/ for full documentation.
s3_list_object_annotations(
Bucket,
Key,
VersionId = NULL,
MaxAnnotationResults = NULL,
AnnotationPrefix = NULL,
ContinuationToken = NULL,
RequestPayer = NULL,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket that contains the object. |
Key |
[required] The object key. |
VersionId |
The version ID of the object. |
MaxAnnotationResults |
The maximum number of annotations to return in the response. Maximum is 1,000. |
AnnotationPrefix |
Filter results to annotations whose name begins with the specified prefix. |
ContinuationToken |
Continuation token returned by a previous request to retrieve the next page. |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.