View source: R/s3_operations.R
| s3_list_objects | R Documentation |
This operation is not supported for directory buckets.
See https://www.paws-r-sdk.com/docs/s3_list_objects/ for full documentation.
s3_list_objects(
Bucket,
Delimiter = NULL,
EncodingType = NULL,
Marker = NULL,
MaxKeys = NULL,
Prefix = NULL,
RequestPayer = NULL,
ExpectedBucketOwner = NULL,
OptionalObjectAttributes = NULL
)
Bucket |
[required] The name of the bucket containing the objects. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
Delimiter |
A delimiter is a character that you use to group keys.
|
EncodingType |
Encoding type used by Amazon S3 to encode the object keys in the response. Responses are encoded only in UTF-8. An object key can contain any Unicode character. However, the XML 1.0 parser can't parse certain characters, such as characters with an ASCII value from 0 to 10. For characters that aren't supported in XML 1.0, you can add this parameter to request that Amazon S3 encode the keys in the response. For more information about characters to avoid in object key names, see Object key naming guidelines. When using the URL encoding type, non-ASCII characters that are used in an object's key name will be percent-encoded according to UTF-8 code values. For example, the object |
Marker |
Marker is where you want Amazon S3 to start listing from. Amazon S3 starts listing after this specified key. Marker can be any key in the bucket. |
MaxKeys |
Sets the maximum number of keys returned in the response. By default, the action returns up to 1,000 key names. The response might contain fewer keys but will never contain more. |
Prefix |
Limits the response to keys that begin with the specified prefix. |
RequestPayer |
Confirms that the requester knows that she or he will be charged for the list objects request. Bucket owners need not specify this parameter in their requests. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
OptionalObjectAttributes |
Specifies the optional fields that you want returned in the response. Fields that you do not specify are not returned. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.