View source: R/s3_operations.R
| s3_put_bucket_acl | R Documentation |
End of support notice: As of October 1, 2025, Amazon S3 has discontinued support for Email Grantee Access Control Lists (ACLs). If you attempt to use an Email Grantee ACL in a request after October 1, 2025, the request will receive an HTTP 405 (Method Not Allowed) error.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_acl/ for full documentation.
s3_put_bucket_acl(
ACL = NULL,
AccessControlPolicy = NULL,
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
GrantFullControl = NULL,
GrantRead = NULL,
GrantReadACP = NULL,
GrantWrite = NULL,
GrantWriteACP = NULL,
ExpectedBucketOwner = NULL
)
ACL |
The canned ACL to apply to the bucket. |
AccessControlPolicy |
Contains the elements that set the ACL permissions for an object per grantee. |
Bucket |
[required] The bucket to which to apply the ACL. |
ContentMD5 |
The Base64 encoded 128-bit For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding If you provide an individual checksum, Amazon S3 ignores any provided |
GrantFullControl |
Allows grantee the read, write, read ACP, and write ACP permissions on the bucket. |
GrantRead |
Allows grantee to list the objects in the bucket. |
GrantReadACP |
Allows grantee to read the bucket ACL. |
GrantWrite |
Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects. |
GrantWriteACP |
Allows grantee to write the ACL for the applicable bucket. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.