View source: R/s3_operations.R
| s3_put_bucket_encryption | R Documentation |
This operation configures default encryption and Amazon S3 Bucket Keys for an existing bucket. You can also block encryption types using this operation.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_encryption/ for full documentation.
s3_put_bucket_encryption(
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
ServerSideEncryptionConfiguration,
ExpectedBucketOwner = NULL
)
Bucket |
[required] Specifies default encryption for a bucket using server-side encryption with different key options. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
ContentMD5 |
The Base64 encoded 128-bit For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically. This functionality is not supported for directory buckets. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding If you provide an individual checksum, Amazon S3 ignores any provided For directory buckets, when you use Amazon Web Services SDKs, |
ServerSideEncryptionConfiguration |
[required] Specifies the default server-side-encryption configuration. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.