View source: R/s3_operations.R
| s3_put_bucket_lifecycle_configuration | R Documentation |
Creates a new lifecycle configuration for the bucket or replaces an existing lifecycle configuration. Keep in mind that this will overwrite an existing lifecycle configuration, so if you want to retain any configuration details, they must be included in the new lifecycle configuration. For information about lifecycle configuration, see Managing your storage lifecycle.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_lifecycle_configuration/ for full documentation.
s3_put_bucket_lifecycle_configuration(
Bucket,
ChecksumAlgorithm = NULL,
LifecycleConfiguration = NULL,
ExpectedBucketOwner = NULL,
TransitionDefaultMinimumObjectSize = NULL
)
Bucket |
[required] The name of the bucket for which to set the configuration. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding If you provide an individual checksum, Amazon S3 ignores any provided |
LifecycleConfiguration |
Container for lifecycle rules. You can add as many as 1,000 rules. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations. |
TransitionDefaultMinimumObjectSize |
Indicates which default minimum object size behavior is applied to the lifecycle configuration. This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
To customize the minimum object size for any transition you can add a filter that specifies a custom |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.