View source: R/s3_operations.R
| s3_put_bucket_logging | R Documentation |
End of support notice: As of October 1, 2025, Amazon S3 has discontinued support for Email Grantee Access Control Lists (ACLs). If you attempt to use an Email Grantee ACL in a request after October 1, 2025, the request will receive an HTTP 405 (Method Not Allowed) error.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_logging/ for full documentation.
s3_put_bucket_logging(
Bucket,
BucketLoggingStatus,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket for which to set the logging parameters. |
BucketLoggingStatus |
[required] Container for logging status information. |
ContentMD5 |
The MD5 hash of the For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding If you provide an individual checksum, Amazon S3 ignores any provided |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.