s3_put_bucket_metrics_configuration: Sets a metrics configuration (specified by the metrics...

View source: R/s3_operations.R

s3_put_bucket_metrics_configurationR Documentation

Sets a metrics configuration (specified by the metrics configuration ID) for the bucket

Description

Sets a metrics configuration (specified by the metrics configuration ID) for the bucket. You can have up to 1,000 metrics configurations per bucket. If you're updating an existing metrics configuration, note that this is a full replacement of the existing metrics configuration. If you don't include the elements you want to keep, they are erased.

See https://www.paws-r-sdk.com/docs/s3_put_bucket_metrics_configuration/ for full documentation.

Usage

s3_put_bucket_metrics_configuration(
  Bucket,
  Id,
  MetricsConfiguration,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The name of the bucket for which the metrics configuration is set.

Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ⁠https://s3express-control.region-code.amazonaws.com/bucket-name ⁠. Virtual-hosted-style requests aren't supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide

Id

[required] The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.

MetricsConfiguration

[required] Specifies the metrics configuration.

ExpectedBucketOwner

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ⁠403 Forbidden⁠ (access denied).

For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code ⁠501 Not Implemented⁠.


paws.storage documentation built on May 30, 2026, 9:13 a.m.