Creates or modifies OwnershipControls for an Amazon S3 bucket. To use this operation, you must have the s3:PutBucketOwnershipControls permission. For more information about Amazon S3 permissions, see Specifying permissions in a policy.
See https://paws-r.github.io/docs/s3/put_bucket_ownership_controls.html for full documentation.
s3_put_bucket_ownership_controls(
Bucket,
ContentMD5 = NULL,
ExpectedBucketOwner = NULL,
OwnershipControls
)[required] The name of the Amazon S3 bucket whose OwnershipControls you want to
set.
The MD5 hash of the OwnershipControls request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
The account ID of the expected bucket owner. If the bucket is owned by a
different account, the request fails with the HTTP status code
403 Forbidden (access denied).
[required] The OwnershipControls (BucketOwnerEnforced, BucketOwnerPreferred, or
ObjectWriter) that you want to apply to this Amazon S3 bucket.