View source: R/s3_operations.R
| s3_put_bucket_policy | R Documentation |
Applies an Amazon S3 bucket policy to an Amazon S3 bucket.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_policy/ for full documentation.
s3_put_bucket_policy(
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
ConfirmRemoveSelfBucketAccess = NULL,
Policy,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
ContentMD5 |
The MD5 hash of the request body. For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically. This functionality is not supported for directory buckets. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding For the
For more information, see Checking object integrity in the Amazon S3 User Guide. If the individual checksum value you provide through For directory buckets, when you use Amazon Web Services SDKs, |
ConfirmRemoveSelfBucketAccess |
Set this parameter to true to confirm that you want to remove your permissions to change this bucket policy in the future. This functionality is not supported for directory buckets. |
Policy |
[required] The bucket policy as a JSON document. For directory buckets, the only IAM action supported in the bucket policy is |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.