View source: R/s3_operations.R
| s3_put_bucket_replication | R Documentation |
This operation is not supported for directory buckets.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_replication/ for full documentation.
s3_put_bucket_replication(
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
ReplicationConfiguration,
Token = NULL,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket |
ContentMD5 |
The Base64 encoded 128-bit For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding If you provide an individual checksum, Amazon S3 ignores any provided |
ReplicationConfiguration |
[required] A container for replication rules. You can add up to 1,000 rules. The maximum size of a replication configuration is 2 MB. |
Token |
A token to allow Object Lock to be enabled for an existing bucket. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.