View source: R/s3_operations.R
| s3_put_object | R Documentation |
End of support notice: As of October 1, 2025, Amazon S3 has discontinued support for Email Grantee Access Control Lists (ACLs). If you attempt to use an Email Grantee ACL in a request after October 1, 2025, the request will receive an HTTP 405 (Method Not Allowed) error.
See https://www.paws-r-sdk.com/docs/s3_put_object/ for full documentation.
s3_put_object(
ACL = NULL,
Body = NULL,
Bucket,
CacheControl = NULL,
ContentDisposition = NULL,
ContentEncoding = NULL,
ContentLanguage = NULL,
ContentLength = NULL,
ContentMD5 = NULL,
ContentType = NULL,
ChecksumAlgorithm = NULL,
ChecksumCRC32 = NULL,
ChecksumCRC32C = NULL,
ChecksumCRC64NVME = NULL,
ChecksumSHA1 = NULL,
ChecksumSHA256 = NULL,
ChecksumSHA512 = NULL,
ChecksumMD5 = NULL,
ChecksumXXHASH64 = NULL,
ChecksumXXHASH3 = NULL,
ChecksumXXHASH128 = NULL,
Expires = NULL,
IfMatch = NULL,
IfNoneMatch = NULL,
GrantFullControl = NULL,
GrantRead = NULL,
GrantReadACP = NULL,
GrantWriteACP = NULL,
Key,
WriteOffsetBytes = NULL,
Metadata = NULL,
ServerSideEncryption = NULL,
StorageClass = NULL,
WebsiteRedirectLocation = NULL,
SSECustomerAlgorithm = NULL,
SSECustomerKey = NULL,
SSECustomerKeyMD5 = NULL,
SSEKMSKeyId = NULL,
SSEKMSEncryptionContext = NULL,
BucketKeyEnabled = NULL,
RequestPayer = NULL,
Tagging = NULL,
ObjectLockMode = NULL,
ObjectLockRetainUntilDate = NULL,
ObjectLockLegalHoldStatus = NULL,
ExpectedBucketOwner = NULL
)
ACL |
The canned ACL to apply to the object. For more information, see Canned ACL in the Amazon S3 User Guide. When adding a new object, you can use headers to grant ACL-based permissions to individual Amazon Web Services accounts or to predefined groups defined by Amazon S3. These permissions are then added to the ACL on the object. By default, all objects are private. Only the owner has full access control. For more information, see Access Control List (ACL) Overview and Managing ACLs Using the REST API in the Amazon S3 User Guide. If the bucket that you're uploading objects to uses the bucket owner enforced setting for S3 Object Ownership, ACLs are disabled and no longer affect permissions. Buckets that use this setting only accept PUT requests that don't specify an ACL or PUT requests that specify bucket owner full control ACLs, such as the
|
Body |
Object data. |
Bucket |
[required] The bucket name to which the PUT action was initiated. Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. Object Lambda access points are not supported by directory buckets. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
CacheControl |
Can be used to specify caching behavior along the request/reply chain. For more information, see http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.9. |
ContentDisposition |
Specifies presentational information for the object. For more information, see https://www.rfc-editor.org/rfc/rfc6266#section-4. |
ContentEncoding |
Specifies what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field. For more information, see https://www.rfc-editor.org/rfc/rfc9110.html#field.content-encoding. |
ContentLanguage |
The language the content is in. |
ContentLength |
Size of the body in bytes. This parameter is useful when the size of the body cannot be determined automatically. For more information, see https://www.rfc-editor.org/rfc/rfc9110.html#name-content-length. |
ContentMD5 |
The Base64 encoded 128-bit The This functionality is not supported for directory buckets. |
ContentType |
A standard MIME type describing the format of the contents. For more information, see https://www.rfc-editor.org/rfc/rfc9110.html#name-content-type. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding For the
For more information, see Checking object integrity in the Amazon S3 User Guide. If the individual checksum value you provide through The For directory buckets, when you use Amazon Web Services SDKs, |
ChecksumCRC32 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit |
ChecksumCRC32C |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit |
ChecksumCRC64NVME |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit |
ChecksumSHA1 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit |
ChecksumSHA256 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit |
ChecksumSHA512 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 512-bit |
ChecksumMD5 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit |
ChecksumXXHASH64 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit |
ChecksumXXHASH3 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit |
ChecksumXXHASH128 |
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit |
Expires |
The date and time at which the object is no longer cacheable. For more information, see https://www.rfc-editor.org/rfc/rfc7234#section-5.3. |
IfMatch |
Uploads the object only if the ETag (entity tag) value provided during the WRITE operation matches the ETag of the object in S3. If the ETag values do not match, the operation returns a If a conflicting operation occurs during the upload S3 returns a Expects the ETag value as a string. For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide. |
IfNoneMatch |
Uploads the object only if the object key name does not already exist in the bucket specified. Otherwise, Amazon S3 returns a If a conflicting operation occurs during the upload S3 returns a Expects the '*' (asterisk) character. For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide. |
GrantFullControl |
Gives the grantee READ, READ_ACP, and WRITE_ACP permissions on the object.
|
GrantRead |
Allows grantee to read the object data and its metadata.
|
GrantReadACP |
Allows grantee to read the object ACL.
|
GrantWriteACP |
Allows grantee to write the ACL for the applicable object.
|
Key |
[required] Object key for which the PUT action was initiated. |
WriteOffsetBytes |
Specifies the offset for appending data to existing objects in bytes. The offset must be equal to the size of the existing object being appended to. If no object exists, setting this header to 0 will create a new object. This functionality is only supported for objects in the Amazon S3 Express One Zone storage class in directory buckets. |
Metadata |
A map of metadata to store with the object in S3. |
ServerSideEncryption |
The server-side encryption algorithm that was used when you store this object in Amazon S3 or Amazon FSx.
|
StorageClass |
By default, Amazon S3 uses the STANDARD Storage Class to store newly created objects. The STANDARD storage class provides high durability and high availability. Depending on performance needs, you can specify a different Storage Class. For more information, see Storage Classes in the Amazon S3 User Guide.
|
WebsiteRedirectLocation |
If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Amazon S3 stores the value of this header in the object metadata. For information about object metadata, see Object Key and Metadata in the Amazon S3 User Guide. In the following example, the request header sets the redirect to an object (anotherPage.html) in the same bucket:
In the following example, the request header sets the object redirect to another website:
For more information about website hosting in Amazon S3, see Hosting Websites on Amazon S3 and How to Configure Website Page Redirects in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
SSECustomerAlgorithm |
Specifies the algorithm to use when encrypting the object (for example, This functionality is not supported for directory buckets. |
SSECustomerKey |
Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the This functionality is not supported for directory buckets. |
SSECustomerKeyMD5 |
Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. This functionality is not supported for directory buckets. |
SSEKMSKeyId |
Specifies the KMS key ID (Key ID, Key ARN, or Key Alias) to use for object encryption. If the KMS key doesn't exist in the same account that's issuing the command, you must use the full Key ARN not the Key ID. General purpose buckets - If you specify Directory buckets - To encrypt data using SSE-KMS, it's recommended to specify the |
SSEKMSEncryptionContext |
Specifies the Amazon Web Services KMS Encryption Context as an additional encryption context to use for object encryption. The value of this header is a Base64 encoded string of a UTF-8 encoded JSON, which contains the encryption context as key-value pairs. This value is stored as object metadata and automatically gets passed on to Amazon Web Services KMS for future General purpose buckets - This value must be explicitly added during Directory buckets - You can optionally provide an explicit encryption context value. The value must match the default encryption context - the bucket Amazon Resource Name (ARN). An additional encryption context value is not supported. |
BucketKeyEnabled |
Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using Key Management Service (KMS) keys (SSE-KMS). General purpose buckets - Setting this header to Directory buckets - S3 Bucket Keys are always enabled for |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
Tagging |
The tag-set for the object. The tag-set must be encoded as URL Query parameters. (For example, "Key1=Value1") This functionality is not supported for directory buckets. |
ObjectLockMode |
The Object Lock mode that you want to apply to this object. This functionality is not supported for directory buckets. |
ObjectLockRetainUntilDate |
The date and time when you want this object's Object Lock to expire. Must be formatted as a timestamp parameter. This functionality is not supported for directory buckets. |
ObjectLockLegalHoldStatus |
Specifies whether a legal hold will be applied to this object. For more information about S3 Object Lock, see Object Lock in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.