View source: R/s3_operations.R
| s3_put_object_acl | R Documentation |
End of support notice: As of October 1, 2025, Amazon S3 has discontinued support for Email Grantee Access Control Lists (ACLs). If you attempt to use an Email Grantee ACL in a request after October 1, 2025, the request will receive an HTTP 405 (Method Not Allowed) error.
See https://www.paws-r-sdk.com/docs/s3_put_object_acl/ for full documentation.
s3_put_object_acl(
ACL = NULL,
AccessControlPolicy = NULL,
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
GrantFullControl = NULL,
GrantRead = NULL,
GrantReadACP = NULL,
GrantWrite = NULL,
GrantWriteACP = NULL,
Key,
RequestPayer = NULL,
VersionId = NULL,
ExpectedBucketOwner = NULL
)
ACL |
The canned ACL to apply to the object. For more information, see Canned ACL. |
AccessControlPolicy |
Contains the elements that set the ACL permissions for an object per grantee. |
Bucket |
[required] The bucket name that contains the object to which you want to attach the ACL. Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form |
ContentMD5 |
The Base64 encoded 128-bit For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically. |
ChecksumAlgorithm |
Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding If you provide an individual checksum, Amazon S3 ignores any provided |
GrantFullControl |
Allows grantee the read, write, read ACP, and write ACP permissions on the bucket. This functionality is not supported for Amazon S3 on Outposts. |
GrantRead |
Allows grantee to list the objects in the bucket. This functionality is not supported for Amazon S3 on Outposts. |
GrantReadACP |
Allows grantee to read the bucket ACL. This functionality is not supported for Amazon S3 on Outposts. |
GrantWrite |
Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects. |
GrantWriteACP |
Allows grantee to write the ACL for the applicable bucket. This functionality is not supported for Amazon S3 on Outposts. |
Key |
[required] Key for which the PUT action was initiated. |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
VersionId |
Version ID used to reference a specific version of the object. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.