s3_put_object_tagging: This operation is not supported for directory buckets

View source: R/s3_operations.R

s3_put_object_taggingR Documentation

This operation is not supported for directory buckets

Description

This operation is not supported for directory buckets.

See https://www.paws-r-sdk.com/docs/s3_put_object_tagging/ for full documentation.

Usage

s3_put_object_tagging(
  Bucket,
  Key,
  VersionId = NULL,
  ContentMD5 = NULL,
  ChecksumAlgorithm = NULL,
  Tagging,
  ExpectedBucketOwner = NULL,
  RequestPayer = NULL
)

Arguments

Bucket

[required] The bucket name containing the object.

Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.

S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When you use this action with S3 on Outposts, the destination bucket must be the Outposts access point ARN or the access point alias. For more information about S3 on Outposts, see What is S3 on Outposts? in the Amazon S3 User Guide.

Key

[required] Name of the object key.

VersionId

The versionId of the object that the tag-set will be added to.

ContentMD5

The MD5 hash for the request body.

For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

ChecksumAlgorithm

Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code ⁠400 Bad Request⁠. For more information, see Checking object integrity in the Amazon S3 User Guide.

If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.

Tagging

[required] Container for the TagSet and Tag elements

ExpectedBucketOwner

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ⁠403 Forbidden⁠ (access denied).

RequestPayer

Confirms that the requester knows that she or he will be charged for the tagging object request. Bucket owners need not specify this parameter in their requests.


paws.storage documentation built on May 30, 2026, 9:13 a.m.