s3_rename_object: Renames an existing object in a directory bucket that uses...

View source: R/s3_operations.R

s3_rename_objectR Documentation

Renames an existing object in a directory bucket that uses the S3 Express One Zone storage class

Description

Renames an existing object in a directory bucket that uses the S3 Express One Zone storage class. You can use rename_object by specifying an existing object’s name as the source and the new name of the object as the destination within the same directory bucket.

See https://www.paws-r-sdk.com/docs/s3_rename_object/ for full documentation.

Usage

s3_rename_object(
  Bucket,
  Key,
  RenameSource,
  DestinationIfMatch = NULL,
  DestinationIfNoneMatch = NULL,
  DestinationIfModifiedSince = NULL,
  DestinationIfUnmodifiedSince = NULL,
  SourceIfMatch = NULL,
  SourceIfNoneMatch = NULL,
  SourceIfModifiedSince = NULL,
  SourceIfUnmodifiedSince = NULL,
  ClientToken = NULL
)

Arguments

Bucket

[required] The bucket name of the directory bucket containing the object.

You must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Availability Zone. Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

Key

[required] Key name of the object to rename.

RenameSource

[required] Specifies the source for the rename operation. The value must be URL encoded.

DestinationIfMatch

Renames the object only if the ETag (entity tag) value provided during the operation matches the ETag of the object in S3. The If-Match header field makes the request method conditional on ETags. If the ETag values do not match, the operation returns a ⁠412 Precondition Failed⁠ error.

Expects the ETag value as a string.

DestinationIfNoneMatch

Renames the object only if the destination does not already exist in the specified directory bucket. If the object does exist when you send a request with ⁠If-None-Match:*⁠, the S3 API will return a ⁠412 Precondition Failed⁠ error, preventing an overwrite. The If-None-Match header prevents overwrites of existing data by validating that there's not an object with the same key name already in your directory bucket.

Expects the * character (asterisk).

DestinationIfModifiedSince

Renames the object if the destination exists and if it has been modified since the specified time.

DestinationIfUnmodifiedSince

Renames the object if it hasn't been modified since the specified time.

SourceIfMatch

Renames the object if the source exists and if its entity tag (ETag) matches the specified ETag.

SourceIfNoneMatch

Renames the object if the source exists and if its entity tag (ETag) is different than the specified ETag. If an asterisk (*) character is provided, the operation will fail and return a ⁠412 Precondition Failed⁠ error.

SourceIfModifiedSince

Renames the object if the source exists and if it has been modified since the specified time.

SourceIfUnmodifiedSince

Renames the object if the source exists and hasn't been modified since the specified time.

ClientToken

A unique string with a max of 64 ASCII characters in the ASCII range of 33 - 126.

rename_object supports idempotency using a client token. To make an idempotent API request using rename_object, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails and an IdempotentParameterMismatch error is returned.


paws.storage documentation built on May 30, 2026, 9:13 a.m.