s3_update_bucket_metadata_inventory_table_configuration: Enables or disables a live inventory table for an S3 Metadata...

View source: R/s3_operations.R

s3_update_bucket_metadata_inventory_table_configurationR Documentation

Enables or disables a live inventory table for an S3 Metadata configuration on a general purpose bucket

Description

Enables or disables a live inventory table for an S3 Metadata configuration on a general purpose bucket. For more information, see Accelerating data discovery with S3 Metadata in the Amazon S3 User Guide.

See https://www.paws-r-sdk.com/docs/s3_update_bucket_metadata_inventory_table_configuration/ for full documentation.

Usage

s3_update_bucket_metadata_inventory_table_configuration(
  Bucket,
  ContentMD5 = NULL,
  ChecksumAlgorithm = NULL,
  InventoryTableConfiguration,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable an inventory table for.

ContentMD5

The Content-MD5 header for the inventory table configuration.

ChecksumAlgorithm

The checksum algorithm to use with your inventory table configuration.

InventoryTableConfiguration

[required] The contents of your inventory table configuration.

ExpectedBucketOwner

The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable an inventory table for.


paws.storage documentation built on May 30, 2026, 9:13 a.m.