s3_update_bucket_metadata_journal_table_configuration: Enables or disables journal table record expiration for an S3...

View source: R/s3_operations.R

s3_update_bucket_metadata_journal_table_configurationR Documentation

Enables or disables journal table record expiration for an S3 Metadata configuration on a general purpose bucket

Description

Enables or disables journal table record expiration for an S3 Metadata configuration on a general purpose bucket. For more information, see Accelerating data discovery with S3 Metadata in the Amazon S3 User Guide.

See https://www.paws-r-sdk.com/docs/s3_update_bucket_metadata_journal_table_configuration/ for full documentation.

Usage

s3_update_bucket_metadata_journal_table_configuration(
  Bucket,
  ContentMD5 = NULL,
  ChecksumAlgorithm = NULL,
  JournalTableConfiguration,
  ExpectedBucketOwner = NULL
)

Arguments

Bucket

[required] The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable journal table record expiration for.

ContentMD5

The Content-MD5 header for the journal table configuration.

ChecksumAlgorithm

The checksum algorithm to use with your journal table configuration.

JournalTableConfiguration

[required] The contents of your journal table configuration.

ExpectedBucketOwner

The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable journal table record expiration for.


paws.storage documentation built on May 30, 2026, 9:13 a.m.