s3_update_object_encryption: This operation is not supported for directory buckets or...

View source: R/s3_operations.R

s3_update_object_encryptionR Documentation

This operation is not supported for directory buckets or Amazon S3 on Outposts buckets

Description

This operation is not supported for directory buckets or Amazon S3 on Outposts buckets.

See https://www.paws-r-sdk.com/docs/s3_update_object_encryption/ for full documentation.

Usage

s3_update_object_encryption(
  Bucket,
  Key,
  VersionId = NULL,
  ObjectEncryption,
  RequestPayer = NULL,
  ExpectedBucketOwner = NULL,
  ContentMD5 = NULL,
  ChecksumAlgorithm = NULL
)

Arguments

Bucket

[required] The name of the general purpose bucket that contains the specified object key name.

When you use this operation with an access point attached to a general purpose bucket, you must either provide the alias of the access point in place of the bucket name or you must specify the access point Amazon Resource Name (ARN). When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this operation with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Referencing access points in the Amazon S3 User Guide.

Key

[required] The key name of the object that you want to update the server-side encryption type for.

VersionId

The version ID of the object that you want to update the server-side encryption type for.

ObjectEncryption

[required] The updated server-side encryption type for this object. The update_object_encryption operation supports the SSE-S3 and SSE-KMS encryption types.

Valid Values: SSES3 | SSEKMS

RequestPayer

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

ExpectedBucketOwner

The account ID of the expected bucket owner. If the account ID that you provide doesn't match the actual owner of the bucket, the request fails with the HTTP status code ⁠403 Forbidden⁠ (access denied).

ContentMD5

The MD5 hash for the request body. For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

ChecksumAlgorithm

Indicates the algorithm used to create the checksum for the object when you use an Amazon Web Services SDK. This header doesn't provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code ⁠400 Bad Request⁠. For more information, see Checking object integrity in the Amazon S3 User Guide.

If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.


paws.storage documentation built on May 30, 2026, 9:13 a.m.