View source: R/s3control_operations.R
| s3control_create_access_point | R Documentation |
Creates an access point and associates it to a specified bucket. For more information, see Managing access to shared datasets with access points or Managing access to shared datasets in directory buckets with access points in the Amazon S3 User Guide.
See https://www.paws-r-sdk.com/docs/s3control_create_access_point/ for full documentation.
s3control_create_access_point(
AccountId,
Name,
Bucket,
VpcConfiguration = NULL,
PublicAccessBlockConfiguration = NULL,
BucketAccountId = NULL,
Scope = NULL,
Tags = NULL
)
AccountId |
[required] The Amazon Web Services account ID for the account that owns the specified access point. |
Name |
[required] The name you want to assign to this access point. For directory buckets, the access point name must consist of a base name that you provide and suffix that includes the |
Bucket |
[required] The name of the bucket that you want to associate this access point with. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format |
VpcConfiguration |
If you include this field, Amazon S3 restricts access to this access point to requests from the specified virtual private cloud (VPC). This is required for creating an access point for Amazon S3 on Outposts buckets. |
PublicAccessBlockConfiguration |
The |
BucketAccountId |
The Amazon Web Services account ID associated with the S3 bucket associated with this access point. For same account access point when your bucket and access point belong to the same account owner, the |
Scope |
For directory buckets, you can filter access control to specific prefixes, API operations, or a combination of both. For more information, see Managing access to shared datasets in directory buckets with access points in the Amazon S3 User Guide. Scope is only supported for access points attached to directory buckets. |
Tags |
An array of tags that you can apply to an access point. Tags are key-value pairs of metadata used to control access to your access points. For more information about tags, see Using tags with Amazon S3. For information about tagging access points, see Using tags for attribute-based access control (ABAC). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.