View source: R/s3control_operations.R
| s3control_delete_access_grant | R Documentation |
Deletes the access grant from the S3 Access Grants instance. You cannot undo an access grant deletion and the grantee will no longer have access to the S3 data.
See https://www.paws-r-sdk.com/docs/s3control_delete_access_grant/ for full documentation.
s3control_delete_access_grant(AccountId, AccessGrantId)
AccountId |
[required] The Amazon Web Services account ID of the S3 Access Grants instance. |
AccessGrantId |
[required] The ID of the access grant. S3 Access Grants auto-generates this ID when you create the access grant. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.