View source: R/s3control_operations.R
| s3control_delete_access_grants_instance | R Documentation |
Deletes your S3 Access Grants instance. You must first delete the access grants and locations before S3 Access Grants can delete the instance. See delete_access_grant and delete_access_grants_location. If you have associated an IAM Identity Center instance with your S3 Access Grants instance, you must first dissassociate the Identity Center instance from the S3 Access Grants instance before you can delete the S3 Access Grants instance. See associate_access_grants_identity_center and dissociate_access_grants_identity_center.
See https://www.paws-r-sdk.com/docs/s3control_delete_access_grants_instance/ for full documentation.
s3control_delete_access_grants_instance(AccountId)
AccountId |
[required] The Amazon Web Services account ID of the S3 Access Grants instance. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.