View source: R/s3control_operations.R
| s3control_delete_access_point_policy | R Documentation |
Deletes the access point policy for the specified access point.
See https://www.paws-r-sdk.com/docs/s3control_delete_access_point_policy/ for full documentation.
s3control_delete_access_point_policy(AccountId, Name)
AccountId |
[required] The account ID for the account that owns the specified access point. |
Name |
[required] The name of the access point whose policy you want to delete. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the access point accessed in the format |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.