s3control_delete_access_point_scope: Deletes an existing access point scope for a directory bucket

View source: R/s3control_operations.R

s3control_delete_access_point_scopeR Documentation

Deletes an existing access point scope for a directory bucket

Description

Deletes an existing access point scope for a directory bucket.

See https://www.paws-r-sdk.com/docs/s3control_delete_access_point_scope/ for full documentation.

Usage

s3control_delete_access_point_scope(AccountId, Name)

Arguments

AccountId

[required] The Amazon Web Services account ID that owns the access point with the scope that you want to delete.

Name

[required] The name of the access point with the scope that you want to delete.


paws.storage documentation built on May 30, 2026, 9:13 a.m.