View source: R/s3control_operations.R
| s3control_get_access_point_scope | R Documentation |
Returns the access point scope for a directory bucket.
See https://www.paws-r-sdk.com/docs/s3control_get_access_point_scope/ for full documentation.
s3control_get_access_point_scope(AccountId, Name)
AccountId |
[required] The Amazon Web Services account ID that owns the access point with the scope that you want to retrieve. |
Name |
[required] The name of the access point with the scope you want to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.