View source: R/s3control_operations.R
| s3control_get_data_access | R Documentation |
Returns a temporary access credential from S3 Access Grants to the grantee or client application. The temporary credential is an Amazon Web Services STS token that grants them access to the S3 data.
See https://www.paws-r-sdk.com/docs/s3control_get_data_access/ for full documentation.
s3control_get_data_access(
AccountId,
Target,
Permission,
DurationSeconds = NULL,
Privilege = NULL,
TargetType = NULL,
AuditContext = NULL
)
AccountId |
[required] The Amazon Web Services account ID of the S3 Access Grants instance. |
Target |
[required] The S3 URI path of the data to which you are requesting temporary access credentials. If the requesting account has an access grant for this data, S3 Access Grants vends temporary access credentials in the response. |
Permission |
[required] The type of permission granted to your S3 data, which can be set to one of the following values:
|
DurationSeconds |
The session duration, in seconds, of the temporary access credential that S3 Access Grants vends to the grantee or client application. The default value is 1 hour, but the grantee can specify a range from 900 seconds (15 minutes) up to 43200 seconds (12 hours). If the grantee requests a value higher than this maximum, the operation fails. |
Privilege |
The scope of the temporary access credential that S3 Access Grants vends to the grantee or client application.
|
TargetType |
The type of |
AuditContext |
The context to identify the job or query associated with the credential request. This information will be displayed in CloudTrail log in your account. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.