View source: R/s3control_operations.R
| s3control_list_access_points | R Documentation |
This operation is not supported by directory buckets.
See https://www.paws-r-sdk.com/docs/s3control_list_access_points/ for full documentation.
s3control_list_access_points(
AccountId,
Bucket = NULL,
NextToken = NULL,
MaxResults = NULL,
DataSourceId = NULL,
DataSourceType = NULL
)
AccountId |
[required] The Amazon Web Services account ID for the account that owns the specified access points. |
Bucket |
The name of the bucket whose associated access points you want to list. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format |
NextToken |
A continuation token. If a previous call to |
MaxResults |
The maximum number of access points that you want to include in the list. If the specified bucket has more than this number of access points, then the response will include a continuation token in the |
DataSourceId |
The unique identifier for the data source of the access point. |
DataSourceType |
The type of the data source that the access point is attached to. Returns only access points attached to S3 buckets by default. To return all access points specify |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.