s3control_put_access_point_scope: Creates or replaces the access point scope for a directory...

View source: R/s3control_operations.R

s3control_put_access_point_scopeR Documentation

Creates or replaces the access point scope for a directory bucket

Description

Creates or replaces the access point scope for a directory bucket. You can use the access point scope to restrict access to specific prefixes, API operations, or a combination of both.

See https://www.paws-r-sdk.com/docs/s3control_put_access_point_scope/ for full documentation.

Usage

s3control_put_access_point_scope(AccountId, Name, Scope)

Arguments

AccountId

[required] The Amazon Web Services account ID that owns the access point with scope that you want to create or replace.

Name

[required] The name of the access point with the scope that you want to create or replace.

Scope

[required] Object prefixes, API operations, or a combination of both.


paws.storage documentation built on May 30, 2026, 9:13 a.m.