s3tables: Amazon S3 Tables

View source: R/s3tables_service.R

s3tablesR Documentation

Amazon S3 Tables

Description

An Amazon S3 table represents a structured dataset consisting of tabular data in Apache Parquet format and related metadata. This data is stored inside an S3 table as a subresource. All tables in a table bucket are stored in the Apache Iceberg table format. Through integration with the Amazon Web Services Glue Data Catalog you can interact with your tables using Amazon Web Services analytics services, such as Amazon Athena and Amazon Redshift. Amazon S3 manages maintenance of your tables through automatic file compaction and snapshot management. For more information, see Amazon S3 table buckets.

Usage

s3tables(config = list(), credentials = list(), endpoint = NULL, region = NULL)

Arguments

config

Optional configuration of credentials, endpoint, and/or region.

  • credentials:

    • creds:

      • access_key_id: AWS access key ID

      • secret_access_key: AWS secret access key

      • session_token: AWS temporary session token

    • profile: The name of a profile to use. If not given, then the default profile is used.

    • anonymous: Set anonymous credentials.

  • endpoint: The complete URL to use for the constructed client.

  • region: The AWS Region used in instantiating the client.

  • close_connection: Immediately close all HTTP connections.

  • timeout: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.

  • s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e. ⁠http://s3.amazonaws.com/BUCKET/KEY⁠.

  • sts_regional_endpoint: Set sts regional endpoint resolver to regional or legacy https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html

credentials

Optional credentials shorthand for the config parameter

  • creds:

    • access_key_id: AWS access key ID

    • secret_access_key: AWS secret access key

    • session_token: AWS temporary session token

  • profile: The name of a profile to use. If not given, then the default profile is used.

  • anonymous: Set anonymous credentials.

endpoint

Optional shorthand for complete URL to use for the constructed client.

region

Optional shorthand for AWS Region used in instantiating the client.

Value

A client for the service. You can call the service's operations using syntax like svc$operation(...), where svc is the name you've assigned to the client. The available operations are listed in the Operations section.

Service syntax

svc <- s3tables(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string",
      anonymous = "logical"
    ),
    endpoint = "string",
    region = "string",
    close_connection = "logical",
    timeout = "numeric",
    s3_force_path_style = "logical",
    sts_regional_endpoint = "string"
  ),
  credentials = list(
    creds = list(
      access_key_id = "string",
      secret_access_key = "string",
      session_token = "string"
    ),
    profile = "string",
    anonymous = "logical"
  ),
  endpoint = "string",
  region = "string"
)

Operations

create_namespace Creates a namespace
create_table Creates a new table associated with the given namespace in a table bucket
create_table_bucket Creates a table bucket
delete_namespace Deletes a namespace
delete_table Deletes a table
delete_table_bucket Deletes a table bucket
delete_table_bucket_encryption Deletes the encryption configuration for a table bucket
delete_table_bucket_metrics_configuration Deletes the metrics configuration for a table bucket
delete_table_bucket_policy Deletes a table bucket policy
delete_table_bucket_replication Deletes the replication configuration for a table bucket
delete_table_policy Deletes a table policy
delete_table_replication Deletes the replication configuration for a specific table
get_namespace Gets details about a namespace
get_table Gets details about a table
get_table_bucket Gets details on a table bucket
get_table_bucket_encryption Gets the encryption configuration for a table bucket
get_table_bucket_maintenance_configuration Gets details about a maintenance configuration for a given table bucket
get_table_bucket_metrics_configuration Gets the metrics configuration for a table bucket
get_table_bucket_policy Gets details about a table bucket policy
get_table_bucket_replication Retrieves the replication configuration for a table bucket
get_table_bucket_storage_class Retrieves the storage class configuration for a specific table
get_table_encryption Gets the encryption configuration for a table
get_table_maintenance_configuration Gets details about the maintenance configuration of a table
get_table_maintenance_job_status Gets the status of a maintenance job for a table
get_table_metadata_location Gets the location of the table metadata
get_table_policy Gets details about a table policy
get_table_record_expiration_configuration Retrieves the expiration configuration settings for records in a table, and the status of the configuration
get_table_record_expiration_job_status Retrieves the status, metrics, and details of the latest record expiration job for a table
get_table_replication Retrieves the replication configuration for a specific table
get_table_replication_status Retrieves the replication status for a table, including the status of replication to each destination
get_table_storage_class Retrieves the storage class configuration for a specific table
list_namespaces Lists the namespaces within a table bucket
list_table_buckets Lists table buckets for your account
list_tables List tables in the given table bucket
list_tags_for_resource Lists all of the tags applied to a specified Amazon S3 Tables resource
put_table_bucket_encryption Sets the encryption configuration for a table bucket
put_table_bucket_maintenance_configuration Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket
put_table_bucket_metrics_configuration Sets the metrics configuration for a table bucket
put_table_bucket_policy Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket
put_table_bucket_replication Creates or updates the replication configuration for a table bucket
put_table_bucket_storage_class Sets or updates the storage class configuration for a table bucket
put_table_maintenance_configuration Creates a new maintenance configuration or replaces an existing maintenance configuration for a table
put_table_policy Creates a new table policy or replaces an existing table policy for a table
put_table_record_expiration_configuration Creates or updates the expiration configuration settings for records in a table, including the status of the configuration
put_table_replication Creates or updates the replication configuration for a specific table
rename_table Renames a table or a namespace
tag_resource Applies one or more user-defined tags to an Amazon S3 Tables resource or updates existing tags
untag_resource Removes the specified user-defined tags from an Amazon S3 Tables resource
update_table_metadata_location Updates the metadata location for a table

Examples

## Not run: 
svc <- s3tables()
svc$create_namespace(
  Foo = 123
)

## End(Not run)


paws.storage documentation built on May 30, 2026, 9:13 a.m.