s3tables_create_namespace: Creates a namespace

View source: R/s3tables_operations.R

s3tables_create_namespaceR Documentation

Creates a namespace

Description

Creates a namespace. A namespace is a logical grouping of tables within your table bucket, which you can use to organize tables. For more information, see Create a namespace in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_create_namespace/ for full documentation.

Usage

s3tables_create_namespace(tableBucketARN, namespace)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket to create the namespace in.

namespace

[required] A name for the namespace.


paws.storage documentation built on May 30, 2026, 9:13 a.m.