s3tables_create_table_bucket: Creates a table bucket

View source: R/s3tables_operations.R

s3tables_create_table_bucketR Documentation

Creates a table bucket

Description

Creates a table bucket. For more information, see Creating a table bucket in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_create_table_bucket/ for full documentation.

Usage

s3tables_create_table_bucket(
  name,
  encryptionConfiguration = NULL,
  storageClassConfiguration = NULL,
  tags = NULL
)

Arguments

name

[required] The name for the table bucket.

encryptionConfiguration

The encryption configuration to use for the table bucket. This configuration specifies the default encryption settings that will be applied to all tables created in this bucket unless overridden at the table level. The configuration includes the encryption algorithm and, if using SSE-KMS, the KMS key to use.

storageClassConfiguration

The default storage class configuration for the table bucket. This configuration will be applied to all new tables created in this bucket unless overridden at the table level. If not specified, the service default storage class will be used.

tags

A map of user-defined tags that you would like to apply to the table bucket that you are creating. A tag is a key-value pair that you apply to your resources. Tags can help you organize and control access to resources. For more information, see Tagging for cost allocation or attribute-based access control (ABAC).

You must have the s3tables:TagResource permission in addition to s3tables:CreateTableBucket permisson to create a table bucket with tags.


paws.storage documentation built on May 30, 2026, 9:13 a.m.