s3tables_delete_table_replication: Deletes the replication configuration for a specific table

View source: R/s3tables_operations.R

s3tables_delete_table_replicationR Documentation

Deletes the replication configuration for a specific table

Description

Deletes the replication configuration for a specific table. After deletion, new updates to this table will no longer be replicated to destination tables, though existing replicated copies will remain in destination buckets.

See https://www.paws-r-sdk.com/docs/s3tables_delete_table_replication/ for full documentation.

Usage

s3tables_delete_table_replication(tableArn, versionToken)

Arguments

tableArn

[required] The Amazon Resource Name (ARN) of the table.

versionToken

[required] A version token from a previous GetTableReplication call. Use this token to ensure you're deleting the expected version of the configuration.


paws.storage documentation built on May 30, 2026, 9:13 a.m.