s3tables_get_table: Gets details about a table

View source: R/s3tables_operations.R

s3tables_get_tableR Documentation

Gets details about a table

Description

Gets details about a table. For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_get_table/ for full documentation.

Usage

s3tables_get_table(
  tableBucketARN = NULL,
  namespace = NULL,
  name = NULL,
  tableArn = NULL
)

Arguments

tableBucketARN

The Amazon Resource Name (ARN) of the table bucket associated with the table.

namespace

The name of the namespace the table is associated with.

name

The name of the table.

tableArn

The Amazon Resource Name (ARN) of the table.


paws.storage documentation built on May 30, 2026, 9:13 a.m.