s3tables_get_table_bucket: Gets details on a table bucket

View source: R/s3tables_operations.R

s3tables_get_table_bucketR Documentation

Gets details on a table bucket

Description

Gets details on a table bucket. For more information, see Viewing details about an Amazon S3 table bucket in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_get_table_bucket/ for full documentation.

Usage

s3tables_get_table_bucket(tableBucketARN)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket.


paws.storage documentation built on May 30, 2026, 9:13 a.m.