s3tables_get_table_bucket_maintenance_configuration: Gets details about a maintenance configuration for a given...

View source: R/s3tables_operations.R

s3tables_get_table_bucket_maintenance_configurationR Documentation

Gets details about a maintenance configuration for a given table bucket

Description

Gets details about a maintenance configuration for a given table bucket. For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_get_table_bucket_maintenance_configuration/ for full documentation.

Usage

s3tables_get_table_bucket_maintenance_configuration(tableBucketARN)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket associated with the maintenance configuration.


paws.storage documentation built on May 30, 2026, 9:13 a.m.