s3tables_get_table_maintenance_configuration: Gets details about the maintenance configuration of a table

View source: R/s3tables_operations.R

s3tables_get_table_maintenance_configurationR Documentation

Gets details about the maintenance configuration of a table

Description

Gets details about the maintenance configuration of a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_get_table_maintenance_configuration/ for full documentation.

Usage

s3tables_get_table_maintenance_configuration(tableBucketARN, namespace, name)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket.

namespace

[required] The namespace associated with the table.

name

[required] The name of the table.


paws.storage documentation built on May 30, 2026, 9:13 a.m.