View source: R/s3tables_operations.R
| s3tables_get_table_maintenance_job_status | R Documentation |
Gets the status of a maintenance job for a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_get_table_maintenance_job_status/ for full documentation.
s3tables_get_table_maintenance_job_status(tableBucketARN, namespace, name)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket. |
namespace |
[required] The name of the namespace the table is associated with. |
name |
[required] The name of the table containing the maintenance job status you want to check. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.