s3tables_get_table_record_expiration_configuration: Retrieves the expiration configuration settings for records...

View source: R/s3tables_operations.R

s3tables_get_table_record_expiration_configurationR Documentation

Retrieves the expiration configuration settings for records in a table, and the status of the configuration

Description

Retrieves the expiration configuration settings for records in a table, and the status of the configuration. If the status of the configuration is enabled, records expire and are automatically removed from the table after the specified number of days.

See https://www.paws-r-sdk.com/docs/s3tables_get_table_record_expiration_configuration/ for full documentation.

Usage

s3tables_get_table_record_expiration_configuration(tableArn)

Arguments

tableArn

[required] The Amazon Resource Name (ARN) of the table.


paws.storage documentation built on May 30, 2026, 9:13 a.m.