s3tables_get_table_record_expiration_job_status: Retrieves the status, metrics, and details of the latest...

View source: R/s3tables_operations.R

s3tables_get_table_record_expiration_job_statusR Documentation

Retrieves the status, metrics, and details of the latest record expiration job for a table

Description

Retrieves the status, metrics, and details of the latest record expiration job for a table. This includes when the job ran, and whether it succeeded or failed. If the job ran successfully, this also includes statistics about the records that were removed.

See https://www.paws-r-sdk.com/docs/s3tables_get_table_record_expiration_job_status/ for full documentation.

Usage

s3tables_get_table_record_expiration_job_status(tableArn)

Arguments

tableArn

[required] The Amazon Resource Name (ARN) of the table.


paws.storage documentation built on May 30, 2026, 9:13 a.m.