s3tables_get_table_replication_status: Retrieves the replication status for a table, including the...

View source: R/s3tables_operations.R

s3tables_get_table_replication_statusR Documentation

Retrieves the replication status for a table, including the status of replication to each destination

Description

Retrieves the replication status for a table, including the status of replication to each destination. This operation provides visibility into replication health and progress.

See https://www.paws-r-sdk.com/docs/s3tables_get_table_replication_status/ for full documentation.

Usage

s3tables_get_table_replication_status(tableArn)

Arguments

tableArn

[required] The Amazon Resource Name (ARN) of the table.


paws.storage documentation built on May 30, 2026, 9:13 a.m.