s3tables_get_table_storage_class: Retrieves the storage class configuration for a specific...

View source: R/s3tables_operations.R

s3tables_get_table_storage_classR Documentation

Retrieves the storage class configuration for a specific table

Description

Retrieves the storage class configuration for a specific table. This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket's default configuration.

See https://www.paws-r-sdk.com/docs/s3tables_get_table_storage_class/ for full documentation.

Usage

s3tables_get_table_storage_class(tableBucketARN, namespace, name)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket that contains the table.

namespace

[required] The namespace associated with the table.

name

[required] The name of the table.


paws.storage documentation built on May 30, 2026, 9:13 a.m.