View source: R/s3tables_operations.R
| s3tables_list_namespaces | R Documentation |
Lists the namespaces within a table bucket. For more information, see Table namespaces in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_list_namespaces/ for full documentation.
s3tables_list_namespaces(
tableBucketARN,
prefix = NULL,
continuationToken = NULL,
maxNamespaces = NULL
)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket. |
prefix |
The prefix of the namespaces. |
continuationToken |
|
maxNamespaces |
The maximum number of namespaces to return in the list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.