View source: R/s3tables_operations.R
| s3tables_list_table_buckets | R Documentation |
Lists table buckets for your account. For more information, see S3 Table buckets in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_list_table_buckets/ for full documentation.
s3tables_list_table_buckets(
prefix = NULL,
continuationToken = NULL,
maxBuckets = NULL,
type = NULL
)
prefix |
The prefix of the table buckets. |
continuationToken |
|
maxBuckets |
The maximum number of table buckets to return in the list. |
type |
The type of table buckets to filter by in the list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.