s3tables_put_table_bucket_policy: Creates a new table bucket policy or replaces an existing...

View source: R/s3tables_operations.R

s3tables_put_table_bucket_policyR Documentation

Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket

Description

Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket. For more information, see Adding a table bucket policy in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_put_table_bucket_policy/ for full documentation.

Usage

s3tables_put_table_bucket_policy(tableBucketARN, resourcePolicy)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket.

resourcePolicy

[required] The JSON that defines the policy.


paws.storage documentation built on May 30, 2026, 9:13 a.m.