s3tables_put_table_bucket_storage_class: Sets or updates the storage class configuration for a table...

View source: R/s3tables_operations.R

s3tables_put_table_bucket_storage_classR Documentation

Sets or updates the storage class configuration for a table bucket

Description

Sets or updates the storage class configuration for a table bucket. This configuration serves as the default storage class for all new tables created in the bucket, allowing you to optimize storage costs at the bucket level.

See https://www.paws-r-sdk.com/docs/s3tables_put_table_bucket_storage_class/ for full documentation.

Usage

s3tables_put_table_bucket_storage_class(
  tableBucketARN,
  storageClassConfiguration
)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket.

storageClassConfiguration

[required] The storage class configuration to apply to the table bucket. This configuration will serve as the default for new tables created in this bucket.


paws.storage documentation built on May 30, 2026, 9:13 a.m.