s3tables_put_table_maintenance_configuration: Creates a new maintenance configuration or replaces an...

View source: R/s3tables_operations.R

s3tables_put_table_maintenance_configurationR Documentation

Creates a new maintenance configuration or replaces an existing maintenance configuration for a table

Description

Creates a new maintenance configuration or replaces an existing maintenance configuration for a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_put_table_maintenance_configuration/ for full documentation.

Usage

s3tables_put_table_maintenance_configuration(
  tableBucketARN,
  namespace,
  name,
  type,
  value
)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table associated with the maintenance configuration.

namespace

[required] The namespace of the table.

name

[required] The name of the table.

type

[required] The type of the maintenance configuration.

value

[required] Defines the values of the maintenance configuration for the table.


paws.storage documentation built on May 30, 2026, 9:13 a.m.