s3tables_put_table_policy: Creates a new table policy or replaces an existing table...

View source: R/s3tables_operations.R

s3tables_put_table_policyR Documentation

Creates a new table policy or replaces an existing table policy for a table

Description

Creates a new table policy or replaces an existing table policy for a table. For more information, see Adding a table policy in the Amazon Simple Storage Service User Guide.

See https://www.paws-r-sdk.com/docs/s3tables_put_table_policy/ for full documentation.

Usage

s3tables_put_table_policy(tableBucketARN, namespace, name, resourcePolicy)

Arguments

tableBucketARN

[required] The Amazon Resource Name (ARN) of the table bucket that contains the table.

namespace

[required] The namespace associated with the table.

name

[required] The name of the table.

resourcePolicy

[required] The JSON that defines the policy.


paws.storage documentation built on May 30, 2026, 9:13 a.m.