s3tables_put_table_record_expiration_configuration: Creates or updates the expiration configuration settings for...

View source: R/s3tables_operations.R

s3tables_put_table_record_expiration_configurationR Documentation

Creates or updates the expiration configuration settings for records in a table, including the status of the configuration

Description

Creates or updates the expiration configuration settings for records in a table, including the status of the configuration. If you enable record expiration for a table, records expire and are automatically removed from the table after the number of days that you specify.

See https://www.paws-r-sdk.com/docs/s3tables_put_table_record_expiration_configuration/ for full documentation.

Usage

s3tables_put_table_record_expiration_configuration(tableArn, value)

Arguments

tableArn

[required] The Amazon Resource Name (ARN) of the table.

value

[required] The record expiration configuration to apply to the table, including the status (enabled or disabled) and retention period in days.


paws.storage documentation built on May 30, 2026, 9:13 a.m.