s3tables_untag_resource: Removes the specified user-defined tags from an Amazon S3...

View source: R/s3tables_operations.R

s3tables_untag_resourceR Documentation

Removes the specified user-defined tags from an Amazon S3 Tables resource

Description

Removes the specified user-defined tags from an Amazon S3 Tables resource. You can pass one or more tag keys.

See https://www.paws-r-sdk.com/docs/s3tables_untag_resource/ for full documentation.

Usage

s3tables_untag_resource(resourceArn, tagKeys)

Arguments

resourceArn

[required] The Amazon Resource Name (ARN) of the Amazon S3 Tables resource that you're removing tags from. The tagged resource can be a table bucket or a table. For a list of all S3 resources that support tagging, see Managing tags for Amazon S3 resources.

tagKeys

[required] The array of tag keys that you're removing from the S3 Tables resource. For more information, see Tagging for cost allocation or attribute-based access control (ABAC).


paws.storage documentation built on May 30, 2026, 9:13 a.m.