View source: R/s3tables_operations.R
| s3tables_update_table_metadata_location | R Documentation |
Updates the metadata location for a table. The metadata location of a table must be an S3 URI that begins with the table's warehouse location. The metadata location for an Apache Iceberg table must end with .metadata.json, or if the metadata file is Gzip-compressed, .metadata.json.gz.
See https://www.paws-r-sdk.com/docs/s3tables_update_table_metadata_location/ for full documentation.
s3tables_update_table_metadata_location(
tableBucketARN,
namespace,
name,
versionToken,
metadataLocation
)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket. |
namespace |
[required] The namespace of the table. |
name |
[required] The name of the table. |
versionToken |
[required] The version token of the table. |
metadataLocation |
[required] The new metadata location for the table. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.