View source: R/storagegateway_operations.R
| storagegateway_add_cache | R Documentation |
Configures one or more gateway local disks as cache for a gateway. This operation is only supported in the cached volume, tape, and file gateway type (see How Storage Gateway works (architecture).
See https://www.paws-r-sdk.com/docs/storagegateway_add_cache/ for full documentation.
storagegateway_add_cache(GatewayARN, DiskIds)
GatewayARN |
[required] The Amazon Resource Name (ARN) of the gateway. Use the |
DiskIds |
[required] An array of strings that identify disks that are to be configured as working storage. Each string has a minimum length of 1 and maximum length of 300. You can get the disk IDs from the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.