storagegateway_cancel_cache_report: Cancels generation of a specified cache report

View source: R/storagegateway_operations.R

storagegateway_cancel_cache_reportR Documentation

Cancels generation of a specified cache report

Description

Cancels generation of a specified cache report. You can use this operation to manually cancel an IN-PROGRESS report for any reason. This action changes the report status from IN-PROGRESS to CANCELLED. You can only cancel in-progress reports. If the the report you attempt to cancel is in FAILED, ERROR, or COMPLETED state, the cancel operation returns an error.

See https://www.paws-r-sdk.com/docs/storagegateway_cancel_cache_report/ for full documentation.

Usage

storagegateway_cancel_cache_report(CacheReportARN)

Arguments

CacheReportARN

[required] The Amazon Resource Name (ARN) of the cache report you want to cancel.


paws.storage documentation built on May 30, 2026, 9:13 a.m.