storagegateway_delete_automatic_tape_creation_policy: Deletes the automatic tape creation policy of a gateway

View source: R/storagegateway_operations.R

storagegateway_delete_automatic_tape_creation_policyR Documentation

Deletes the automatic tape creation policy of a gateway

Description

Deletes the automatic tape creation policy of a gateway. If you delete this policy, new virtual tapes must be created manually. Use the Amazon Resource Name (ARN) of the gateway in your request to remove the policy.

See https://www.paws-r-sdk.com/docs/storagegateway_delete_automatic_tape_creation_policy/ for full documentation.

Usage

storagegateway_delete_automatic_tape_creation_policy(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.