View source: R/storagegateway_operations.R
| storagegateway_delete_cache_report | R Documentation |
Deletes the specified cache report and any associated tags from the Storage Gateway database. You can only delete completed reports. If the status of the report you attempt to delete still IN-PROGRESS, the delete operation returns an error. You can use cancel_cache_report to cancel an IN-PROGRESS report.
See https://www.paws-r-sdk.com/docs/storagegateway_delete_cache_report/ for full documentation.
storagegateway_delete_cache_report(CacheReportARN)
CacheReportARN |
[required] The Amazon Resource Name (ARN) of the cache report you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.