storagegateway_describe_bandwidth_rate_limit: Returns the bandwidth rate limits of a gateway

View source: R/storagegateway_operations.R

storagegateway_describe_bandwidth_rate_limitR Documentation

Returns the bandwidth rate limits of a gateway

Description

Returns the bandwidth rate limits of a gateway. By default, these limits are not set, which means no bandwidth rate limiting is in effect. This operation is supported only for the stored volume, cached volume, and tape gateway types. To describe bandwidth rate limits for S3 file gateways, use describe_bandwidth_rate_limit_schedule.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_bandwidth_rate_limit/ for full documentation.

Usage

storagegateway_describe_bandwidth_rate_limit(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.