storagegateway_describe_cache: Returns information about the cache of a gateway

View source: R/storagegateway_operations.R

storagegateway_describe_cacheR Documentation

Returns information about the cache of a gateway

Description

Returns information about the cache of a gateway. This operation is only supported in the cached volume, tape, and file gateway types.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_cache/ for full documentation.

Usage

storagegateway_describe_cache(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.