storagegateway_describe_cache_report: Returns information about the specified cache report,...

View source: R/storagegateway_operations.R

storagegateway_describe_cache_reportR Documentation

Returns information about the specified cache report, including completion status and generation progress

Description

Returns information about the specified cache report, including completion status and generation progress.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_cache_report/ for full documentation.

Usage

storagegateway_describe_cache_report(CacheReportARN)

Arguments

CacheReportARN

[required] The Amazon Resource Name (ARN) of the cache report you want to describe.


paws.storage documentation built on May 30, 2026, 9:13 a.m.