storagegateway_describe_gateway_information: Returns metadata about a gateway such as its name, network...

View source: R/storagegateway_operations.R

storagegateway_describe_gateway_informationR Documentation

Returns metadata about a gateway such as its name, network interfaces, time zone, status, and software version

Description

Returns metadata about a gateway such as its name, network interfaces, time zone, status, and software version. To specify which gateway to describe, use the Amazon Resource Name (ARN) of the gateway in your request.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_gateway_information/ for full documentation.

Usage

storagegateway_describe_gateway_information(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.