storagegateway_describe_smb_settings: Gets a description of a Server Message Block (SMB) file share...

View source: R/storagegateway_operations.R

storagegateway_describe_smb_settingsR Documentation

Gets a description of a Server Message Block (SMB) file share settings from a file gateway

Description

Gets a description of a Server Message Block (SMB) file share settings from a file gateway. This operation is only supported for file gateways.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_smb_settings/ for full documentation.

Usage

storagegateway_describe_smb_settings(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.