storagegateway_describe_tape_recovery_points: Returns a list of virtual tape recovery points that are...

View source: R/storagegateway_operations.R

storagegateway_describe_tape_recovery_pointsR Documentation

Returns a list of virtual tape recovery points that are available for the specified tape gateway

Description

Returns a list of virtual tape recovery points that are available for the specified tape gateway.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_tape_recovery_points/ for full documentation.

Usage

storagegateway_describe_tape_recovery_points(
  GatewayARN,
  Marker = NULL,
  Limit = NULL
)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.

Marker

An opaque string that indicates the position at which to begin describing the virtual tape recovery points.

Limit

Specifies that the number of virtual tape recovery points that are described be limited to the specified number.


paws.storage documentation built on May 30, 2026, 9:13 a.m.