storagegateway_describe_upload_buffer: Returns information about the upload buffer of a gateway

View source: R/storagegateway_operations.R

storagegateway_describe_upload_bufferR Documentation

Returns information about the upload buffer of a gateway

Description

Returns information about the upload buffer of a gateway. This operation is supported for the stored volume, cached volume, and tape gateway types.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_upload_buffer/ for full documentation.

Usage

storagegateway_describe_upload_buffer(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.