storagegateway_describe_working_storage: Returns information about the working storage of a gateway

View source: R/storagegateway_operations.R

storagegateway_describe_working_storageR Documentation

Returns information about the working storage of a gateway

Description

Returns information about the working storage of a gateway. This operation is only supported in the stored volumes gateway type. This operation is deprecated in cached volumes API version (20120630). Use DescribeUploadBuffer instead.

See https://www.paws-r-sdk.com/docs/storagegateway_describe_working_storage/ for full documentation.

Usage

storagegateway_describe_working_storage(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.