storagegateway_disable_gateway: Disables a tape gateway when the gateway is no longer...

View source: R/storagegateway_operations.R

storagegateway_disable_gatewayR Documentation

Disables a tape gateway when the gateway is no longer functioning

Description

Disables a tape gateway when the gateway is no longer functioning. For example, if your gateway VM is damaged, you can disable the gateway so you can recover virtual tapes.

See https://www.paws-r-sdk.com/docs/storagegateway_disable_gateway/ for full documentation.

Usage

storagegateway_disable_gateway(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.