storagegateway_evict_files_failing_upload: Starts a process that cleans the specified file share's cache...

View source: R/storagegateway_operations.R

storagegateway_evict_files_failing_uploadR Documentation

Starts a process that cleans the specified file share's cache of file entries that are failing upload to Amazon S3

Description

Starts a process that cleans the specified file share's cache of file entries that are failing upload to Amazon S3. This API operation reports success if the request is received with valid arguments, and there are no other cache clean operations currently in-progress for the specified file share. After a successful request, the cache clean operation occurs asynchronously and reports progress using CloudWatch logs and notifications.

See https://www.paws-r-sdk.com/docs/storagegateway_evict_files_failing_upload/ for full documentation.

Usage

storagegateway_evict_files_failing_upload(FileShareARN, ForceRemove = NULL)

Arguments

FileShareARN

[required] The Amazon Resource Name (ARN) of the file share for which you want to start the cache clean operation.

ForceRemove

Specifies whether cache entries with full or partial file data currently stored on the gateway will be forcibly removed by the cache clean operation.

Valid arguments:

  • False - The cache clean operation skips cache entries failing upload if they are associated with data currently stored on the gateway. This preserves the cached data.

  • True - The cache clean operation removes cache entries failing upload even if they are associated with data currently stored on the gateway. This deletes the cached data.

    If ForceRemove is set to True, the cache clean operation will delete file data from the gateway which might otherwise be recoverable.


paws.storage documentation built on May 30, 2026, 9:13 a.m.