storagegateway_list_automatic_tape_creation_policies: Lists the automatic tape creation policies for a gateway

View source: R/storagegateway_operations.R

storagegateway_list_automatic_tape_creation_policiesR Documentation

Lists the automatic tape creation policies for a gateway

Description

Lists the automatic tape creation policies for a gateway. If there are no automatic tape creation policies for the gateway, it returns an empty list.

See https://www.paws-r-sdk.com/docs/storagegateway_list_automatic_tape_creation_policies/ for full documentation.

Usage

storagegateway_list_automatic_tape_creation_policies(GatewayARN = NULL)

Arguments

GatewayARN

The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.