storagegateway_list_cache_reports: Returns a list of existing cache reports for all file shares...

View source: R/storagegateway_operations.R

storagegateway_list_cache_reportsR Documentation

Returns a list of existing cache reports for all file shares associated with your Amazon Web Services account

Description

Returns a list of existing cache reports for all file shares associated with your Amazon Web Services account. This list includes all information provided by the describe_cache_report action, such as report name, status, completion progress, start time, end time, filters, and tags.

See https://www.paws-r-sdk.com/docs/storagegateway_list_cache_reports/ for full documentation.

Usage

storagegateway_list_cache_reports(Marker = NULL)

Arguments

Marker

Opaque pagination token returned from a previous list_cache_reports operation. If present, Marker specifies where to continue the list from after a previous call to list_cache_reports. Optional.


paws.storage documentation built on May 30, 2026, 9:13 a.m.