storagegateway_list_file_system_associations: Gets a list of FileSystemAssociationSummary objects

View source: R/storagegateway_operations.R

storagegateway_list_file_system_associationsR Documentation

Gets a list of FileSystemAssociationSummary objects

Description

Gets a list of FileSystemAssociationSummary objects. Each object contains a summary of a file system association. This operation is only supported for FSx File Gateways.

See https://www.paws-r-sdk.com/docs/storagegateway_list_file_system_associations/ for full documentation.

Usage

storagegateway_list_file_system_associations(
  GatewayARN = NULL,
  Limit = NULL,
  Marker = NULL
)

Arguments

GatewayARN

The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.

Limit

The maximum number of file system associations to return in the response. If present, Limit must be an integer with a value greater than zero. Optional.

Marker

Opaque pagination token returned from a previous list_file_system_associations operation. If present, Marker specifies where to continue the list from after a previous call to list_file_system_associations. Optional.


paws.storage documentation built on May 30, 2026, 9:13 a.m.