storagegateway_list_volume_recovery_points: Lists the recovery points for a specified gateway

View source: R/storagegateway_operations.R

storagegateway_list_volume_recovery_pointsR Documentation

Lists the recovery points for a specified gateway

Description

Lists the recovery points for a specified gateway. This operation is only supported in the cached volume gateway type.

See https://www.paws-r-sdk.com/docs/storagegateway_list_volume_recovery_points/ for full documentation.

Usage

storagegateway_list_volume_recovery_points(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.