storagegateway_notify_when_uploaded: Sends you notification through Amazon EventBridge when all...

View source: R/storagegateway_operations.R

storagegateway_notify_when_uploadedR Documentation

Sends you notification through Amazon EventBridge when all files written to your file share have been uploaded to Amazon S3

Description

Sends you notification through Amazon EventBridge when all files written to your file share have been uploaded to Amazon S3.

See https://www.paws-r-sdk.com/docs/storagegateway_notify_when_uploaded/ for full documentation.

Usage

storagegateway_notify_when_uploaded(FileShareARN)

Arguments

FileShareARN

[required] The Amazon Resource Name (ARN) of the file share.


paws.storage documentation built on May 30, 2026, 9:13 a.m.