storagegateway_retrieve_tape_recovery_point: Retrieves the recovery point for the specified virtual tape

View source: R/storagegateway_operations.R

storagegateway_retrieve_tape_recovery_pointR Documentation

Retrieves the recovery point for the specified virtual tape

Description

Retrieves the recovery point for the specified virtual tape. This operation is only supported in the tape gateway type.

See https://www.paws-r-sdk.com/docs/storagegateway_retrieve_tape_recovery_point/ for full documentation.

Usage

storagegateway_retrieve_tape_recovery_point(TapeARN, GatewayARN)

Arguments

TapeARN

[required] The Amazon Resource Name (ARN) of the virtual tape for which you want to retrieve the recovery point.

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.