storagegateway_start_gateway: Starts a gateway that you previously shut down (see...

View source: R/storagegateway_operations.R

storagegateway_start_gatewayR Documentation

Starts a gateway that you previously shut down (see ShutdownGateway)

Description

Starts a gateway that you previously shut down (see shutdown_gateway). After the gateway starts, you can then make other API calls, your applications can read from or write to the gateway's storage volumes and you will be able to take snapshot backups.

See https://www.paws-r-sdk.com/docs/storagegateway_start_gateway/ for full documentation.

Usage

storagegateway_start_gateway(GatewayARN)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.


paws.storage documentation built on May 30, 2026, 9:13 a.m.