storagegateway_update_bandwidth_rate_limit_schedule: Updates the bandwidth rate limit schedule for a specified...

View source: R/storagegateway_operations.R

storagegateway_update_bandwidth_rate_limit_scheduleR Documentation

Updates the bandwidth rate limit schedule for a specified gateway

Description

Updates the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have bandwidth rate limit schedules, which means no bandwidth rate limiting is in effect. Use this to initiate or update a gateway's bandwidth rate limit schedule. This operation is supported for volume, tape, and S3 file gateways. S3 file gateways support bandwidth rate limits for upload only. FSx file gateways do not support bandwidth rate limits.

See https://www.paws-r-sdk.com/docs/storagegateway_update_bandwidth_rate_limit_schedule/ for full documentation.

Usage

storagegateway_update_bandwidth_rate_limit_schedule(
  GatewayARN,
  BandwidthRateLimitIntervals
)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.

BandwidthRateLimitIntervals

[required] An array containing bandwidth rate limit schedule intervals for a gateway. When no bandwidth rate limit intervals have been scheduled, the array is empty.


paws.storage documentation built on May 30, 2026, 9:13 a.m.