storagegateway_update_gateway_information: Updates a gateway's metadata, which includes the gateway's...

View source: R/storagegateway_operations.R

storagegateway_update_gateway_informationR Documentation

Updates a gateway's metadata, which includes the gateway's name, time zone, and metadata cache size

Description

Updates a gateway's metadata, which includes the gateway's name, time zone, and metadata cache size. To specify which gateway to update, use the Amazon Resource Name (ARN) of the gateway in your request.

See https://www.paws-r-sdk.com/docs/storagegateway_update_gateway_information/ for full documentation.

Usage

storagegateway_update_gateway_information(
  GatewayARN,
  GatewayName = NULL,
  GatewayTimezone = NULL,
  CloudWatchLogGroupARN = NULL,
  GatewayCapacity = NULL
)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.

GatewayName

The name you configured for your gateway.

GatewayTimezone

A value that indicates the time zone of the gateway.

CloudWatchLogGroupARN

The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that you want to use to monitor and log events in the gateway.

For more information, see What is Amazon CloudWatch Logs?

GatewayCapacity

Specifies the size of the gateway's metadata cache. This setting impacts gateway performance and hardware recommendations. For more information, see Performance guidance for gateways with multiple file shares in the Amazon S3 File Gateway User Guide.


paws.storage documentation built on May 30, 2026, 9:13 a.m.