View source: R/storagegateway_operations.R
| storagegateway_update_smb_file_share | R Documentation |
Updates a Server Message Block (SMB) file share. This operation is only supported for S3 File Gateways.
See https://www.paws-r-sdk.com/docs/storagegateway_update_smb_file_share/ for full documentation.
storagegateway_update_smb_file_share(
FileShareARN,
EncryptionType = NULL,
KMSEncrypted = NULL,
KMSKey = NULL,
DefaultStorageClass = NULL,
ObjectACL = NULL,
ReadOnly = NULL,
GuessMIMETypeEnabled = NULL,
RequesterPays = NULL,
SMBACLEnabled = NULL,
AccessBasedEnumeration = NULL,
AdminUserList = NULL,
ValidUserList = NULL,
InvalidUserList = NULL,
AuditDestinationARN = NULL,
CaseSensitivity = NULL,
FileShareName = NULL,
CacheAttributes = NULL,
NotificationPolicy = NULL,
OplocksEnabled = NULL
)
FileShareARN |
[required] The Amazon Resource Name (ARN) of the SMB file share that you want to update. |
EncryptionType |
A value that specifies the type of server-side encryption that the file share will use for the data that it stores in Amazon S3. We recommend using If values for both parameters exist in the same request, then the specified encryption methods must not conflict. For example, if |
KMSEncrypted |
Optional. Set to We recommend using If values for both parameters exist in the same request, then the specified encryption methods must not conflict. For example, if Valid Values: |
KMSKey |
Optional. The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does not support asymmetric CMKs. This value must be set if |
DefaultStorageClass |
The default storage class for objects put into an Amazon S3 bucket by the S3 File Gateway. The default value is Valid Values: |
ObjectACL |
A value that sets the access control list (ACL) permission for objects in the S3 bucket that a S3 File Gateway puts objects into. The default value is |
ReadOnly |
A value that sets the write status of a file share. Set this value to Valid Values: |
GuessMIMETypeEnabled |
A value that enables guessing of the MIME type for uploaded objects based on file extensions. Set this value to Valid Values: |
RequesterPays |
A value that sets who pays the cost of the request and the cost associated with data download from the S3 bucket. If this value is set to
Valid Values: |
SMBACLEnabled |
Set this value to For more information, see Using Windows ACLs to limit SMB file share access in the Amazon S3 File Gateway User Guide. Valid Values: |
AccessBasedEnumeration |
The files and folders on this share will only be visible to users with read access. |
AdminUserList |
A list of users or groups in the Active Directory that have administrator rights to the file share. A group must be prefixed with the @ character. Acceptable formats include: |
ValidUserList |
A list of users or groups in the Active Directory that are allowed to access the file share. A group must be prefixed with the @ character. Acceptable formats include: |
InvalidUserList |
A list of users or groups in the Active Directory that are not allowed to access the file share. A group must be prefixed with the @ character. Acceptable formats include: |
AuditDestinationARN |
The Amazon Resource Name (ARN) of the storage used for audit logs. |
CaseSensitivity |
The case of an object name in an Amazon S3 bucket. For |
FileShareName |
The name of the file share. Optional.
A valid SMB file share name cannot contain the following characters: |
CacheAttributes |
Specifies refresh cache information for the file share. |
NotificationPolicy |
The notification policy of the file share.
This setting is not meant to specify an exact time at which the notification will be sent. In some cases, the gateway might require more than the specified delay time to generate and send notifications. The following example sets
The following example sets
|
OplocksEnabled |
Specifies whether opportunistic locking is enabled for the SMB file share. Enabling opportunistic locking on case-sensitive shares is not recommended for workloads that involve access to files with the same name in different case. Valid Values: |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.