storagegateway_update_smb_file_share_visibility: Controls whether the shares on an S3 File Gateway are visible...

View source: R/storagegateway_operations.R

storagegateway_update_smb_file_share_visibilityR Documentation

Controls whether the shares on an S3 File Gateway are visible in a net view or browse list

Description

Controls whether the shares on an S3 File Gateway are visible in a net view or browse list. The operation is only supported for S3 File Gateways.

See https://www.paws-r-sdk.com/docs/storagegateway_update_smb_file_share_visibility/ for full documentation.

Usage

storagegateway_update_smb_file_share_visibility(GatewayARN, FileSharesVisible)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.

FileSharesVisible

[required] The shares on this gateway appear when listing shares.


paws.storage documentation built on May 30, 2026, 9:13 a.m.