storagegateway_update_smb_local_groups: Updates the list of Active Directory users and groups that...

View source: R/storagegateway_operations.R

storagegateway_update_smb_local_groupsR Documentation

Updates the list of Active Directory users and groups that have special permissions for SMB file shares on the gateway

Description

Updates the list of Active Directory users and groups that have special permissions for SMB file shares on the gateway.

See https://www.paws-r-sdk.com/docs/storagegateway_update_smb_local_groups/ for full documentation.

Usage

storagegateway_update_smb_local_groups(GatewayARN, SMBLocalGroups)

Arguments

GatewayARN

[required] The Amazon Resource Name (ARN) of the gateway. Use the list_gateways operation to return a list of gateways for your account and Amazon Web Services Region.

SMBLocalGroups

[required] A list of Active Directory users and groups that you want to grant special permissions for SMB file shares on the gateway.


paws.storage documentation built on May 30, 2026, 9:13 a.m.