View source: R/backup_operations.R
| backup_create_restore_access_backup_vault | R Documentation |
Creates a restore access backup vault that provides temporary access to recovery points in a logically air-gapped backup vault, subject to MPA approval.
See https://www.paws-r-sdk.com/docs/backup_create_restore_access_backup_vault/ for full documentation.
backup_create_restore_access_backup_vault(
SourceBackupVaultArn,
BackupVaultName = NULL,
BackupVaultTags = NULL,
CreatorRequestId = NULL,
RequesterComment = NULL
)
SourceBackupVaultArn |
[required] The ARN of the source backup vault containing the recovery points to which temporary access is requested. |
BackupVaultName |
The name of the backup vault to associate with an MPA approval team. |
BackupVaultTags |
Optional tags to assign to the restore access backup vault. |
CreatorRequestId |
A unique string that identifies the request and allows failed requests to be retried without the risk of executing the operation twice. |
RequesterComment |
A comment explaining the reason for requesting restore access to the backup vault. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.