View source: R/backup_operations.R
| backup_describe_backup_access_point | R Documentation |
Returns metadata about a backup access point, including its status and the details of the underlying Amazon S3 access point.
See https://www.paws-r-sdk.com/docs/backup_describe_backup_access_point/ for full documentation.
backup_describe_backup_access_point(AccessPointArn)
AccessPointArn |
[required] The Amazon Resource Name (ARN) of the backup access point to describe. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.