View source: R/backup_operations.R
| backup_disassociate_backup_vault_mpa_approval_team | R Documentation |
Removes the association between an MPA approval team and a backup vault, disabling the MPA approval workflow for restore operations.
See https://www.paws-r-sdk.com/docs/backup_disassociate_backup_vault_mpa_approval_team/ for full documentation.
backup_disassociate_backup_vault_mpa_approval_team(
BackupVaultName,
RequesterComment = NULL
)
BackupVaultName |
[required] The name of the backup vault from which to disassociate the MPA approval team. |
RequesterComment |
An optional comment explaining the reason for disassociating the MPA approval team from the backup vault. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.