View source: R/backup_operations.R
| backup_list_backup_access_points_by_recovery_point | R Documentation |
Returns the backup access points associated with the specified recovery point.
See https://www.paws-r-sdk.com/docs/backup_list_backup_access_points_by_recovery_point/ for full documentation.
backup_list_backup_access_points_by_recovery_point(
MaxResults = NULL,
NextToken = NULL,
RecoveryPointArn
)
MaxResults |
The maximum number of items to be returned. |
NextToken |
The next item following a partial list of returned items. For example, if a request is made to return |
RecoveryPointArn |
[required] The Amazon Resource Name (ARN) of the recovery point whose backup access points you want to list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.