View source: R/backup_operations.R
| backup_list_backup_access_points_by_resource | R Documentation |
Returns the backup access points associated with the specified resource, such as an Amazon S3 bucket.
See https://www.paws-r-sdk.com/docs/backup_list_backup_access_points_by_resource/ for full documentation.
backup_list_backup_access_points_by_resource(
MaxResults = NULL,
NextToken = NULL,
ResourceArn
)
MaxResults |
The maximum number of items to be returned. |
NextToken |
The next item following a partial list of returned items. For example, if a request is made to return |
ResourceArn |
[required] The Amazon Resource Name (ARN) of the resource whose backup access points you want to list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.