View source: R/backup_operations.R
| backup_list_restore_access_backup_vaults | R Documentation |
Returns a list of restore access backup vaults associated with a specified backup vault.
See https://www.paws-r-sdk.com/docs/backup_list_restore_access_backup_vaults/ for full documentation.
backup_list_restore_access_backup_vaults(
BackupVaultName,
NextToken = NULL,
MaxResults = NULL
)
BackupVaultName |
[required] The name of the backup vault for which to list associated restore access backup vaults. |
NextToken |
The pagination token from a previous request to retrieve the next set of results. |
MaxResults |
The maximum number of items to return in the response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.