View source: R/backup_operations.R
| backup_revoke_restore_access_backup_vault | R Documentation |
Revokes access to a restore access backup vault, removing the ability to restore from its recovery points and permanently deleting the vault.
See https://www.paws-r-sdk.com/docs/backup_revoke_restore_access_backup_vault/ for full documentation.
backup_revoke_restore_access_backup_vault(
BackupVaultName,
RestoreAccessBackupVaultArn,
RequesterComment = NULL
)
BackupVaultName |
[required] The name of the source backup vault associated with the restore access backup vault to be revoked. |
RestoreAccessBackupVaultArn |
[required] The ARN of the restore access backup vault to revoke. |
RequesterComment |
A comment explaining the reason for revoking access to the restore access backup vault. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.