View source: R/backup_operations.R
| backup_update_global_settings | R Documentation |
Updates whether the Amazon Web Services account has enabled different cross-account management options, including cross-account backup, multi-party approval, and delegated administrator. Returns an error if the account is not an Organizations management account. Use the describe_global_settings API to determine the current settings.
See https://www.paws-r-sdk.com/docs/backup_update_global_settings/ for full documentation.
backup_update_global_settings(GlobalSettings = NULL)
GlobalSettings |
Inputs can include: A value for A value for Multi-party approval, styled as A value for Backup Service-Linked Role creation, styled as |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.