View source: R/efs_operations.R
| efs_create_mount_target | R Documentation |
Creates a mount target for a file system. You can then mount the file system on EC2 instances by using the mount target.
See https://www.paws-r-sdk.com/docs/efs_create_mount_target/ for full documentation.
efs_create_mount_target(
FileSystemId,
SubnetId,
IpAddress = NULL,
Ipv6Address = NULL,
IpAddressType = NULL,
SecurityGroups = NULL
)
FileSystemId |
[required] The ID of the file system for which to create the mount target. |
SubnetId |
[required] The ID of the subnet to add the mount target in. For One Zone file systems, use the subnet that is associated with the file system's Availability Zone. |
IpAddress |
If the IP address type for the mount target is IPv4, then specify the IPv4 address within the address range of the specified subnet. |
Ipv6Address |
If the IP address type for the mount target is IPv6, then specify the IPv6 address within the address range of the specified subnet. |
IpAddressType |
Specify the type of IP address of the mount target you are creating. Options are IPv4, dual stack, or IPv6. If you don’t specify an IpAddressType, then IPv4 is used.
Creating IPv6 mount target only ENI in dual-stack subnet is not supported. |
SecurityGroups |
VPC security group IDs, of the form |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.