View source: R/fsx_operations.R
| fsx_copy_backup | R Documentation |
Copies an existing backup within the same Amazon Web Services account to another Amazon Web Services Region (cross-Region copy) or within the same Amazon Web Services Region (in-Region copy). You can have up to five backup copy requests in progress to a single destination Region per account.
See https://www.paws-r-sdk.com/docs/fsx_copy_backup/ for full documentation.
fsx_copy_backup(
ClientRequestToken = NULL,
SourceBackupId,
SourceRegion = NULL,
KmsKeyId = NULL,
CopyTags = NULL,
Tags = NULL
)
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
SourceBackupId |
[required] The ID of the source backup. Specifies the ID of the backup that's being copied. |
SourceRegion |
The source Amazon Web Services Region of the backup. Specifies the Amazon Web Services Region from which the backup is being copied. The source and destination Regions must be in the same Amazon Web Services partition. If you don't specify a Region, |
KmsKeyId |
Specifies the ID of the Key Management Service (KMS) key to use for encrypting data on Amazon FSx file systems, as follows:
If a |
CopyTags |
A Boolean flag indicating whether tags from the source backup should be copied to the backup copy. This value defaults to If you set |
Tags |
A list of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.