View source: R/fsx_operations.R
| fsx_create_snapshot | R Documentation |
Creates a snapshot of an existing Amazon FSx for OpenZFS volume. With snapshots, you can easily undo file changes and compare file versions by restoring the volume to a previous version.
See https://www.paws-r-sdk.com/docs/fsx_create_snapshot/ for full documentation.
fsx_create_snapshot(ClientRequestToken = NULL, Name, VolumeId, Tags = NULL)
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
Name |
[required] The name of the snapshot. |
VolumeId |
[required] The ID of the volume that you are taking a snapshot of. |
Tags |
A list of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.