View source: R/fsx_operations.R
| fsx_delete_file_cache | R Documentation |
Deletes an Amazon File Cache resource. After deletion, the cache no longer exists, and its data is gone.
See https://www.paws-r-sdk.com/docs/fsx_delete_file_cache/ for full documentation.
fsx_delete_file_cache(FileCacheId, ClientRequestToken = NULL)
FileCacheId |
[required] The ID of the cache that's being deleted. |
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.