View source: R/fsx_operations.R
| fsx_describe_s3_access_point_attachments | R Documentation |
Describes one or more S3 access points attached to Amazon FSx volumes.
See https://www.paws-r-sdk.com/docs/fsx_describe_s3_access_point_attachments/ for full documentation.
fsx_describe_s3_access_point_attachments(
Names = NULL,
Filters = NULL,
MaxResults = NULL,
NextToken = NULL
)
Names |
The names of the S3 access point attachments whose descriptions you want to retrieve. |
Filters |
Enter a filter Name and Values pair to view a select set of S3 access point attachments. |
MaxResults |
The maximum number of resources to return in the response. This value must be an integer greater than zero. |
NextToken |
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.