View source: R/fsx_operations.R
| fsx_describe_snapshots | R Documentation |
Returns the description of specific Amazon FSx for OpenZFS snapshots, if a SnapshotIds value is provided. Otherwise, this operation returns all snapshots owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.
See https://www.paws-r-sdk.com/docs/fsx_describe_snapshots/ for full documentation.
fsx_describe_snapshots(
SnapshotIds = NULL,
Filters = NULL,
MaxResults = NULL,
NextToken = NULL,
IncludeShared = NULL
)
SnapshotIds |
The IDs of the snapshots that you want to retrieve. This parameter value overrides any filters. If any IDs aren't found, a |
Filters |
The filters structure. The supported names are |
MaxResults |
The maximum number of resources to return in the response. This value must be an integer greater than zero. |
NextToken |
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous |
IncludeShared |
Set to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.