View source: R/fsx_operations.R
| fsx_describe_storage_virtual_machines | R Documentation |
Describes one or more Amazon FSx for NetApp ONTAP storage virtual machines (SVMs).
See https://www.paws-r-sdk.com/docs/fsx_describe_storage_virtual_machines/ for full documentation.
fsx_describe_storage_virtual_machines(
StorageVirtualMachineIds = NULL,
Filters = NULL,
MaxResults = NULL,
NextToken = NULL
)
StorageVirtualMachineIds |
Enter the ID of one or more SVMs that you want to view. |
Filters |
Enter a filter name:value pair to view a select set of SVMs. |
MaxResults |
The maximum number of resources to return in the response. This value must be an integer greater than zero. |
NextToken |
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.