View source: R/fsx_operations.R
| fsx_describe_volumes | R Documentation |
Describes one or more Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volumes.
See https://www.paws-r-sdk.com/docs/fsx_describe_volumes/ for full documentation.
fsx_describe_volumes(
VolumeIds = NULL,
Filters = NULL,
MaxResults = NULL,
NextToken = NULL
)
VolumeIds |
The IDs of the volumes whose descriptions you want to retrieve. |
Filters |
Enter a filter |
MaxResults |
The maximum number of resources to return in the response. This value must be an integer greater than zero. |
NextToken |
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.