View source: R/fsx_operations.R
| fsx_detach_and_delete_s3_access_point | R Documentation |
Detaches an S3 access point from an Amazon FSx volume and deletes the S3 access point.
See https://www.paws-r-sdk.com/docs/fsx_detach_and_delete_s3_access_point/ for full documentation.
fsx_detach_and_delete_s3_access_point(ClientRequestToken = NULL, Name)
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
Name |
[required] The name of the S3 access point attachment that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.