View source: R/fsx_operations.R
| fsx_start_misconfigured_state_recovery | R Documentation |
After performing steps to repair the Active Directory configuration of an FSx for Windows File Server file system, use this action to initiate the process of Amazon FSx attempting to reconnect to the file system.
See https://www.paws-r-sdk.com/docs/fsx_start_misconfigured_state_recovery/ for full documentation.
fsx_start_misconfigured_state_recovery(ClientRequestToken = NULL, FileSystemId)
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
FileSystemId |
[required] The globally unique ID of the file system, assigned by Amazon FSx. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.