View source: R/fsx_operations.R
| fsx_update_shared_vpc_configuration | R Documentation |
Configures whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner. For more information, see the Amazon FSx for NetApp ONTAP User Guide.
See https://www.paws-r-sdk.com/docs/fsx_update_shared_vpc_configuration/ for full documentation.
fsx_update_shared_vpc_configuration(
EnableFsxRouteTableUpdatesFromParticipantAccounts = NULL,
ClientRequestToken = NULL
)
EnableFsxRouteTableUpdatesFromParticipantAccounts |
Specifies whether participant accounts can create FSx for ONTAP Multi-AZ file systems in shared subnets. Set to |
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.