View source: R/fsx_operations.R
| fsx_update_snapshot | R Documentation |
Updates the name of an Amazon FSx for OpenZFS snapshot.
See https://www.paws-r-sdk.com/docs/fsx_update_snapshot/ for full documentation.
fsx_update_snapshot(ClientRequestToken = NULL, Name, SnapshotId)
ClientRequestToken |
(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK. |
Name |
[required] The name of the snapshot to update. |
SnapshotId |
[required] The ID of the snapshot that you want to update, in the format |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.