View source: R/omics_operations.R
| omics_batch_delete_read_set | R Documentation |
Deletes one or more read sets. If the operation is successful, it returns a response with no body. If there is an error with deleting one of the read sets, the operation returns an error list. If the operation successfully deletes only a subset of files, it will return an error list for the remaining files that fail to be deleted. There is a limit of 100 read sets that can be deleted in each batch_delete_read_set API call.
See https://www.paws-r-sdk.com/docs/omics_batch_delete_read_set/ for full documentation.
omics_batch_delete_read_set(ids, sequenceStoreId)
ids |
[required] The read sets' IDs. |
sequenceStoreId |
[required] The read sets' sequence store ID. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.