View source: R/omics_operations.R
| omics_create_sequence_store | R Documentation |
Creates a sequence store and returns its metadata. Sequence stores are used to store sequence data files called read sets that are saved in FASTQ, BAM, uBAM, or CRAM formats. For aligned formats (BAM and CRAM), a sequence store can only use one reference genome. For unaligned formats (FASTQ and uBAM), a reference genome is not required. You can create multiple sequence stores per region per account.
See https://www.paws-r-sdk.com/docs/omics_create_sequence_store/ for full documentation.
omics_create_sequence_store(
name,
description = NULL,
sseConfig = NULL,
tags = NULL,
clientToken = NULL,
fallbackLocation = NULL,
eTagAlgorithmFamily = NULL,
propagatedSetLevelTags = NULL,
s3AccessConfig = NULL
)
name |
[required] A name for the store. |
description |
A description for the store. |
sseConfig |
Server-side encryption (SSE) settings for the store. |
tags |
Tags for the store. You can configure up to 50 tags. |
clientToken |
An idempotency token used to dedupe retry requests so that duplicate runs are not created. |
fallbackLocation |
An S3 location that is used to store files that have failed a direct upload. You can add or change the |
eTagAlgorithmFamily |
The ETag algorithm family to use for ingested read sets. The default value is MD5up. For more information on ETags, see ETags and data provenance in the Amazon Web Services HealthOmics User Guide. |
propagatedSetLevelTags |
The tags keys to propagate to the S3 objects associated with read sets in the sequence store. These tags can be used as input to add metadata to your read sets. |
s3AccessConfig |
S3 access configuration parameters. This specifies the parameters needed to access logs stored in S3 buckets. The S3 bucket must be in the same region and account as the sequence store. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.