View source: R/omics_operations.R
| omics_delete_annotation_store | R Documentation |
Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers. Existing customers can continue to use the service as normal. For more information, see Amazon Web Services HealthOmics variant store and annotation store availability change.
See https://www.paws-r-sdk.com/docs/omics_delete_annotation_store/ for full documentation.
omics_delete_annotation_store(name, force = NULL)
name |
[required] The store's name. |
force |
Whether to force deletion. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.