View source: R/omics_operations.R
| omics_delete_batch | R Documentation |
Deletes a run batch resource and its associated metadata. This operation does not delete the individual workflow runs. To delete the runs, call delete_run_batch before calling delete_batch.
See https://www.paws-r-sdk.com/docs/omics_delete_batch/ for full documentation.
omics_delete_batch(batchId)
batchId |
[required] The identifier portion of the run batch ARN. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.