View source: R/omics_operations.R
| omics_delete_reference | R Documentation |
Deletes a reference genome and returns a response with no body if the operation is successful. The read set associated with the reference genome must first be deleted before deleting the reference genome. After the reference genome is deleted, you can delete the reference store using the delete_reference_store API operation.
See https://www.paws-r-sdk.com/docs/omics_delete_reference/ for full documentation.
omics_delete_reference(id, referenceStoreId)
id |
[required] The reference's ID. |
referenceStoreId |
[required] The reference's store ID. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.