View source: R/omics_operations.R
| omics_delete_reference_store | R Documentation |
Deletes a reference store and returns a response with no body if the operation is successful. You can only delete a reference store when it does not contain any reference genomes. To empty a reference store, use delete_reference.
See https://www.paws-r-sdk.com/docs/omics_delete_reference_store/ for full documentation.
omics_delete_reference_store(id)
id |
[required] The store's ID. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.