View source: R/omics_operations.R
| omics_delete_run_cache | R Documentation |
Deletes a run cache and returns a response with no body if the operation is successful. This action removes the cache metadata stored in the service account, but does not delete the data in Amazon S3. You can access the cache data in Amazon S3, for inspection or to troubleshoot issues. You can remove old cache data using standard S3 Delete operations.
See https://www.paws-r-sdk.com/docs/omics_delete_run_cache/ for full documentation.
omics_delete_run_cache(id)
id |
[required] Run cache identifier for the cache you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.