View source: R/omics_operations.R
| omics_get_read_set | R Documentation |
Retrieves detailed information from parts of a read set and returns the read set in the same format that it was uploaded. You must have read sets uploaded to your sequence store in order to run this operation.
See https://www.paws-r-sdk.com/docs/omics_get_read_set/ for full documentation.
omics_get_read_set(id, sequenceStoreId, file = NULL, partNumber)
id |
[required] The read set's ID. |
sequenceStoreId |
[required] The read set's sequence store ID. |
file |
The file to retrieve. |
partNumber |
[required] The part number to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.