View source: R/omics_operations.R
| omics_get_read_set_export_job | R Documentation |
Retrieves status information about a read set export job and returns the data in JSON format. Use this operation to actively monitor the progress of an export job.
See https://www.paws-r-sdk.com/docs/omics_get_read_set_export_job/ for full documentation.
omics_get_read_set_export_job(sequenceStoreId, id)
sequenceStoreId |
[required] The job's sequence store ID. |
id |
[required] The job's ID. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.