View source: R/omics_operations.R
| omics_get_read_set_metadata | R Documentation |
Retrieves the metadata for a read set from a sequence store in JSON format. This operation does not return tags. To retrieve the list of tags for a read set, use the list_tags_for_resource API operation.
See https://www.paws-r-sdk.com/docs/omics_get_read_set_metadata/ for full documentation.
omics_get_read_set_metadata(id, sequenceStoreId)
id |
[required] The read set's ID. |
sequenceStoreId |
[required] The read set's sequence store ID. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.