View source: R/omics_operations.R
| omics_list_batch | R Documentation |
Returns a list of run batches in your account, with optional filtering by status, name, or run group. Results are paginated. Only one filter per call is supported.
See https://www.paws-r-sdk.com/docs/omics_list_batch/ for full documentation.
omics_list_batch(
maxItems = NULL,
startingToken = NULL,
status = NULL,
name = NULL,
runGroupId = NULL
)
maxItems |
The maximum number of batches to return. If not specified, defaults to 100. |
startingToken |
A pagination token returned from a prior |
status |
Filter batches by status. |
name |
Filter batches by name. |
runGroupId |
Filter batches by run group ID. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.