View source: R/omics_operations.R
| omics_list_runs_in_batch | R Documentation |
Returns a paginated list of individual workflow runs within a specific batch. Use this operation to map each runSettingId to its HealthOmics-generated runId, and to check the submission status of each run. Only one filter per call is supported.
See https://www.paws-r-sdk.com/docs/omics_list_runs_in_batch/ for full documentation.
omics_list_runs_in_batch(
batchId,
maxItems = NULL,
startingToken = NULL,
submissionStatus = NULL,
runSettingId = NULL,
runId = NULL
)
batchId |
[required] The identifier portion of the run batch ARN. |
maxItems |
The maximum number of runs to return. |
startingToken |
A pagination token returned from a prior |
submissionStatus |
Filter runs by submission status. |
runSettingId |
Filter runs by the customer-provided run setting ID. |
runId |
Filter runs by the HealthOmics-generated run ID. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.