View source: R/omics_operations.R
| omics_list_workflow_versions | R Documentation |
Lists the workflow versions for the specified workflow. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.
See https://www.paws-r-sdk.com/docs/omics_list_workflow_versions/ for full documentation.
omics_list_workflow_versions(
workflowId,
type = NULL,
workflowOwnerId = NULL,
startingToken = NULL,
maxResults = NULL
)
workflowId |
[required] The workflow's ID. The |
type |
The workflow type. |
workflowOwnerId |
The 12-digit account ID of the workflow owner. The workflow owner ID can be retrieved using the |
startingToken |
Specify the pagination token from a previous request to retrieve the next page of results. |
maxResults |
The maximum number of workflows to return in one page of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.