View source: R/omics_operations.R
| omics_start_read_set_import_job | R Documentation |
Imports a read set from the sequence store. Read set import jobs support a maximum of 100 read sets of different types. Monitor the progress of your read set import job by calling the get_read_set_import_job API operation.
See https://www.paws-r-sdk.com/docs/omics_start_read_set_import_job/ for full documentation.
omics_start_read_set_import_job(
sequenceStoreId,
roleArn,
clientToken = NULL,
sources
)
sequenceStoreId |
[required] The read set's sequence store ID. |
roleArn |
[required] A service role for the job. |
clientToken |
To ensure that jobs don't run multiple times, specify a unique token for each job. |
sources |
[required] The job's source files. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.