View source: R/omics_operations.R
| omics_start_variant_import_job | R Documentation |
Amazon Web Services HealthOmics variant stores and annotation stores are no longer open to new customers. Existing customers can continue to use the service as normal. For more information, see Amazon Web Services HealthOmics variant store and annotation store availability change.
See https://www.paws-r-sdk.com/docs/omics_start_variant_import_job/ for full documentation.
omics_start_variant_import_job(
destinationName,
roleArn,
items,
runLeftNormalization = NULL,
annotationFields = NULL
)
destinationName |
[required] The destination variant store for the job. |
roleArn |
[required] A service role for the job. |
items |
[required] Items to import. |
runLeftNormalization |
The job's left normalization setting. |
annotationFields |
The annotation schema generated by the parsed annotation data. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.