View source: R/omics_operations.R
| omics_update_run_cache | R Documentation |
Updates a run cache using its ID and returns a response with no body if the operation is successful. You can update the run cache description, name, or the default run cache behavior with CACHE_ON_FAILURE or CACHE_ALWAYS. To confirm that your run cache settings have been properly updated, use the get_run_cache API operation.
See https://www.paws-r-sdk.com/docs/omics_update_run_cache/ for full documentation.
omics_update_run_cache(
cacheBehavior = NULL,
description = NULL,
id,
name = NULL
)
cacheBehavior |
Update the default run cache behavior. |
description |
Update the run cache description. |
id |
[required] The identifier of the run cache you want to update. |
name |
Update the name of the run cache. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.