View source: R/omics_operations.R
| omics_update_workflow | R Documentation |
Updates information about a workflow.
See https://www.paws-r-sdk.com/docs/omics_update_workflow/ for full documentation.
omics_update_workflow(
id,
name = NULL,
description = NULL,
storageType = NULL,
storageCapacity = NULL,
readmeMarkdown = NULL
)
id |
[required] The workflow's ID. |
name |
A name for the workflow. |
description |
A description for the workflow. |
storageType |
The default storage type for runs that use this workflow. STATIC storage allocates a fixed amount of storage. DYNAMIC storage dynamically scales the storage up or down, based on file system utilization. For more information about static and dynamic storage, see Running workflows in the Amazon Web Services HealthOmics User Guide. |
storageCapacity |
The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version. |
readmeMarkdown |
The markdown content for the workflow's README file. This provides documentation and usage information for users of the workflow. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.