View source: R/omics_operations.R
| omics_update_workflow_version | R Documentation |
Updates information about the workflow version. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.
See https://www.paws-r-sdk.com/docs/omics_update_workflow_version/ for full documentation.
omics_update_workflow_version(
workflowId,
versionName,
description = NULL,
storageType = NULL,
storageCapacity = NULL,
readmeMarkdown = NULL
)
workflowId |
[required] The workflow's ID. The |
versionName |
[required] The name of the workflow version. |
description |
Description of the workflow version. |
storageType |
The default storage type for runs that use this workflow version. The |
storageCapacity |
The default static storage capacity (in gibibytes) for runs that use this workflow version. The |
readmeMarkdown |
The markdown content for the workflow version's README file. This provides documentation and usage information for users of this specific workflow version. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.