View source: R/omics_operations.R
| omics_upload_read_set_part | R Documentation |
Uploads a specific part of a read set into a sequence store. When you a upload a read set part with a part number that already exists, the new part replaces the existing one. This operation returns a JSON formatted response containing a string identifier that is used to confirm that parts are being added to the intended upload.
See https://www.paws-r-sdk.com/docs/omics_upload_read_set_part/ for full documentation.
omics_upload_read_set_part(
sequenceStoreId,
uploadId,
partSource,
partNumber,
payload
)
sequenceStoreId |
[required] The Sequence Store ID used for the multipart upload. |
uploadId |
[required] The ID for the initiated multipart upload. |
partSource |
[required] The source file for an upload part. |
partNumber |
[required] The number of the part being uploaded. |
payload |
[required] The read set data to upload for a part. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.