View source: R/s3_operations.R
| s3_create_bucket | R Documentation |
This action creates an Amazon S3 bucket. To create an Amazon S3 on Outposts bucket, see create_bucket .
See https://www.paws-r-sdk.com/docs/s3_create_bucket/ for full documentation.
s3_create_bucket(
ACL = NULL,
Bucket,
CreateBucketConfiguration = NULL,
GrantFullControl = NULL,
GrantRead = NULL,
GrantReadACP = NULL,
GrantWrite = NULL,
GrantWriteACP = NULL,
ObjectLockEnabledForBucket = NULL,
ObjectOwnership = NULL,
BucketNamespace = NULL
)
ACL |
The canned ACL to apply to the bucket. This functionality is not supported for directory buckets. |
Bucket |
[required] The name of the bucket to create. General purpose buckets - For information about bucket naming restrictions, see Bucket naming rules in the Amazon S3 User Guide. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
CreateBucketConfiguration |
The configuration information for the bucket. |
GrantFullControl |
Allows grantee the read, write, read ACP, and write ACP permissions on the bucket. This functionality is not supported for directory buckets. |
GrantRead |
Allows grantee to list the objects in the bucket. This functionality is not supported for directory buckets. |
GrantReadACP |
Allows grantee to read the bucket ACL. This functionality is not supported for directory buckets. |
GrantWrite |
Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects. This functionality is not supported for directory buckets. |
GrantWriteACP |
Allows grantee to write the ACL for the applicable bucket. This functionality is not supported for directory buckets. |
ObjectLockEnabledForBucket |
Specifies whether you want S3 Object Lock to be enabled for the new bucket. This functionality is not supported for directory buckets. |
ObjectOwnership |
The container element for object ownership for a bucket's ownership controls.
By default, This functionality is not supported for directory buckets. Directory buckets use the bucket owner enforced setting for S3 Object Ownership. |
BucketNamespace |
Specifies the namespace where you want to create your general purpose bucket. When you create a general purpose bucket, you can choose to create a bucket in the shared global namespace or you can choose to create a bucket in your account regional namespace. Your account regional namespace is a subdivision of the global namespace that only your account can create buckets in. For more information on bucket namespaces, see Namespaces for general purpose buckets. General purpose buckets in your account regional namespace must follow a specific naming convention. These buckets consist of a bucket name prefix that you create, and a suffix that contains your 12-digit Amazon Web Services Account ID, the Amazon Web Services Region code, and ends with This functionality is not supported for directory buckets. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.