View source: R/s3_operations.R
| s3_create_bucket_metadata_configuration | R Documentation |
Creates an S3 Metadata V2 metadata configuration for a general purpose bucket. For more information, see Accelerating data discovery with S3 Metadata in the Amazon S3 User Guide.
See https://www.paws-r-sdk.com/docs/s3_create_bucket_metadata_configuration/ for full documentation.
s3_create_bucket_metadata_configuration(
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
MetadataConfiguration,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The general purpose bucket that you want to create the metadata configuration for. |
ContentMD5 |
The |
ChecksumAlgorithm |
The checksum algorithm to use with your metadata configuration. |
MetadataConfiguration |
[required] The contents of your metadata configuration. |
ExpectedBucketOwner |
The expected owner of the general purpose bucket that corresponds to your metadata configuration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.