View source: R/s3_operations.R
| s3_create_bucket_metadata_table_configuration | R Documentation |
We recommend that you create your S3 Metadata configurations by using the V2 create_bucket_metadata_configuration API operation. We no longer recommend using the V1 create_bucket_metadata_table_configuration API operation.
See https://www.paws-r-sdk.com/docs/s3_create_bucket_metadata_table_configuration/ for full documentation.
s3_create_bucket_metadata_table_configuration(
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
MetadataTableConfiguration,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The general purpose bucket that you want to create the metadata table configuration for. |
ContentMD5 |
The |
ChecksumAlgorithm |
The checksum algorithm to use with your metadata table configuration. |
MetadataTableConfiguration |
[required] The contents of your metadata table configuration. |
ExpectedBucketOwner |
The expected owner of the general purpose bucket that corresponds to your metadata table configuration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.