Deletes the cors configuration information set for the bucket.
See https://paws-r.github.io/docs/s3/delete_bucket_cors.html for full documentation.
s3_delete_bucket_cors(Bucket, ExpectedBucketOwner = NULL)[required] Specifies the bucket whose cors configuration is being deleted.
The account ID of the expected bucket owner. If the bucket is owned by a
different account, the request fails with the HTTP status code
403 Forbidden (access denied).