View source: R/s3_operations.R
| s3_delete_bucket_inventory_configuration | R Documentation |
Deletes an S3 Inventory configuration (identified by the inventory ID) from the bucket.
See https://www.paws-r-sdk.com/docs/s3_delete_bucket_inventory_configuration/ for full documentation.
s3_delete_bucket_inventory_configuration(
Bucket,
Id,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket containing the inventory configuration to delete. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
Id |
[required] The ID used to identify the inventory configuration. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.