View source: R/s3_operations.R
| s3_delete_bucket_metadata_configuration | R Documentation |
Deletes an S3 Metadata configuration from a general purpose bucket. For more information, see Accelerating data discovery with S3 Metadata in the Amazon S3 User Guide.
See https://www.paws-r-sdk.com/docs/s3_delete_bucket_metadata_configuration/ for full documentation.
s3_delete_bucket_metadata_configuration(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The general purpose bucket that you want to remove the metadata configuration from. |
ExpectedBucketOwner |
The expected bucket owner of the general purpose bucket that you want to remove the metadata table configuration from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.