View source: R/s3_operations.R
| s3_delete_bucket_metadata_table_configuration | R Documentation |
We recommend that you delete your S3 Metadata configurations by using the V2 delete_bucket_metadata_table_configuration API operation. We no longer recommend using the V1 delete_bucket_metadata_table_configuration API operation.
See https://www.paws-r-sdk.com/docs/s3_delete_bucket_metadata_table_configuration/ for full documentation.
s3_delete_bucket_metadata_table_configuration(
Bucket,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The general purpose bucket that you want to remove the metadata table configuration from. |
ExpectedBucketOwner |
The expected bucket owner of the general purpose bucket that you want to remove the metadata table configuration from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.