View source: R/s3_operations.R
| s3_delete_object_annotation | R Documentation |
Deletes a specific annotation from an Amazon S3 object. Use the x-amz-object-if-match header to perform a conditional delete that only succeeds if the object's ETag matches the provided value, preventing race conditions during concurrent updates.
See https://www.paws-r-sdk.com/docs/s3_delete_object_annotation/ for full documentation.
s3_delete_object_annotation(
Bucket,
Key,
AnnotationName,
VersionId = NULL,
RequestPayer = NULL,
ExpectedBucketOwner = NULL,
ObjectIfMatch = NULL
)
Bucket |
[required] The name of the bucket that contains the object. |
Key |
[required] The object key. |
AnnotationName |
[required] The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with Length Constraints: Minimum length of 1. Maximum length of 512 bytes. |
VersionId |
The version ID of the object. |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. |
ObjectIfMatch |
If specified, the operation only succeeds if the object's ETag matches the provided value. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.