| s3_generate_presigned_post | R Documentation |
Generate the url and form fields used for a presigned s3 post
s3_generate_presigned_post(Bucket, Key, Fields = list(),
Conditions = list(), ExpiresIn = 3600)
Bucket |
(character): The name of the bucket to presign the post to.
Note that bucket related conditions should not be included in the
|
Key |
(character): Key name, optionally add |
Fields |
(list): A list of prefilled form fields to build on top of.
Note that if a particular element is included in |
Conditions |
(list): A list of conditions to include in the policy.
Each element is either a named list for an exact-match condition, e.g.
|
ExpiresIn |
(numeric): The number of seconds the presigned post is valid for. By default it expires in an hour (3600 seconds). |
A list with two elements: url and fields. url is the
url to post to. fields is a list of form fields and values to
include in the post.
svc$generate_presigned_post( Bucket = "string", Key = "string", Fields = list(), Conditions = list(), ExpiresIn = 3600 )
## Not run:
# The following example generates the url and form fields for a presigned
# post that you can give to others so that they can upload a file to an
# S3 bucket without needing AWS credentials.
svc$generate_presigned_post(
Bucket = "BUCKET_NAME",
Key = "OBJECT_KEY"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.