View source: R/s3_operations.R
| s3_get_bucket_lifecycle_configuration | R Documentation |
Returns the lifecycle configuration information set on the bucket. For information about lifecycle configuration, see Object Lifecycle Management.
See https://www.paws-r-sdk.com/docs/s3_get_bucket_lifecycle_configuration/ for full documentation.
s3_get_bucket_lifecycle_configuration(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The name of the bucket for which to get the lifecycle information. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.