View source: R/s3_operations.R
| s3_get_bucket_metadata_configuration | R Documentation |
Retrieves the S3 Metadata configuration for a general purpose bucket. For more information, see Accelerating data discovery with S3 Metadata in the Amazon S3 User Guide.
See https://www.paws-r-sdk.com/docs/s3_get_bucket_metadata_configuration/ for full documentation.
s3_get_bucket_metadata_configuration(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The general purpose bucket that corresponds to the metadata configuration that you want to retrieve. |
ExpectedBucketOwner |
The expected owner of the general purpose bucket that you want to retrieve the metadata table configuration for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.