View source: R/s3_operations.R
| s3_get_bucket_metadata_table_configuration | R Documentation |
We recommend that you retrieve your S3 Metadata configurations by using the V2 get_bucket_metadata_table_configuration API operation. We no longer recommend using the V1 get_bucket_metadata_table_configuration API operation.
See https://www.paws-r-sdk.com/docs/s3_get_bucket_metadata_table_configuration/ for full documentation.
s3_get_bucket_metadata_table_configuration(Bucket, ExpectedBucketOwner = NULL)
Bucket |
[required] The general purpose bucket that corresponds to the metadata table configuration that you want to retrieve. |
ExpectedBucketOwner |
The expected owner of the general purpose bucket that you want to retrieve the metadata table configuration for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.