View source: R/s3_operations.R
| s3_get_object_torrent | R Documentation |
This operation is not supported for directory buckets.
See https://www.paws-r-sdk.com/docs/s3_get_object_torrent/ for full documentation.
s3_get_object_torrent(
Bucket,
Key,
RequestPayer = NULL,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket containing the object for which to get the torrent files. |
Key |
[required] The object key for which to get the information. |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.