View source: R/s3_operations.R
| s3_list_bucket_metrics_configurations | R Documentation |
Lists the metrics configurations for the bucket. The metrics configurations are only for the request metrics of the bucket and do not provide information on daily storage metrics. You can have up to 1,000 configurations per bucket.
See https://www.paws-r-sdk.com/docs/s3_list_bucket_metrics_configurations/ for full documentation.
s3_list_bucket_metrics_configurations(
Bucket,
ContinuationToken = NULL,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket containing the metrics configurations to retrieve. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
ContinuationToken |
The marker that is used to continue a metrics configuration listing that has been truncated. Use the |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.