View source: R/s3_operations.R
| s3_list_object_versions | R Documentation |
This operation is not supported for directory buckets.
See https://www.paws-r-sdk.com/docs/s3_list_object_versions/ for full documentation.
s3_list_object_versions(
Bucket,
Delimiter = NULL,
EncodingType = NULL,
KeyMarker = NULL,
MaxKeys = NULL,
Prefix = NULL,
VersionIdMarker = NULL,
ExpectedBucketOwner = NULL,
RequestPayer = NULL,
OptionalObjectAttributes = NULL
)
Bucket |
[required] The bucket name that contains the objects. |
Delimiter |
A delimiter is a character that you specify to group keys. All keys that contain the same string between the
|
EncodingType |
Encoding type used by Amazon S3 to encode the object keys in the response. Responses are encoded only in UTF-8. An object key can contain any Unicode character. However, the XML 1.0 parser can't parse certain characters, such as characters with an ASCII value from 0 to 10. For characters that aren't supported in XML 1.0, you can add this parameter to request that Amazon S3 encode the keys in the response. For more information about characters to avoid in object key names, see Object key naming guidelines. When using the URL encoding type, non-ASCII characters that are used in an object's key name will be percent-encoded according to UTF-8 code values. For example, the object |
KeyMarker |
Specifies the key to start with when listing objects in a bucket. |
MaxKeys |
Sets the maximum number of keys returned in the response. By default, the action returns up to 1,000 key names. The response might contain fewer keys but will never contain more. If additional keys satisfy the search criteria, but were not returned because |
Prefix |
Use this parameter to select only those keys that begin with the specified prefix. You can use prefixes to separate a bucket into different groupings of keys. (You can think of using |
VersionIdMarker |
Specifies the object version you want to start listing from. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code |
RequestPayer |
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide. This functionality is not supported for directory buckets. |
OptionalObjectAttributes |
Specifies the optional fields that you want returned in the response. Fields that you do not specify are not returned. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.