View source: R/s3_operations.R
| s3_put_bucket_inventory_configuration | R Documentation |
This implementation of the PUT action adds an S3 Inventory configuration (identified by the inventory ID) to the bucket. You can have up to 1,000 inventory configurations per bucket.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_inventory_configuration/ for full documentation.
s3_put_bucket_inventory_configuration(
Bucket,
Id,
InventoryConfiguration,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket where the inventory configuration will be stored. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
Id |
[required] The ID used to identify the inventory configuration. |
InventoryConfiguration |
[required] Specifies the inventory configuration. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.