View source: R/s3_operations.R
| s3_put_bucket_metrics_configuration | R Documentation |
Sets a metrics configuration (specified by the metrics configuration ID) for the bucket. You can have up to 1,000 metrics configurations per bucket. If you're updating an existing metrics configuration, note that this is a full replacement of the existing metrics configuration. If you don't include the elements you want to keep, they are erased.
See https://www.paws-r-sdk.com/docs/s3_put_bucket_metrics_configuration/ for full documentation.
s3_put_bucket_metrics_configuration(
Bucket,
Id,
MetricsConfiguration,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket for which the metrics configuration is set. Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format |
Id |
[required] The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores. |
MetricsConfiguration |
[required] Specifies the metrics configuration. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.