View source: R/s3_operations.R
| s3_rename_object | R Documentation |
Renames an existing object in a directory bucket that uses the S3 Express One Zone storage class. You can use rename_object by specifying an existing object’s name as the source and the new name of the object as the destination within the same directory bucket.
See https://www.paws-r-sdk.com/docs/s3_rename_object/ for full documentation.
s3_rename_object(
Bucket,
Key,
RenameSource,
DestinationIfMatch = NULL,
DestinationIfNoneMatch = NULL,
DestinationIfModifiedSince = NULL,
DestinationIfUnmodifiedSince = NULL,
SourceIfMatch = NULL,
SourceIfNoneMatch = NULL,
SourceIfModifiedSince = NULL,
SourceIfUnmodifiedSince = NULL,
ClientToken = NULL
)
Bucket |
[required] The bucket name of the directory bucket containing the object. You must use virtual-hosted-style requests in the format |
Key |
[required] Key name of the object to rename. |
RenameSource |
[required] Specifies the source for the rename operation. The value must be URL encoded. |
DestinationIfMatch |
Renames the object only if the ETag (entity tag) value provided during the operation matches the ETag of the object in S3. The Expects the ETag value as a string. |
DestinationIfNoneMatch |
Renames the object only if the destination does not already exist in the specified directory bucket. If the object does exist when you send a request with Expects the |
DestinationIfModifiedSince |
Renames the object if the destination exists and if it has been modified since the specified time. |
DestinationIfUnmodifiedSince |
Renames the object if it hasn't been modified since the specified time. |
SourceIfMatch |
Renames the object if the source exists and if its entity tag (ETag) matches the specified ETag. |
SourceIfNoneMatch |
Renames the object if the source exists and if its entity tag (ETag) is different than the specified ETag. If an asterisk ( |
SourceIfModifiedSince |
Renames the object if the source exists and if it has been modified since the specified time. |
SourceIfUnmodifiedSince |
Renames the object if the source exists and hasn't been modified since the specified time. |
ClientToken |
A unique string with a max of 64 ASCII characters in the ASCII range of 33 - 126.
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.