View source: R/s3_operations.R
| s3_update_bucket_metadata_annotation_table_configuration | R Documentation |
Updates the annotation table configuration for an Amazon S3 bucket's metadata configuration. Use this operation to enable or disable the annotation table, or to update its associated IAM role.
See https://www.paws-r-sdk.com/docs/s3_update_bucket_metadata_annotation_table_configuration/ for full documentation.
s3_update_bucket_metadata_annotation_table_configuration(
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
AnnotationTableConfiguration,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The name of the bucket whose annotation table configuration to update. |
ContentMD5 |
Base64-encoded MD5 digest of the message body. |
ChecksumAlgorithm |
Checksum algorithm for the request payload. |
AnnotationTableConfiguration |
[required] The annotation table configuration updates to apply. |
ExpectedBucketOwner |
The account ID of the expected bucket owner. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.