View source: R/s3_operations.R
| s3_update_bucket_metadata_journal_table_configuration | R Documentation |
Enables or disables journal table record expiration for an S3 Metadata configuration on a general purpose bucket. For more information, see Accelerating data discovery with S3 Metadata in the Amazon S3 User Guide.
See https://www.paws-r-sdk.com/docs/s3_update_bucket_metadata_journal_table_configuration/ for full documentation.
s3_update_bucket_metadata_journal_table_configuration(
Bucket,
ContentMD5 = NULL,
ChecksumAlgorithm = NULL,
JournalTableConfiguration,
ExpectedBucketOwner = NULL
)
Bucket |
[required] The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable journal table record expiration for. |
ContentMD5 |
The |
ChecksumAlgorithm |
The checksum algorithm to use with your journal table configuration. |
JournalTableConfiguration |
[required] The contents of your journal table configuration. |
ExpectedBucketOwner |
The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable journal table record expiration for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.