View source: R/s3control_operations.R
| s3control_delete_access_point_scope | R Documentation |
Deletes an existing access point scope for a directory bucket.
See https://www.paws-r-sdk.com/docs/s3control_delete_access_point_scope/ for full documentation.
s3control_delete_access_point_scope(AccountId, Name)
AccountId |
[required] The Amazon Web Services account ID that owns the access point with the scope that you want to delete. |
Name |
[required] The name of the access point with the scope that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.