View source: R/s3control_operations.R
| s3control_put_access_point_scope | R Documentation |
Creates or replaces the access point scope for a directory bucket. You can use the access point scope to restrict access to specific prefixes, API operations, or a combination of both.
See https://www.paws-r-sdk.com/docs/s3control_put_access_point_scope/ for full documentation.
s3control_put_access_point_scope(AccountId, Name, Scope)
AccountId |
[required] The Amazon Web Services account ID that owns the access point with scope that you want to create or replace. |
Name |
[required] The name of the access point with the scope that you want to create or replace. |
Scope |
[required] Object prefixes, API operations, or a combination of both. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.