View source: R/s3tables_operations.R
| s3tables_create_namespace | R Documentation |
Creates a namespace. A namespace is a logical grouping of tables within your table bucket, which you can use to organize tables. For more information, see Create a namespace in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_create_namespace/ for full documentation.
s3tables_create_namespace(tableBucketARN, namespace)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket to create the namespace in. |
namespace |
[required] A name for the namespace. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.