View source: R/s3tables_operations.R
| s3tables_create_table | R Documentation |
Creates a new table associated with the given namespace in a table bucket. For more information, see Creating an Amazon S3 table in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_create_table/ for full documentation.
s3tables_create_table(
tableBucketARN,
namespace,
name,
format,
metadata = NULL,
encryptionConfiguration = NULL,
storageClassConfiguration = NULL,
tags = NULL
)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket to create the table in. |
namespace |
[required] The namespace to associated with the table. |
name |
[required] The name for the table. |
format |
[required] The format for the table. |
metadata |
The metadata for the table. |
encryptionConfiguration |
The encryption configuration to use for the table. This configuration specifies the encryption algorithm and, if using SSE-KMS, the KMS key to use for encrypting the table. If you choose SSE-KMS encryption you must grant the S3 Tables maintenance principal access to your KMS key. For more information, see Permissions requirements for S3 Tables SSE-KMS encryption. |
storageClassConfiguration |
The storage class configuration for the table. If not specified, the table inherits the storage class configuration from its table bucket. Specify this parameter to override the bucket's default storage class for this table. |
tags |
A map of user-defined tags that you would like to apply to the table that you are creating. A tag is a key-value pair that you apply to your resources. Tags can help you organize, track costs for, and control access to resources. For more information, see Tagging for cost allocation or attribute-based access control (ABAC). You must have the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.