View source: R/s3tables_operations.R
| s3tables_delete_table_bucket_replication | R Documentation |
Deletes the replication configuration for a table bucket. After deletion, new table updates will no longer be replicated to destination buckets, though existing replicated tables will remain in destination buckets.
See https://www.paws-r-sdk.com/docs/s3tables_delete_table_bucket_replication/ for full documentation.
s3tables_delete_table_bucket_replication(tableBucketARN, versionToken = NULL)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket. |
versionToken |
A version token from a previous GetTableBucketReplication call. Use this token to ensure you're deleting the expected version of the configuration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.