View source: R/s3tables_operations.R
| s3tables_get_table_maintenance_configuration | R Documentation |
Gets details about the maintenance configuration of a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_get_table_maintenance_configuration/ for full documentation.
s3tables_get_table_maintenance_configuration(tableBucketARN, namespace, name)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket. |
namespace |
[required] The namespace associated with the table. |
name |
[required] The name of the table. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.