View source: R/s3tables_operations.R
| s3tables_get_table_record_expiration_configuration | R Documentation |
Retrieves the expiration configuration settings for records in a table, and the status of the configuration. If the status of the configuration is enabled, records expire and are automatically removed from the table after the specified number of days.
See https://www.paws-r-sdk.com/docs/s3tables_get_table_record_expiration_configuration/ for full documentation.
s3tables_get_table_record_expiration_configuration(tableArn)
tableArn |
[required] The Amazon Resource Name (ARN) of the table. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.