View source: R/s3tables_operations.R
| s3tables_get_table_record_expiration_job_status | R Documentation |
Retrieves the status, metrics, and details of the latest record expiration job for a table. This includes when the job ran, and whether it succeeded or failed. If the job ran successfully, this also includes statistics about the records that were removed.
See https://www.paws-r-sdk.com/docs/s3tables_get_table_record_expiration_job_status/ for full documentation.
s3tables_get_table_record_expiration_job_status(tableArn)
tableArn |
[required] The Amazon Resource Name (ARN) of the table. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.