View source: R/s3tables_operations.R
| s3tables_get_table_replication_status | R Documentation |
Retrieves the replication status for a table, including the status of replication to each destination. This operation provides visibility into replication health and progress.
See https://www.paws-r-sdk.com/docs/s3tables_get_table_replication_status/ for full documentation.
s3tables_get_table_replication_status(tableArn)
tableArn |
[required] The Amazon Resource Name (ARN) of the table. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.