View source: R/s3tables_operations.R
| s3tables_put_table_bucket_maintenance_configuration | R Documentation |
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket. For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_put_table_bucket_maintenance_configuration/ for full documentation.
s3tables_put_table_bucket_maintenance_configuration(
tableBucketARN,
type,
value
)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket associated with the maintenance configuration. |
type |
[required] The type of the maintenance configuration. |
value |
[required] Defines the values of the maintenance configuration for the table bucket. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.