View source: R/s3tables_operations.R
| s3tables_put_table_bucket_policy | R Documentation |
Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket. For more information, see Adding a table bucket policy in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_put_table_bucket_policy/ for full documentation.
s3tables_put_table_bucket_policy(tableBucketARN, resourcePolicy)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket. |
resourcePolicy |
[required] The |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.