View source: R/s3tables_operations.R
| s3tables_put_table_policy | R Documentation |
Creates a new table policy or replaces an existing table policy for a table. For more information, see Adding a table policy in the Amazon Simple Storage Service User Guide.
See https://www.paws-r-sdk.com/docs/s3tables_put_table_policy/ for full documentation.
s3tables_put_table_policy(tableBucketARN, namespace, name, resourcePolicy)
tableBucketARN |
[required] The Amazon Resource Name (ARN) of the table bucket that contains the table. |
namespace |
[required] The namespace associated with the table. |
name |
[required] The name of the table. |
resourcePolicy |
[required] The |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.