View source: R/storagegateway_operations.R
| storagegateway_cancel_cache_report | R Documentation |
Cancels generation of a specified cache report. You can use this operation to manually cancel an IN-PROGRESS report for any reason. This action changes the report status from IN-PROGRESS to CANCELLED. You can only cancel in-progress reports. If the the report you attempt to cancel is in FAILED, ERROR, or COMPLETED state, the cancel operation returns an error.
See https://www.paws-r-sdk.com/docs/storagegateway_cancel_cache_report/ for full documentation.
storagegateway_cancel_cache_report(CacheReportARN)
CacheReportARN |
[required] The Amazon Resource Name (ARN) of the cache report you want to cancel. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.