View source: R/storagegateway_operations.R
| storagegateway_evict_files_failing_upload | R Documentation |
Starts a process that cleans the specified file share's cache of file entries that are failing upload to Amazon S3. This API operation reports success if the request is received with valid arguments, and there are no other cache clean operations currently in-progress for the specified file share. After a successful request, the cache clean operation occurs asynchronously and reports progress using CloudWatch logs and notifications.
See https://www.paws-r-sdk.com/docs/storagegateway_evict_files_failing_upload/ for full documentation.
storagegateway_evict_files_failing_upload(FileShareARN, ForceRemove = NULL)
FileShareARN |
[required] The Amazon Resource Name (ARN) of the file share for which you want to start the cache clean operation. |
ForceRemove |
Specifies whether cache entries with full or partial file data currently stored on the gateway will be forcibly removed by the cache clean operation. Valid arguments:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.